(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; initialization; nohscroll; center; ]
*)
Finite Volume Method
(*
:[font = subtitle; inactive; nohscroll; center; ]

(Local Approximation Study)
:[font = subsubtitle; inactive; nohscroll; center; ]

Triangular Mesh
:[font = name; inactive; nohscroll; ]

                                    Victor G. Ganzha and Evgenii V. Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]
This Mathematica-Notebook is part of the book entitled
                                  V.G.Ganzha and E.V.Vorozhtsov
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.

:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]

 Numerical Solutions For Partial Differential Equations: Problem Solving
 Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.

:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The program appr31.ma which follows below enables one to compute 
 the symbolic expression for the leading terms of the truncation error of 
 the finite volume approximation of the partial derivative of the function 
 F(x,y)  with respect to x or y  on  an irregular or regular mesh of triangu-
 lar cells, see  also  subsection  4.6.2  of  the  above book. The uniform 
 mesh of triangular  cells  is  made from the uniform rectangular grid by 
drawing one diagonal in each rectangular cell.   

:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1.
:[font = special4; inactive; nowordwrap; nohscroll; ]

Load and compile the program beginning with the line
:[font = input; nowordwrap; ]
ClearAll[appr31];

:[font = subsection; inactive; ]
Step 2.
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the input value kt in the line
:[font = input; nowordwrap; ]

              appr31[3]
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line and wait for the result of symbolic computation. 
The value of kt  (kt = 2  or  kt = 3)  represents the order of expansion 
 into the Taylor series,

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; ]

appr31[kt_]:=
(
(*  The expansion of the function F(x,y) into the
    Taylor series with respect to (xc, yc) point *)

    F[x_, y_]:=
(sf = Fc + Fx*(x - xc) + Fy*(y - yc) +
1/2*Fxx*(x - xc)^2 + Fxy*(x - xc)*(y - yc) +
1/2*Fyy*(y - yc)^2;
If[kt > 2, sf = sf +
1/6*Fxxx*(x-xc)^3+1/2*Fxxy*(x - xc)^2*(y - yc) +
1/2*Fxyy*(x-xc)*(y-yc)^2+1/6*Fyyy*(y-yc)^3]; sf );

(*  The difference operator under consideration  *)
         dy12 = y2 - y1;    dy23 = y3 - y2;
         dy34 = y4 - y3;    dy45 = y5 - y4;
         dy56 = y6 - y5;    dy67 = y1 - y6;
(* Substitution of the Taylor series expansions  *)
Print["Substitution of the Taylor series expansions"];
sc1 = (F[x1, y1] + F[x2, y2])*dy12 +
      (F[x2, y2] + F[x3, y3])*dy23 +
      (F[x3, y3] + F[x4, y4])*dy34 +
      (F[x4, y4] + F[x5, y5])*dy45 +
      (F[x5, y5] + F[x6, y6])*dy56 +
      (F[x6, y6] + F[x1, y1])*dy67;
(* ------ Ai is the area of the hexagon -------- *)
Ai = ((x1+x2)*dy12+(x2+x3)*dy23 + (x3 + x4)*dy34 +
      (x4+x5)*dy45+(x5+x6)*dy56+(x6+x1)*dy67)/2;
			  Ai = Simplify[Ai];
  OutputForm[sc1] >> ap3.m;
                       OutputForm[Ai] >>> ap3.m;
sc1 = sc1;  sc1 = Expand[sc1];
                              sc2 = sc1/(2*Ai);
Print["The difference operator expanded into Taylor",
" series has the form"];
			 Print[sc2];

(* -- Representation of the spatial coordinates of 
      points 1, 2, 3, 4, 5, 6 as the deviations 
      from the center (xc, yc) of the Taylor 
      expansions ------------------------------ *)
        x1 = xc + c1x*h;   y1 = yc + c1y*h;
        x2 = xc + c2x*h;   y2 = yc + c2y*h;
        x3 = xc + c3x*h;   y3 = yc + c3y*h;
        x4 = xc + c4x*h;   y4 = yc + c4y*h;
        x5 = xc + c5x*h;   y5 = yc + c5y*h;
        x6 = xc + c6x*h;   y6 = yc + c6y*h;
Print["Substitution of the coordinates of points 1,...,6"];
Print["into the expanded difference operator as the"];
Print["deviations from the (xc, yc) point."];
   sc1 = sc1;   sc1 = Expand[sc1];
   OutputForm[sc1] >>> ap3.m;
   Ai = Ai;   Ai = Expand[Ai];  Ai = Simplify[Ai];
   OutputForm[Ai] >>> ap3.m;
   a2 = Coefficient[Ai, h, 2];
		    OutputForm[a2] >>> ap3.m;
Print["Determination of the coefficient of h^2 in the"];
Print["numerator of the expanded difference operator."];
   r0 = Coefficient[sc1, h, 2];  r0 = Simplify[r0];
  OutputForm[r0] >>> ap3.m;

Print["Determination of the coefficient of h^3 in the"];
Print["numerator of the expanded difference operator."];
   r1 = Coefficient[sc1, h, 3];  r1 = Simplify[r1];
        OutputForm[r1] >>> ap3.m;

Print["Determination of the coefficient of h^4 in the"];
Print["numerator of the expanded difference operator."];
   r2 = Coefficient[sc1, h, 4];  r2 = Simplify[r2];
         OutputForm[r2] >>> ap3.m;

Print["The coefficient of h^0 in the operator sc2 is"];
       r0 = r0/(2*a2);
Print[r0];
		  OutputForm[r0] >>> ap3.m;
Print["The coefficient of h^1 in the operator sc2 is"];
       r1 = r1/(2*a2);
Print[r1];
		  OutputForm[r1] >>> ap3.m;
Print["The coefficient of h^2 in the operator sc2 is"];
       r2 = r2/(2*a2);
Print[r2];
		  OutputForm[r2] >>> ap3.m;

(* -- The particular case of an uniform triangular 
      grid made from the uniform rectangular grid 
      by drawing one diagonal in each rectangular 
      cell ------------------------------------ *)
Print["The particular case of uniform triangular grid"];
Print["c is the cell aspect ratio, c = h2/h1"];
c1x = 1;    c1y = 0;    c2x = 1;    c2y = c;
c3x = 0;    c3y = c;    c4x = -1;   c4y = 0;
c5x = -1;   c5y = -c;   c6x = 0;    c6y = -c;
 r1 = r1; r1 = Simplify[r1];
Print["The coefficient of h in the operator sc2"];
Print["in the case of  uniform triangular mesh is"];
Print[r1];
            OutputForm[r1] >>> ap3.m; 
 r2 = r2; r2 = Simplify[r2];
Print["The coefficient of h^2 in the operator sc2"];
Print["in the case of the uniform triangular mesh is"];
Print[r2];
           OutputForm[r2] >>> ap3.m;
Clear[c1x,c1y,c2x,c2y,c3x,c3y,c4x,c4y,c5x,c5y,
         c6x,c6y, Ai, sc1, sc2]; ) 
^*)