(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
Color Maps
:[font = name; inactive; nohscroll; ]

                                   Victor G. Ganzha and Evgenii V. Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

This Mathematica-Notebook is part of the book entitled
                                  V.G.Ganzha and E.V.Vorozhtsov
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]
Numerical Solutions For Partial Differential Equations: Problem Solving
Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.

:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]
The program col.ma which follows below creates two different color 
maps corresponding to the test function 
                   v(x, y) = |sin 2x cos 2y|,     0 <= x,y <= 2 Pi, 
see also Section 2.12 of the above book.  The values of a bivariate
function v(x, y) are specified at the centers of cells of an uiform rect-
angular grid in the (x, y) plane. 

:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = special4; inactive; nowordwrap; nohscroll; ]

Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]

ClearAll[col];
:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the input data by entering them in the line (see Section
"Example of the Input Data"):
:[font = input; nowordwrap; ]

col[40, 40, 0.5, 100, 100];
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line and wait for the result of numerical computation. 
The meaning of the input parameters is explained in the section
"Parameters Used in Program col.ma".
:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; ]

ClearAll[col];
col[ix_, jy_, h0_, m1int_, m2int_] := 
(
xl = 0.0; xr = N[2 Pi]; yl = xl; yr = xr;
dr = xr - xl; h1 = dr/(ix-1); h2 = dr/(jy - 1);
v = Table[1.0, {i, ix}, {j, jy}];
xmax = N[2*Pi];
 Do[xi = (i - 1)*xmax/(ix - 1); z1 = N[Sin[2*xi]];
    Do[ yj = (j - 1)*xmax/(jy - 1);
 	v[[i, j]] = Abs[N[z1*Cos[2*yj]]], {j, jy}],
		       {i, ix}];
cl1[f_]:= Hue[h0*(1 - f)];
cl2[f_]:=Hue[f];
Print["The color map on the original ",ix,"x",jy,
      " mesh"];
    gr1 = DensityGraphics[v];
   gr2 = Show[gr1, ColorFunction -> (cl2[#]&), 
                   Mesh -> False];
   Display["fig2_29", gr2];
(* ---- Interpolation on a finer mesh ---- *)
tb = {};
	 Do[ yj = xl + (j - 1)*h2;
	     Do[ xi = xl + (i - 1)*h1;
AppendTo[tb, {xi, yj, v[[i,j]]}], {i, ix}],
				 {j, jy}];
Print["Calculation of the interpolating function."];
   vint = Interpolation[tb, InterpolationOrder -> 1];
h1n = dr/(m1int - 1); h2n = dr/(m2int - 1);
Print["h1n = ", h1n, ", h2n = ", h2n];
vn = Table[0.0, {i, m1int}, {j, m2int}];
Print["Calculation of the values of v(x,y)",
      " in the nodes of a fine mesh."];
   Do[ yj = xl + (j - 1)*h2n;
       Do[ xi = xl + (i - 1)*h1n;
vn[[i, j]]=vint[xi, yj], {i,m1int}], {j,m2int}];
Print["Plotting the density graph on a fine mesh."];
     gr3 = DensityGraphics[vn];
   gr4 = Show[gr3, ColorFunction -> (cl1[#]&),
                   Mesh -> False];
Display["fig2_30", gr3];
 )

:[font = section; inactive; ]
Parameters Used in Program col.ma
:[font = special4; inactive; nowordwrap; nohscroll; ]
____________________________________________________
 Parameter                            Description
____________________________________________________
ix                      the number of cells of an uniform mesh in the interval 
                         0 <= x <= 2 Pi; ix > 1;
jy                      the number of cells of an uniform mesh in the interval 
                        0 <= y <= 2 Pi; jy > 1;
h0                    the number in  the  interval 0 < h0 <= 1 to  specify the 
                        color corresponding to the minimum value of the func-
                        tion u(x, y)  in  the spatial region under consideration;
m1int               the number of cells of a fine mesh in the interval 
                        0 <= x <= 2 Pi; m1int >= ix;
m2int               the number of cells of a fine mesh in the interval 
                        0 <= y <= 2 Pi; m2int  >=  jy.
____________________________________________________

:[font = section; inactive; ]
Example of the Input Data
:[font = input; nowordwrap; ]

col[40, 40, 0.5, 100, 100];

:[font = section; inactive; ]
The Structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]

The following color pictures are generated in the process of the work of
the program:

1. The color map of the function u(x,y) = |sin 2x cos 2y| on the original un-
     iform rectangular mesh;

2. The color map of the same function u(x, y) obtained in the same recta-
     ngular region by using the linear interpolation of the grid values given
     on the original grid onto a finer uniform grid introduced in the  spatial
     region under consideration.
^*)