(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
Dispersion
:[font = subtitle; inactive; nohscroll; center; ]

(Advection-Diffusion Equation)
:[font = name; inactive; nohscroll; ]

                                   Victor G. Ganzha and Evgenii V. Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

This Mathematica-Notebook is part of the book entitled
                                  V.G.Ganzha and E.V.Vorozhtsov
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]

Numerical Solutions For Partial Differential Equations: Problem Solving
Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = section; inactive; ]
Initialisation
:[font = special4; inactive; nowordwrap; nohscroll; ]

Needs[Algebra`ReIm`]
:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The program disp1ad.ma which follows below performs the dispersion 
analysis of scalar explicit two-level difference schemes approximating
the  one-dimensional  advection-diffusion equation. The description of 
the algorithm for dispersion analysis can be found in Section 3.8 of the 
above book.
:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = special4; inactive; nowordwrap; nohscroll; ]

Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]

ClearAll[disp1ad, a, cp1, cp2, nu, k, omega];

:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the form of a difference scheme by modifying the body of the
function sch1 or sch2, see below Section "Examples of Difference
Schemes".
:[font = subsection; inactive; ]
Step 3
:[font = special4; inactive; nowordwrap; nohscroll; ]
Specify the form of the nondimensional variable kappa in terms of which 
the stability region is to be determined. The corresponding transformati-
on rule should follow the expression for the difference scheme (see exa-
mples below) and should  be in  the same cell as the difference scheme 
itself. Load and compile  the difference scheme together with the transf-
ormation rule.

:[font = subsection; inactive; ]
Step 4
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the input data by entering them in the line (see Section
"Examples of the Input Data"):
:[font = input; nowordwrap; ]

disp1[5, -1.0, 1.0, 0.5, sch1];
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line and wait for the result of symbolic computation. The
meaning of the input parameters is explained in the Section
"Parameters Used in Program disp1ad.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; ]

ClearAll[disp1ad, a, cp1, cp2, nu, k, omega];
disp1ad[kt_, cpl_, cpr_, cp20_, sc_] := 
(
<< Algebra`ReIm`;
Print["The package Algebra`ReIm` is loaded"];
(* --- The variables xi, cp, dt, a, k are declared
                            to be real --------- *)
xi/: Im[xi] = 0;
cp/: Im[cp] = 0;
cp1/: Im[cp1] = 0;
cp2/: Im[cp2] = 0;
dt/: Im[dt] = 0;
a/: Im[a] = 0;
nu/: Im[nu] = 0;
k/: Im[k] = 0;
Print["Determination of omega from the original PDE"];
(* ---- Substitution of a Fourier harmonic into
	the partial differential equation ------ *)
dif1 = D[Exp[I*k*x - I*omega*t], t] +
               a*D[Exp[I*k*x - I*omega*t], x] -
nu*D[Exp[I*k*x - I*omega*t], {x, 2}];
OutputForm[dif1] >> dispres.m;

(* ---- Divide the both sides of obtained equation
           by Exp[I*(k*x - omega*t)] ----------- *)
dif2 = dif1/Exp[I*(k*x - omega*t)]; 
dif3 = Simplify[dif2];
OutputForm[dif3] >>> dispres.m;
sol0 = Solve[dif3==0, omega];
omega0 = omega /. sol0; omega=omega0[[1]]//Simplify;
Print["omega = ", omega];
  OutputForm[omega] >>> dispres.m;
reom = Re[omega];  imom = Im[omega];
Print["Re(omega) = ", reom];
Print["Im(omega) = ", imom];
(* -- Calculation of the expression for the step 
  operator corresponding to the original PDE --- *)
S0 = Exp[I*(k*x-reom*(t+dt))]/Exp[I*(k*x-reom*t)];
S0 = Simplify[S0];
OutputForm[S0] >>> dispres.m;
ims0 = Im[S0];   res0 = Re[S0];
    OutputForm[ims0] >>> dispres.m;
           OutputForm[res0] >>> dispres.m;
Phi0 = ArcTan[ims0/res0];  Phi0 = Simplify[Phi0];
Phi0 = Phi0 /. cap;  Phi0 = Simplify[Phi0];
Print["Phi0 = ", Phi0];
     OutputForm[Phi0] >>> dispres.m;

(* ---- Substitution of a Fourier harmonic into
        the difference scheme ------------------ *)
  sc0 = Expand[sc]/. cap;     
Print["The difference scheme under consideration"];
Print[sc0, " = 0"];
  sc0 >>> dispres.m;
  sc1 = sc0 /. {u[j_, n_] -> l^n*Exp[I*j*xi]};
(* -- Divide the both sides of obtained equation
           by l^n Exp[I*j*xi] ------------------ *)
      sc3 = sc1/(l^n*Exp[I*j*xi]) //Expand;
  sc2 = Simplify[sc3]; 
sol = Solve[sc2==0, l];
l1 = Simplify[l /. sol] ;
l4 = ComplexExpand[l1];                  
Print["The amplification factor of scheme has",
      " the form"];
Print["lambda = ", l4];
OutputForm[l4] >>> dispres.m;
l = l4[[1]]; lnum = Numerator[l];
OutputForm[lnum] >>> dispres.m;
lden = Denominator[l]; imd = Im[lden];
OutputForm[lden] >>> dispres.m;
OutputForm[imd] >>> dispres.m;
If[lden == 1, iml = Im[l]; rel = l - I*iml];
If[lden =!= 1 && imd == 0,
imn = Im[lnum]; reln = lnum - I*imn;
imn = Simplify[imn]; reln = Simplify[reln];
iml = imn/lden; rel = reln/lden];
(* ---- The complex denominator ---- *)
If[lden =!= 1 && imd =!= 0, reld = lden - I*imd;
ldenq = reld*reld + imd*imd;
imn = Im[lnum]; reln = lnum - I*imn;
imn = Simplify[imn]; reln = Simplify[reln];
rel = (reln*reld + imn*imd)/ldenq;
iml = (imn*reld - reln*imd)/ldenq];
rel = Simplify[rel]; iml = Simplify[iml];
OutputForm[rel] >>> dispres.m;
OutputForm[iml] >>> dispres.m;
          Print["Re(lambda) = ", rel];
          Print["Im(lambda) = ", iml];
Phih = ArcTan[iml/rel];
                         err = Phih - Phi0;
Print["The phase error = ", err];
tayl = Series[err, {xi, 0, kt}];  
tayl = Simplify[tayl];
Print["The expression for the dispersion error"];
Print["E(\kappa,\xi) obtained by the Taylor expansion "];
Print["around the point \xi = 0 has the form"];
Print["E(kappa, xi) = ", tayl];
                  OutputForm[tayl] >>> dispres.m;
err1 = err /. cp2 -> cp20;
gr1=Plot3D[err1, {xi,0, 2 Pi}, {cp1, cpl, cpr},
       AxesLabel -> {"xi", "kappa1", "E"}];
Display["fig3_15a", gr1];
(* ------- End of the procedure disp1ad -------- *)
	  )

:[font = section; inactive; ]
Parameters Used in Program disp1ad.ma
:[font = special4; inactive; nowordwrap; nohscroll; ]

___________________________________________________
 Parameter                               Description  
___________________________________________________
kt                     the number of terms in the Tailor expansion of the
                        phase error err; kt > 1;
cpl                   the left end of the stability interval of the
                       difference scheme under consideration;
cpr                  the right end of the stability interval of the
                       difference scheme under consideration; cpl < cpr;
cp20              the user-specified value of the variable $\kappa_2$
                       for plotting the 3D section of the hypersurface
                       E = E(\kappa_1, \kappa_2,\xi);
sc                   the left-hand side of the difference equation sc = 0.
 _____________________________________________________

:[font = section; inactive; ]
Examples of Difference Schemes

:[font = special4; inactive; nowordwrap; nohscroll; ]
Attention! Only the letter j can be used to denote the number of the grid 
node on the x-axis, and only the letter n can be used to denote the time 
level.

:[font = subsection; inactive; ]
Example 1
:[font = input; startGroup; nowordwrap; ]
ClearAll[sch1];
  sch1 =
(* -- The explicit scheme for advection-diffusion
                                    equation -- *)
 ( ut = (u[j,n+1] - u[j,n])/dt;
            ux = (u[j + 1,n] - u[j - 1,n])/(2*h1);
 uxx = (u[j+1,n] - 2*u[j, n] + u[j - 1, n])/(h1*h1);
                           ut + a*ux - nu*uxx  )
(* ------------ dt is the time step -------------- *)
(* - Transformation rule for the introduction of the
      nondimensional variable cp ----------- *)
 cap={a->cp1*h1/dt, nu -> cp2*h1^2/dt, k -> xi/h1}

:[font = output; inactive; formatted; output; nowordwrap; ]
(-u[j, n] + u[j, 1 + n])/dt + 
  (a*(-u[-1 + j, n] + u[1 + j, n]))/(2*h1) - 
  (nu*(u[-1 + j, n] - 2*u[j, n] + u[1 + j, n]))/h1^2



;[o]
-u[j, n] + u[j, 1 + n]
---------------------- + 
          dt
 
 a (-u[-1 + j, n] + u[1 + j, n])
 ------------------------------- - 
              2 h1
 
 nu (u[-1 + j, n] - 2 u[j, n] + u[1 + j, n])
 -------------------------------------------
                       2
                     h1
:[font = output; inactive; formatted; output; endGroup; nowordwrap; ]
{a -> (cp1*h1)/dt, nu -> (cp2*h1^2)/dt, k -> xi/h1}



;[o]
                          2
      cp1 h1        cp2 h1        xi
{a -> ------, nu -> -------, k -> --}
        dt            dt          h1
:[font = section; inactive; ]
Examples of the Input Data
:[font = subsection; inactive; ]
Example 1
:[font = input; startGroup; nowordwrap; ]

disp1ad[5, -1.0, 1.0, 0.5, sch1]

:[font = print; inactive; formatted; output; nowordwrap; ]
No Input Form Generated


;[o]
The package Algebra`ReIm` is loaded
Determination of omega from the original PDE
omega = k (a - I k nu)
Re(omega) = a k
               2
Im(omega) = -(k  nu)
Phi0 = -ArcTan[Tan[cp1 xi]]
The difference scheme under consideration
-(cp1 u[-1 + j, n])   cp2 u[-1 + j, n]   u[j, n]
------------------- - ---------------- - ------- + 
       2 dt                  dt            dt
 
  2 cp2 u[j, n]   u[j, 1 + n]   cp1 u[1 + j, n]
  ------------- + ----------- + --------------- - 
       dt             dt             2 dt
 
  cp2 u[1 + j, n]
  --------------- = 0
        dt
The amplification factor of scheme has the form
lambda = {1 - 2 cp2 + 2 cp2 Cos[xi] - I cp1 Sin[xi]}
Re(lambda) = 1 - 2 cp2 + 2 cp2 Cos[xi]
Im(lambda) = -(cp1 Sin[xi])
The phase error = -ArcTan[
 
            cp1 Sin[xi]
     -------------------------] + ArcTan[Tan[cp1 xi]]
     1 - 2 cp2 + 2 cp2 Cos[xi]
The expression for the dispersion error
E(\kappa,\xi) obtained by the Taylor expansion 
around the point \xi = 0 has the form
                             2            3
               cp1 (1 + 2 cp1  - 6 cp2) xi
E(kappa, xi) = ---------------------------- + 
                            6
 
             3      5
   -cp1   cp1    cp1    cp1 cp2      3
  (---- - ---- - ---- + ------- + cp1  cp2 - 
   120     6      5        4
 
            2    5        6
     cp1 cp2 ) xi  + O[xi]
:[font = postscript; inactive; output; endGroup; BITMAP; PostScript; pictureLeft = 100; pictureTop = 0; pictureWidth = 300; pictureHeight = 246; nowordwrap; ]
%!
%%Creator: Mathematica
%%AspectRatio: .82055 
MathPictureStart
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0249355 0.99742 -0.0396341 0.99742 [
[(0)] .05113 .25884 1 .93395 Msboxa
[(2)] .23273 .18737 .938 1 Msboxa
[(4)] .42876 .11027 .80527 1 Msboxa
[(6)] .64102 .02686 .67254 1 Msboxa
[(xi)] .30204 .09689 .86223 1 Msboxa
[(-1)] .69093 .02039 -1 .39157 Msboxa
[(-0.5)] .76901 .13994 -1 .36413 Msboxa
[(0)] .83872 .24668 -1 .34028 Msboxa
[(0.5)] .90133 .34257 -1 .31937 Msboxa
[(1)] .95788 .42917 -1 .30087 Msboxa
[(kappa1)] .89773 .2266 -1 .34028 Msboxa
[(-2)] .0431 .30655 1 -0.38472 Msboxa
[(0)] .03155 .37899 1 -0.37036 Msboxa
[(2)] .01941 .45507 1 -0.35519 Msboxa
[(E)] -0.02691 .40064 1 -0.37036 Msboxa
[ 0 0 0 0 ]
[ 1 .82055 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06024 .26735 m
.67932 .02494 L
s
P
p
.002 w
.06024 .26735 m
.0648 .2716 L
s
P
[(0)] .05113 .25884 1 .93395 Mshowa
p
.002 w
.24126 .19647 m
.24553 .20101 L
s
P
[(2)] .23273 .18737 .938 1 Mshowa
p
.002 w
.43658 .11999 m
.44049 .12484 L
s
P
[(4)] .42876 .11027 .80527 1 Mshowa
p
.002 w
.64798 .03721 m
.65146 .04238 L
s
P
[(6)] .64102 .02686 .67254 1 Mshowa
p
.001 w
.09538 .25359 m
.09808 .25618 L
s
P
p
.001 w
.13104 .23963 m
.1337 .24225 L
s
P
p
.001 w
.16723 .22546 m
.16986 .22811 L
s
P
p
.001 w
.20396 .21107 m
.20656 .21376 L
s
P
p
.001 w
.27913 .18164 m
.28165 .1844 L
s
P
p
.001 w
.31758 .16658 m
.32006 .16938 L
s
P
p
.001 w
.35663 .15129 m
.35907 .15413 L
s
P
p
.001 w
.39629 .13576 m
.39869 .13864 L
s
P
p
.001 w
.47752 .10396 m
.47981 .10691 L
s
P
p
.001 w
.5191 .08767 m
.52135 .09066 L
s
P
p
.001 w
.56137 .07112 m
.56356 .07415 L
s
P
p
.001 w
.60432 .05431 m
.60646 .05737 L
s
P
[(xi)] .30204 .09689 .86223 1 Mshowa
P
p
p
.002 w
.67932 .02494 m
.94594 .43277 L
s
P
p
.002 w
.67932 .02494 m
.67352 .02721 L
s
P
[(-1)] .69093 .02039 -1 .39157 Mshowa
p
.002 w
.7573 .14421 m
.75144 .14634 L
s
P
[(-0.5)] .76901 .13994 -1 .36413 Mshowa
p
.002 w
.82692 .2507 m
.82101 .25271 L
s
P
[(0)] .83872 .24668 -1 .34028 Mshowa
p
.002 w
.88945 .34636 m
.88352 .34826 L
s
P
[(0.5)] .90133 .34257 -1 .31937 Mshowa
p
.002 w
.94594 .43277 m
.93997 .43456 L
s
P
[(1)] .95788 .42917 -1 .30087 Mshowa
p
.001 w
.69566 .04992 m
.69217 .05127 L
s
P
p
.001 w
.71161 .07432 m
.70811 .07565 L
s
P
p
.001 w
.72719 .09816 m
.72369 .09947 L
s
P
p
.001 w
.74242 .12145 m
.73891 .12274 L
s
P
p
.001 w
.77184 .16646 m
.76832 .16772 L
s
P
p
.001 w
.78607 .18822 m
.78254 .18947 L
s
P
p
.001 w
.79998 .2095 m
.79645 .21074 L
s
P
p
.001 w
.81359 .23032 m
.81006 .23154 L
s
P
p
.001 w
.83995 .27064 m
.83641 .27183 L
s
P
p
.001 w
.85272 .29017 m
.84917 .29135 L
s
P
p
.001 w
.86522 .30929 m
.86166 .31045 L
s
P
p
.001 w
.87746 .32802 m
.8739 .32917 L
s
P
p
.001 w
.90121 .36434 m
.89764 .36546 L
s
P
p
.001 w
.91272 .38196 m
.90915 .38307 L
s
P
p
.001 w
.92402 .39923 m
.92044 .40033 L
s
P
p
.001 w
.93508 .41616 m
.93151 .41725 L
s
P
[(kappa1)] .89773 .2266 -1 .34028 Mshowa
P
p
p
.002 w
.06024 .26735 m
.02494 .49015 L
s
P
p
.002 w
.05474 .30207 m
.06056 .29983 L
s
P
[(-2)] .0431 .30655 1 -0.38472 Mshowa
p
.002 w
.04324 .37466 m
.04908 .37249 L
s
P
[(0)] .03155 .37899 1 -0.37036 Mshowa
p
.002 w
.03115 .4509 m
.03703 .44881 L
s
P
[(2)] .01941 .45507 1 -0.35519 Mshowa
p
.001 w
.05248 .31631 m
.05598 .31497 L
s
P
p
.001 w
.05021 .33068 m
.0537 .32936 L
s
P
p
.001 w
.04791 .3452 m
.05141 .34388 L
s
P
p
.001 w
.04558 .35986 m
.04909 .35855 L
s
P
p
.001 w
.04087 .38961 m
.04438 .38832 L
s
P
p
.001 w
.03848 .4047 m
.04199 .40342 L
s
P
p
.001 w
.03606 .41995 m
.03958 .41868 L
s
P
p
.001 w
.03362 .43535 m
.03714 .43408 L
s
P
p
.001 w
.05697 .28797 m
.06046 .28662 L
s
P
p
.001 w
.05919 .274 m
.06267 .27264 L
s
P
p
.001 w
.02867 .46661 m
.03219 .46537 L
s
P
p
.001 w
.02615 .48248 m
.02968 .48125 L
s
P
[(E)] -0.02691 .40064 1 -0.37036 Mshowa
P
0 0 m
1 0 L
1 .82055 L
0 .82055 L
closepath
clip
newpath
p
.002 w
.06024 .26735 m
.02494 .49015 L
s
.02494 .49015 m
.40296 .79562 L
s
.40296 .79562 m
.41001 .59401 L
s
.41001 .59401 m
.06024 .26735 L
s
.67932 .02494 m
.94594 .43277 L
s
.94594 .43277 m
.97506 .64585 L
s
.97506 .64585 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.06024 .26735 m
.02494 .49015 L
s
.02494 .49015 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.67932 .02494 m
.06024 .26735 L
s
.41001 .59401 m
.94594 .43277 L
s
.94594 .43277 m
.97506 .64585 L
s
.97506 .64585 m
.40296 .79562 L
s
.40296 .79562 m
.41001 .59401 L
s
P
p
.658 .752 .919 r
.0015 w
.38505 .67298 .40659 .69179 .44251 .68166 .42129 .66235 Metetra
.672 .753 .911 r
.42129 .66235 .44251 .68166 .47894 .67139 .45807 .65026 Metetra
.69 .743 .892 r
.45807 .65026 .47894 .67139 .51588 .66097 .49537 .63599 Metetra
.9 .491 .101 r
.49537 .63599 .51588 .66097 .55336 .65041 .53345 .73169 Metetra
.53345 .73169 .55336 .65041 .59138 .63969 .57134 .60582 Metetra
.663 .65 .827 r
.57134 .60582 .59138 .63969 .62995 .62881 .61008 .59304 Metetra
.653 .637 .822 r
.61008 .59304 .62995 .62881 .66909 .61778 .64942 .5814 Metetra
.653 .636 .821 r
.64942 .5814 .66909 .61778 .7088 .60658 .68933 .5696 Metetra
.661 .638 .817 r
.68933 .5696 .7088 .60658 .74911 .59522 .72975 .55628 Metetra
.671 .636 .806 r
.72975 .55628 .74911 .59522 .79003 .58368 .77059 .54071 Metetra
0 0 .433 r
.77059 .54071 .79003 .58368 .83156 .57197 .82212 .6372 Metetra
.465 .153 .352 r
.82212 .6372 .83156 .57197 .87373 .56008 .86558 .62142 Metetra
0 0 .058 r
.86558 .62142 .87373 .56008 .91654 .54801 .89642 .49376 Metetra
.64 .571 .761 r
.89642 .49376 .91654 .54801 .96002 .53575 .9399 .48079 Metetra
.66 .752 .919 r
.36293 .65367 .38505 .67298 .42129 .66235 .3995 .64263 Metetra
.683 .756 .907 r
.3995 .64263 .42129 .66235 .45807 .65026 .43666 .6291 Metetra
.719 .754 .88 r
.43666 .6291 .45807 .65026 .49537 .63599 .47437 .61086 Metetra
.889 .471 .072 r
.47437 .61086 .49537 .63599 .53345 .73169 .51209 .70078 Metetra
.903 .721 .646 r
.51209 .70078 .53345 .73169 .57134 .60582 .55092 .57081 Metetra
.67 .65 .822 r
.55092 .57081 .57134 .60582 .61008 .59304 .58986 .55652 Metetra
.654 .637 .821 r
.58986 .55652 .61008 .59304 .64942 .5814 .6294 .54438 Metetra
.653 .636 .82 r
.6294 .54438 .64942 .5814 .68933 .5696 .66951 .53205 Metetra
.668 .642 .815 r
.66951 .53205 .68933 .5696 .72975 .55628 .71009 .5172 Metetra
.691 .647 .801 r
.71009 .5172 .72975 .55628 .77059 .54071 .75089 .49756 Metetra
0 0 .471 r
.75089 .49756 .77059 .54071 .82212 .6372 .80149 .58697 Metetra
.675 .606 .77 r
.80149 .58697 .82212 .6372 .86558 .62142 .84468 .56682 Metetra
.649 .58 .764 r
.84468 .56682 .86558 .62142 .89642 .49376 .88891 .55133 Metetra
.458 .127 .316 r
.88891 .55133 .89642 .49376 .9399 .48079 .9341 .53814 Metetra
.66 .752 .918 r
.34022 .63385 .36293 .65367 .3995 .64263 .37712 .62247 Metetra
.689 .759 .905 r
.37712 .62247 .3995 .64263 .43666 .6291 .41466 .608 Metetra
.744 .763 .868 r
.41466 .608 .43666 .6291 .47437 .61086 .45284 .58587 Metetra
.872 .442 .032 r
.45284 .58587 .47437 .61086 .51209 .70078 .49028 .66841 Metetra
.72 .691 .821 r
.49028 .66841 .51209 .70078 .55092 .57081 .53035 .64563 Metetra
.461 .152 .355 r
.53035 .64563 .55092 .57081 .58986 .55652 .57087 .63055 Metetra
.57087 .63055 .58986 .55652 .6294 .54438 .60901 .50668 Metetra
.654 .636 .82 r
.60901 .50668 .6294 .54438 .66951 .53205 .64934 .49392 Metetra
.672 .644 .814 r
.64934 .49392 .66951 .53205 .71009 .5172 .69012 .47803 Metetra
.71 .658 .797 r
.69012 .47803 .71009 .5172 .75089 .49756 .73095 .4545 Metetra
0 0 .519 r
.73095 .4545 .75089 .49756 .80149 .58697 .78054 .53534 Metetra
.69 .611 .763 r
.78054 .53534 .80149 .58697 .84468 .56682 .82351 .51105 Metetra
.651 .58 .761 r
.82351 .51105 .84468 .56682 .88891 .55133 .86772 .49442 Metetra
.637 .57 .762 r
.86772 .49442 .88891 .55133 .9341 .53814 .91294 .48067 Metetra
.66 .752 .918 r
.31689 .61349 .34022 .63385 .37712 .62247 .35413 .60184 Metetra
.689 .759 .905 r
.35413 .60184 .37712 .62247 .41466 .608 .39203 .58702 Metetra
.762 .771 .86 r
.39203 .58702 .41466 .608 .45284 .58587 .43073 .5616 Metetra
.84 .392 0 r
.43073 .5616 .45284 .58587 .49028 .66841 .46802 .63393 Metetra
.732 .687 .807 r
.46802 .63393 .49028 .66841 .53035 .64563 .50843 .60773 Metetra
.669 .648 .82 r
.50843 .60773 .53035 .64563 .57087 .63055 .54918 .59223 Metetra
.649 .639 .827 r
.54918 .59223 .57087 .63055 .60901 .50668 .59056 .57969 Metetra
.464 .147 .343 r
.59056 .57969 .60901 .50668 .64934 .49392 .63258 .56694 Metetra
.63258 .56694 .64934 .49392 .69012 .47803 .66982 .43885 Metetra
.725 .668 .793 r
.66982 .43885 .69012 .47803 .73095 .4545 .71077 .41208 Metetra
0 .012 .587 r
.71077 .41208 .73095 .4545 .78054 .53534 .75924 .48171 Metetra
.699 .611 .755 r
.75924 .48171 .78054 .53534 .82351 .51105 .80208 .45404 Metetra
.651 .577 .759 r
.80208 .45404 .82351 .51105 .86772 .49442 .84634 .43692 Metetra
.637 .569 .762 r
.84634 .43692 .86772 .49442 .91294 .48067 .89159 .42268 Metetra
.659 .752 .919 r
.29291 .59257 .31689 .61349 .35413 .60184 .33049 .5807 Metetra
.683 .759 .908 r
.33049 .5807 .35413 .60184 .39203 .58702 .36874 .56617 Metetra
.77 .777 .859 r
.36874 .56617 .39203 .58702 .43073 .5616 .40795 .53932 Metetra
.764 .281 0 r
.40795 .53932 .43073 .5616 .46802 .63393 .44538 .59599 Metetra
.73 .673 .795 r
.44538 .59599 .46802 .63393 .50843 .60773 .4861 .56836 Metetra
.664 .642 .818 r
.4861 .56836 .50843 .60773 .54918 .59223 .52708 .55312 Metetra
.648 .639 .827 r
.52708 .55312 .54918 .59223 .59056 .57969 .56868 .54025 Metetra
.648 .639 .827 r
.56868 .54025 .59056 .57969 .63258 .56694 .61093 .52717 Metetra
.665 .647 .823 r
.61093 .52717 .63258 .56694 .66982 .43885 .65376 .51129 Metetra
.368 .058 .301 r
.65376 .51129 .66982 .43885 .71077 .41208 .6965 .48247 Metetra
.692 .346 .384 r
.6965 .48247 .71077 .41208 .75924 .48171 .7456 .54127 Metetra
.324 0 .243 r
.7456 .54127 .75924 .48171 .80208 .45404 .79013 .51155 Metetra
.79013 .51155 .80208 .45404 .84634 .43692 .82476 .37884 Metetra
.636 .569 .762 r
.82476 .37884 .84634 .43692 .89159 .42268 .87005 .36416 Metetra
.657 .752 .92 r
.26827 .57106 .29291 .59257 .33049 .5807 .30618 .559 Metetra
.672 .756 .914 r
.30618 .559 .33049 .5807 .36874 .56617 .34474 .54534 Metetra
.749 .781 .879 r
.34474 .54534 .36874 .56617 .40795 .53932 .38429 .5218 Metetra
.46 0 0 r
.38429 .5218 .40795 .53932 .44538 .59599 .42248 .55175 Metetra
.702 .639 .783 r
.42248 .55175 .44538 .59599 .4861 .56836 .46337 .52763 Metetra
.655 .636 .818 r
.46337 .52763 .4861 .56836 .52708 .55312 .50456 .51322 Metetra
.647 .638 .827 r
.50456 .51322 .52708 .55312 .56868 .54025 .54638 .50005 Metetra
.648 .639 .828 r
.54638 .50005 .56868 .54025 .61093 .52717 .58887 .48667 Metetra
.657 .644 .825 r
.58887 .48667 .61093 .52717 .65376 .51129 .632 .47161 Metetra
.715 .675 .81 r
.632 .47161 .65376 .51129 .6965 .48247 .6753 .44627 Metetra
.13 .373 .831 r
.6753 .44627 .6965 .48247 .7456 .54127 .72252 .47642 Metetra
.675 .578 .739 r
.72252 .47642 .7456 .54127 .79013 .51155 .76742 .45041 Metetra
.637 .567 .759 r
.76742 .45041 .79013 .51155 .82476 .37884 .8137 .43445 Metetra
.407 .051 .245 r
.8137 .43445 .82476 .37884 .87005 .36416 .86088 .41975 Metetra
.656 .751 .92 r
.24293 .54895 .26827 .57106 .30618 .559 .28117 .5367 Metetra
.656 .753 .921 r
.28117 .5367 .30618 .559 .34474 .54534 .32001 .52427 Metetra
.655 .767 .932 r
.32001 .52427 .34474 .54534 .38429 .5218 .35946 .51164 Metetra
.614 .87 .991 r
.35946 .51164 .38429 .5218 .42248 .55175 .39953 .49881 Metetra
.634 .578 .775 r
.39953 .49881 .42248 .55175 .46337 .52763 .44024 .48578 Metetra
.645 .629 .82 r
.44024 .48578 .46337 .52763 .50456 .51322 .48161 .47253 Metetra
.646 .637 .827 r
.48161 .47253 .50456 .51322 .54638 .50005 .52365 .45908 Metetra
.646 .638 .828 r
.52365 .45908 .54638 .50005 .58887 .48667 .56637 .4454 Metetra
.647 .639 .829 r
.56637 .4454 .58887 .48667 .632 .47161 .6098 .43149 Metetra
.648 .648 .836 r
.6098 .43149 .632 .47161 .6753 .44627 .65395 .41736 Metetra
.656 .727 .901 r
.65395 .41736 .6753 .44627 .72252 .47642 .69884 .40299 Metetra
.62 .529 .73 r
.69884 .40299 .72252 .47642 .76742 .45041 .74449 .38837 Metetra
.629 .562 .76 r
.74449 .38837 .76742 .45041 .8137 .43445 .79092 .37351 Metetra
.631 .567 .765 r
.79092 .37351 .8137 .43445 .86088 .41975 .83815 .35839 Metetra
.654 .751 .921 r
.21687 .5262 .24293 .54895 .28117 .5367 .25544 .51376 Metetra
.638 .748 .928 r
.25544 .51376 .28117 .5367 .32001 .52427 .29453 .50256 Metetra
.485 .709 .969 r
.29453 .50256 .32001 .52427 .35946 .51164 .33368 .50109 Metetra
.895 .851 .793 r
.33368 .50109 .35946 .51164 .39953 .49881 .37634 .44531 Metetra
.561 .54 .789 r
.37634 .44531 .39953 .49881 .44024 .48578 .41669 .44316 Metetra
.634 .624 .823 r
.41669 .44316 .44024 .48578 .48161 .47253 .45821 .43106 Metetra
.645 .637 .827 r
.45821 .43106 .48161 .47253 .52365 .45908 .50047 .41729 Metetra
.645 .638 .828 r
.50047 .41729 .52365 .45908 .56637 .4454 .54342 .4033 Metetra
.636 .634 .832 r
.54342 .4033 .56637 .4454 .6098 .43149 .58713 .39053 Metetra
.557 .605 .856 r
.58713 .39053 .6098 .43149 .65395 .41736 .63198 .38761 Metetra
.863 .779 .767 r
.63198 .38761 .65395 .41736 .69884 .40299 .67515 .32952 Metetra
.568 .498 .737 r
.67515 .32952 .69884 .40299 .74449 .38837 .72137 .32582 Metetra
.622 .558 .761 r
.72137 .32582 .74449 .38837 .79092 .37351 .76793 .31199 Metetra
.63 .567 .765 r
.76793 .31199 .79092 .37351 .83815 .35839 .8152 .29643 Metetra
.653 .751 .922 r
.19004 .50278 .21687 .5262 .25544 .51376 .22895 .49012 Metetra
.624 .744 .933 r
.22895 .49012 .25544 .51376 .29453 .50256 .26829 .47981 Metetra
.407 .671 .968 r
.26829 .47981 .29453 .50256 .33368 .50109 .30747 .48196 Metetra
.904 .783 .717 r
.30747 .48196 .33368 .50109 .37634 .44531 .35246 .39904 Metetra
.523 .553 .828 r
.35246 .39904 .37634 .44531 .41669 .44316 .39269 .40014 Metetra
.625 .622 .827 r
.39269 .40014 .41669 .44316 .45821 .43106 .43435 .38879 Metetra
.644 .637 .828 r
.43435 .38879 .45821 .43106 .50047 .41729 .47682 .37468 Metetra
.644 .637 .829 r
.47682 .37468 .50047 .41729 .54342 .4033 .52001 .36033 Metetra
.627 .63 .834 r
.52001 .36033 .54342 .4033 .58713 .39053 .56397 .34831 Metetra
.521 .584 .859 r
.56397 .34831 .58713 .39053 .63198 .38761 .60913 .34876 Metetra
.886 .741 .697 r
.60913 .34876 .63198 .38761 .67515 .32952 .65179 .26384 Metetra
.547 .505 .761 r
.65179 .26384 .67515 .32952 .72137 .32582 .69809 .26313 Metetra
0 0 .493 r
.69809 .26313 .72137 .32582 .76793 .31199 .75368 .36764 Metetra
.366 0 .185 r
.75368 .36764 .76793 .31199 .8152 .29643 .803 .35203 Metetra
.652 .75 .922 r
.16241 .47867 .19004 .50278 .22895 .49012 .20167 .46572 Metetra
.616 .741 .935 r
.20167 .46572 .22895 .49012 .26829 .47981 .2413 .4557 Metetra
.436 .678 .965 r
.2413 .4557 .26829 .47981 .30747 .48196 .28081 .45651 Metetra
.902 .754 .689 r
.28081 .45651 .30747 .48196 .35246 .39904 .32785 .3574 Metetra
.525 .583 .855 r
.32785 .3574 .35246 .39904 .39269 .40014 .3682 .35694 Metetra
.621 .623 .832 r
.3682 .35694 .39269 .40014 .43435 .38879 .41002 .34573 Metetra
.644 .637 .828 r
.41002 .34573 .43435 .38879 .47682 .37468 .45271 .33121 Metetra
.644 .637 .829 r
.45271 .33121 .47682 .37468 .52001 .36033 .49613 .31644 Metetra
.771 .376 0 r
.49613 .31644 .52001 .36033 .56397 .34831 .54098 .42306 Metetra
.479 .12 .279 r
.54098 .42306 .56397 .34831 .60913 .34876 .58811 .42348 Metetra
.58811 .42348 .60913 .34876 .65179 .26384 .63266 .31672 Metetra
.445 .046 .188 r
.63266 .31672 .65179 .26384 .69809 .26313 .68072 .31565 Metetra
.363 0 .155 r
.68072 .31565 .69809 .26313 .75368 .36764 .72935 .30305 Metetra
.624 .565 .768 r
.72935 .30305 .75368 .36764 .803 .35203 .7787 .28688 Metetra
.651 .75 .922 r
.13396 .45384 .16241 .47867 .20167 .46572 .17358 .44052 Metetra
.616 .741 .935 r
.17358 .44052 .20167 .46572 .2413 .4557 .21354 .43009 Metetra
.5 .698 .958 r
.21354 .43009 .2413 .4557 .28081 .45651 .25357 .42746 Metetra
.902 .743 .675 r
.25357 .42746 .28081 .45651 .32785 .3574 .30255 .31757 Metetra
.554 .612 .865 r
.30255 .31757 .32785 .3574 .3682 .35694 .3432 .31362 Metetra
.622 .627 .835 r
.3432 .31362 .3682 .35694 .41002 .34573 .3852 .30187 Metetra
.821 .422 0 r
.3852 .30187 .41002 .34573 .45271 .33121 .42432 .40368 Metetra
.377 .017 .221 r
.42432 .40368 .45271 .33121 .49613 .31644 .46968 .38886 Metetra
.398 .036 .23 r
.46968 .38886 .49613 .31644 .54098 .42306 .51586 .37706 Metetra
.546 .596 .855 r
.51586 .37706 .54098 .42306 .58811 .42348 .5631 .37353 Metetra
.899 .719 .651 r
.5631 .37353 .58811 .42348 .63266 .31672 .60829 .25629 Metetra
.562 .541 .789 r
.60829 .25629 .63266 .31672 .68072 .31565 .65616 .25124 Metetra
.608 .557 .771 r
.65616 .25124 .68072 .31565 .72935 .30305 .70478 .23789 Metetra
.624 .566 .768 r
.70478 .23789 .72935 .30305 .7787 .28688 .75416 .22106 Metetra
.652 .75 .922 r
.10464 .42825 .13396 .45384 .17358 .44052 .14462 .41446 Metetra
.624 .742 .932 r
.14462 .41446 .17358 .44052 .21354 .43009 .18501 .40294 Metetra
.562 .716 .944 r
.18501 .40294 .21354 .43009 .25357 .42746 .22567 .39612 Metetra
.903 .737 .666 r
.22567 .39612 .25357 .42746 .30255 .31757 .27659 .27822 Metetra
.899 .503 .079 r
.27659 .27822 .30255 .31757 .3432 .31362 .30954 .38536 Metetra
.376 .008 .205 r
.30954 .38536 .3432 .31362 .3852 .30187 .35336 .37304 Metetra
.356 0 .193 r
.35336 .37304 .3852 .30187 .42432 .40368 .39816 .35786 Metetra
.638 .641 .836 r
.39816 .35786 .42432 .40368 .46968 .38886 .44378 .3424 Metetra
.62 .632 .841 r
.44378 .3424 .46968 .38886 .51586 .37706 .4902 .32929 Metetra
.58 .609 .846 r
.4902 .32929 .51586 .37706 .5631 .37353 .53758 .32108 Metetra
.902 .716 .641 r
.53758 .32108 .5631 .37353 .60829 .25629 .58367 .19655 Metetra
.586 .559 .791 r
.58367 .19655 .60829 .25629 .65616 .25124 .63139 .18691 Metetra
.612 .561 .773 r
.63139 .18691 .65616 .25124 .70478 .23789 .67997 .17216 Metetra
.624 .566 .769 r
.67997 .17216 .70478 .23789 .75416 .22106 .72936 .15458 Metetra
.653 .751 .921 r
.07442 .40187 .10464 .42825 .14462 .41446 .11478 .38749 Metetra
.638 .746 .926 r
.11478 .38749 .14462 .41446 .18501 .40294 .15567 .37429 Metetra
.614 .729 .927 r
.15567 .37429 .18501 .40294 .22567 .39612 .19706 .36307 Metetra
.904 .734 .66 r
.19706 .36307 .22567 .39612 .27659 .27822 .24996 .23872 Metetra
.893 .492 .064 r
.24996 .23872 .27659 .27822 .30954 .38536 .28227 .34113 Metetra
.63 .644 .846 r
.28227 .34113 .30954 .38536 .35336 .37304 .3264 .32696 Metetra
.639 .642 .837 r
.3264 .32696 .35336 .37304 .39816 .35786 .37145 .31104 Metetra
.639 .641 .836 r
.37145 .31104 .39816 .35786 .44378 .3424 .41731 .29484 Metetra
.629 .636 .838 r
.41731 .29484 .44378 .3424 .4902 .32929 .464 .27982 Metetra
.611 .621 .836 r
.464 .27982 .4902 .32929 .53758 .32108 .51159 .2668 Metetra
.905 .714 .635 r
.51159 .2668 .53758 .32108 .58367 .19655 .55874 .13681 Metetra
.611 .575 .79 r
.55874 .13681 .58367 .19655 .63139 .18691 .60638 .12256 Metetra
0 0 .452 r
.60638 .12256 .63139 .18691 .67997 .17216 .66057 .22493 Metetra
.279 0 .071 r
.66057 .22493 .67997 .17216 .72936 .15458 .71218 .20686 Metetra
.656 .751 .92 r
.04324 .37466 .07442 .40187 .11478 .38749 .08401 .35956 Metetra
.656 .749 .919 r
.08401 .35956 .11478 .38749 .15567 .37429 .12549 .3442 Metetra
.655 .737 .91 r
.12549 .3442 .15567 .37429 .19706 .36307 .16769 .32857 Metetra
.652 .709 .889 r
.16769 .32857 .19706 .36307 .24996 .23872 .21064 .31266 Metetra
.319 0 .155 r
.21064 .31266 .24996 .23872 .28227 .34113 .25435 .29647 Metetra
.643 .653 .844 r
.25435 .29647 .28227 .34113 .3264 .32696 .29885 .27999 Metetra
.641 .643 .837 r
.29885 .27999 .3264 .32696 .37145 .31104 .34415 .26321 Metetra
.641 .642 .835 r
.34415 .26321 .37145 .31104 .41731 .29484 .39028 .24613 Metetra
.641 .64 .834 r
.39028 .24613 .41731 .29484 .464 .27982 .43726 .22873 Metetra
.639 .631 .827 r
.43726 .22873 .464 .27982 .51159 .2668 .48512 .211 Metetra
.634 .612 .811 r
.48512 .211 .51159 .2668 .55874 .13681 .53388 .19295 Metetra
.266 0 .065 r
.53388 .19295 .55874 .13681 .60638 .12256 .58356 .17455 Metetra
.249 0 .037 r
.58356 .17455 .60638 .12256 .66057 .22493 .6342 .15579 Metetra
.622 .567 .772 r
.6342 .15579 .66057 .22493 .71218 .20686 .68581 .13668 Metetra
P
p
.002 w
.67932 .02494 m
.94594 .43277 L
s
.94594 .43277 m
.97506 .64585 L
s
.97506 .64585 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.06024 .26735 m
.02494 .49015 L
s
.02494 .49015 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.67932 .02494 m
.06024 .26735 L
s
P
p
p
.002 w
.06024 .26735 m
.67932 .02494 L
s
P
p
.002 w
.06024 .26735 m
.0648 .2716 L
s
P
[(0)] .05113 .25884 1 .93395 Mshowa
p
.002 w
.24126 .19647 m
.24553 .20101 L
s
P
[(2)] .23273 .18737 .938 1 Mshowa
p
.002 w
.43658 .11999 m
.44049 .12484 L
s
P
[(4)] .42876 .11027 .80527 1 Mshowa
p
.002 w
.64798 .03721 m
.65146 .04238 L
s
P
[(6)] .64102 .02686 .67254 1 Mshowa
p
.001 w
.09538 .25359 m
.09808 .25618 L
s
P
p
.001 w
.13104 .23963 m
.1337 .24225 L
s
P
p
.001 w
.16723 .22546 m
.16986 .22811 L
s
P
p
.001 w
.20396 .21107 m
.20656 .21376 L
s
P
p
.001 w
.27913 .18164 m
.28165 .1844 L
s
P
p
.001 w
.31758 .16658 m
.32006 .16938 L
s
P
p
.001 w
.35663 .15129 m
.35907 .15413 L
s
P
p
.001 w
.39629 .13576 m
.39869 .13864 L
s
P
p
.001 w
.47752 .10396 m
.47981 .10691 L
s
P
p
.001 w
.5191 .08767 m
.52135 .09066 L
s
P
p
.001 w
.56137 .07112 m
.56356 .07415 L
s
P
p
.001 w
.60432 .05431 m
.60646 .05737 L
s
P
[(xi)] .30204 .09689 .86223 1 Mshowa
P
% End of Graphics
MathPictureEnd
:[font = section; inactive; ]
The Structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]

The following data are printed out in the process of the work of the program:

1. The symbolic expression for the wave frequency omega corresponding to
     the original PDE;

2. The exact phase shift Phi0 during the time dt (see equation (3.8.6)) comp-
     uted from the original PDE;

3. The difference scheme under consideration;

4. The symbolic expression for the amplification factor lambda for a given
     difference scheme;

5. The real part rel = Re(lambda) and iml = Im(lambda) of the amplification
     factor lambda;

6. The expression for the phase error  (3.8.9) of a given difference scheme;

7. The expression for the dispersion error E(kappa, xi) obtained by the Tay-
     lor expansion around the point xi = 0;

8. The surface E = E(kappa1, kappa20, xi).   

^*)