(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
Dispersion
:[font = subtitle; inactive; nohscroll; center; ]

(Advection-Diffusion Equation)
:[font = name; inactive; nohscroll; ]

                                   Victor G. Ganzha and Evgenii V. Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

This Mathematica-Notebook is part of the book entitled
                                  V.G.Ganzha and E.V.Vorozhtsov
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]

Numerical Solutions For Partial Differential Equations: Problem Solving
Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = section; inactive; ]
Initialisation
:[font = special4; inactive; nowordwrap; nohscroll; ]

Needs[Algebra`ReIm`]
:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The program disp1adc.ma which follows below performs the dispersion 
analysis of scalar implicit two-level difference schemes approximating 
the  one-dimensional  advection-diffusion  equation. The description of
the algorithm for dispersion analysis can be found in Section 3.8 of the 
above book.
:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = special4; inactive; nowordwrap; nohscroll; ]

Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]

ClearAll[disp1ad, a, cp1, cp2, nu, k, omega];

:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the form of a difference scheme by modifying the body of the
function sch1 or sch2, see below Section "Examples of Difference
Schemes".
:[font = subsection; inactive; ]
Step 3
:[font = special4; inactive; nowordwrap; nohscroll; ]
Specify the form of the nondimensional variable kappa in terms of which 
the stability region is to be determined. The corresponding transformati-
on rule should follow the expression for the difference scheme (see exa-
mples below) and should  be in  the same cell as the difference scheme 
itself. Load and compile  the difference scheme together with the transf-
ormation rule.

:[font = subsection; inactive; ]
Step 4
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the input data by entering them in the line (see Section
"Examples of the Input Data"):
:[font = input; nowordwrap; ]

disp1[5, -1.0, 1.0, 0.5, sch1];
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line and wait for the result of symbolic computation. The
meaning of the input parameters is explained in the Section
"Parameters Used in Program disp1ad.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; ]

ClearAll[disp1ad, a, cp1, cp2, nu, k, omega];
disp1ad[kt_, cpl_, cpr_, cp20_, sc_] := 
(
<< Algebra`ReIm`;
Print["The package Algebra`ReIm` is loaded"];
(* --- The variables xi, cp, dt, a, k are declared
                            to be real --------- *)
xi/: Im[xi] = 0;
cp/: Im[cp] = 0;
cp1/: Im[cp1] = 0;
cp2/: Im[cp2] = 0;
dt/: Im[dt] = 0;
a/: Im[a] = 0;
nu/: Im[nu] = 0;
k/: Im[k] = 0;
Print["Determination of omega from the original PDE"];
(* ---- Substitution of a Fourier harmonic into
	the partial differential equation ------ *)
dif1 = D[Exp[I*k*x - I*omega*t], t] +
               a*D[Exp[I*k*x - I*omega*t], x] -
nu*D[Exp[I*k*x - I*omega*t], {x, 2}];
OutputForm[dif1] >> dispres.m;

(* ---- Divide the both sides of obtained equation
           by Exp[I*(k*x - omega*t)] ----------- *)
dif2 = dif1/Exp[I*(k*x - omega*t)]; 
dif3 = Simplify[dif2];
OutputForm[dif3] >>> dispres.m;
sol0 = Solve[dif3==0, omega];
omega0 = omega /. sol0; omega=omega0[[1]]//Simplify;
Print["omega = ", omega];
  OutputForm[omega] >>> dispres.m;
reom = Re[omega];  imom = Im[omega];
Print["Re(omega) = ", reom];
Print["Im(omega) = ", imom];
(* -- Calculation of the expression for the step 
  operator corresponding to the original PDE --- *)
S0 = Exp[I*(k*x-reom*(t+dt))]/Exp[I*(k*x-reom*t)];
S0 = Simplify[S0];
OutputForm[S0] >>> dispres.m;
ims0 = Im[S0];   res0 = Re[S0];
    OutputForm[ims0] >>> dispres.m;
           OutputForm[res0] >>> dispres.m;
Phi0 = ArcTan[ims0/res0];  Phi0 = Simplify[Phi0];
Phi0 = Phi0 /. cap;  Phi0 = Simplify[Phi0];
Print["Phi0 = ", Phi0];
     OutputForm[Phi0] >>> dispres.m;

(* ---- Substitution of a Fourier harmonic into
        the difference scheme ------------------ *)
  sc0 = Expand[sc]/. cap;     
Print["The difference scheme under consideration"];
Print[sc0, " = 0"];
  sc0 >>> dispres.m;
  sc1 = sc0 /. {u[j_, n_] -> l^n*Exp[I*j*xi]};
(* -- Divide the both sides of obtained equation
           by l^n Exp[I*j*xi] ------------------ *)
      sc3 = sc1*l^(-n) //Expand //Simplify;
  sc2 = Simplify[sc3 /. j -> 0]; 
sc4 = ComplexExpand[sc2];
sol = Solve[sc4==0, l];
l1 = Expand[l /. sol] ; l4 = Simplify[l1];                 
Print["The amplification factor of scheme has",
      " the form"];
Print["lambda = ", l4];
OutputForm[l4] >>> dispres.m;
l = l4[[1]]; lnum = Numerator[l];
OutputForm[lnum] >>> dispres.m;
lden = Denominator[l]; imd = Im[lden];
OutputForm[lden] >>> dispres.m;
OutputForm[imd] >>> dispres.m;
If[lden == 1, iml = Im[l]; rel = l - I*iml];
If[lden =!= 1 && imd == 0,
imn = Im[lnum]; reln = lnum - I*imn;
imn = Simplify[imn]; reln = Simplify[reln];
iml = imn/lden; rel = reln/lden];
(* ---- The complex denominator ---- *)
If[lden =!= 1 && imd =!= 0, reld = lden - I*imd;
ldenq = reld*reld + imd*imd;
imn = Im[lnum]; reln = lnum - I*imn;
imn = Simplify[imn]; reln = Simplify[reln];
rel = (reln*reld + imn*imd)/ldenq;
iml = (imn*reld - reln*imd)/ldenq];
rel = Simplify[rel]; iml = Simplify[iml];
OutputForm[rel] >>> dispres.m;
OutputForm[iml] >>> dispres.m;
          Print["Re(lambda) = ", rel];
          Print["Im(lambda) = ", iml];
Phih = ArcTan[iml/rel];
                         err = Phih - Phi0;
Print["The phase error = ", err];
tayl = Series[err, {xi, 0, kt}];  
tayl = Simplify[tayl];
Print["The expression for the dispersion error"];
Print["E(\kappa,\xi) obtained by the Taylor expansion "];
Print["around the point \xi = 0 has the form"];
Print["E(kappa, xi) = ", tayl];
                  OutputForm[tayl] >>> dispres.m;
err1 = err /. cp2 -> cp20;
gr1=Plot3D[err1, {xi,0, 2 Pi}, {cp1, cpl, cpr},
       AxesLabel -> {"xi", "kappa1", "E"}];
Display["fig3_15a", gr1];
(* ------- End of the procedure disp1ad -------- *)
	  )

:[font = section; inactive; ]
Parameters Used in Program disp1ad.ma
:[font = special4; inactive; nowordwrap; nohscroll; ]

___________________________________________________
 Parameter                               Description  
___________________________________________________
kt                     the number of terms in the Tailor expansion of the
                        phase error err; kt > 1;
cpl                   the left end of the stability interval of the
                       difference scheme under consideration;
cpr                  the right end of the stability interval of the
                       difference scheme under consideration; cpl < cpr;
cp20              the user-specified value of the variable $\kappa_2$
                       for plotting the 3D section of the hypersurface
                       E = E(\kappa_1, \kappa_2,\xi);
sc                   the left-hand side of the difference equation sc = 0.
 _____________________________________________________

:[font = section; inactive; ]
Examples of Difference Schemes

:[font = special4; inactive; nowordwrap; nohscroll; ]
Attention! Only the letter j can be used to denote the number of the grid 
node on the x-axis, and only the letter n can be used to denote the time 
level.

:[font = subsection; inactive; ]
Example 1
:[font = input; nowordwrap; ]

(* -- Crank-Nicolson scheme for advection-diffusion
      equation --------------------------------- *)
ClearAll[sch1];
sch1 =
( ut = (u[j,n+1] - u[j,n])/dt;
   uxn = (u[j+1,n] - u[j-1,n])/(2*h1);
uximp = (u[j+1,n+1] - u[j-1,n+1])/(2*h1);
uxx = (u[j+1,n] - 2*u[j,n] + u[j-1,n])/(h1*h1);
uxximp = (u[j+1,n+1]-2*u[j,n+1]+u[j-1,n+1])/(h1*h1);
4*dt*(ut + a*(uxn+uximp)/2 - nu*(uxx + uxximp)/2) )
(* ------------ dt is the time step -------------- *)
 cap={a->cp1*h1/dt, nu -> cp2*h1^2/dt, k -> xi/h1}

:[font = output; inactive; formatted; output; nowordwrap; ]
4*dt*((-u[j, n] + u[j, 1 + n])/dt + 
    (a*((-u[-1 + j, n] + u[1 + j, n])/(2*h1) + 
         (-u[-1 + j, 1 + n] + u[1 + j, 1 + n])/
          (2*h1)))/2 - 
    (nu*((u[-1 + j, n] - 2*u[j, n] + u[1 + j, n])/
          h1^2 + (u[-1 + j, 1 + n] - 
            2*u[j, 1 + n] + u[1 + j, 1 + n])/h1^2))/2
    )




;[o]
      -u[j, n] + u[j, 1 + n]
4 dt (---------------------- + 
                dt
 
   (a ((-u[-1 + j, n] + u[1 + j, n]) / (2 h1) + 
 
        (-u[-1 + j, 1 + n] + u[1 + j, 1 + n]) / 
 
         (2 h1))) / 2 - 
 
   (nu ((u[-1 + j, n] - 2 u[j, n] + u[1 + j, n]) / 
 
           2
         h1  + (u[-1 + j, 1 + n] - 2 u[j, 1 + n] + 
 
                                2
           u[1 + j, 1 + n]) / h1 )) / 2)
:[font = output; inactive; formatted; output; nowordwrap; ]
{a -> (cp1*h1)/dt, nu -> (cp2*h1^2)/dt, k -> xi/h1}




;[o]
                          2
      cp1 h1        cp2 h1        xi
{a -> ------, nu -> -------, k -> --}
        dt            dt          h1
:[font = section; inactive; ]
Examples of the Input Data
:[font = subsection; inactive; ]
Example 1
:[font = input; nowordwrap; ]

disp1ad[5, -1.0, 1.0, 0.49999, sch1]

:[font = print; inactive; formatted; output; nowordwrap; ]
No Input Form Generated



;[o]
The package Algebra`ReIm` is loaded
Determination of omega from the original PDE
omega = k (a - I k nu)
Re(omega) = a k
               2
Im(omega) = -(k  nu)
Phi0 = -ArcTan[Tan[cp1 xi]]
The difference scheme under consideration
-(cp1 u[-1 + j, n]) - 2 cp2 u[-1 + j, n] - 
 
  cp1 u[-1 + j, 1 + n] - 2 cp2 u[-1 + j, 1 + n] - 
 
  4 u[j, n] + 4 cp2 u[j, n] + 4 u[j, 1 + n] + 
 
  4 cp2 u[j, 1 + n] + cp1 u[1 + j, n] - 
 
  2 cp2 u[1 + j, n] + cp1 u[1 + j, 1 + n] - 
 
  2 cp2 u[1 + j, 1 + n] = 0
The amplification factor of scheme has the form
          2 - 2 cp2 + 2 cp2 Cos[xi] - I cp1 Sin[xi]
lambda = {-----------------------------------------}
          2 + 2 cp2 - 2 cp2 Cos[xi] + I cp1 Sin[xi]
                       2        2
Re(lambda) = (4 - 6 cp2  + 8 cp2  Cos[xi] - 
 
         2                2        2
    2 cp2  Cos[2 xi] - cp1  Sin[xi] ) / 
 
                            2      2        2
  (4 (1 + cp2 - cp2 Cos[xi])  + cp1  Sin[xi] )
Im(lambda) = 
 
                -4 cp1 Sin[xi]
  ------------------------------------------
                           2      2        2
  4 (1 + cp2 - cp2 Cos[xi])  + cp1  Sin[xi]
The phase error = -ArcTan[(4 cp1 Sin[xi]) / 
 
               2        2
     (4 - 6 cp2  + 8 cp2  Cos[xi] - 
 
            2                2        2
       2 cp2  Cos[2 xi] - cp1  Sin[xi] )] + 
 
  ArcTan[Tan[cp1 xi]]
The expression for the dispersion error
E(\kappa,\xi) obtained by the Taylor expansion 
around the point \xi = 0 has the form
                         3
                cp1   cp1     3
E(kappa, xi) = (--- + ----) xi  - 
                 6     12
 
                 2        4         2    5
  cp1 (2 + 10 cp1  + 3 cp1  + 60 cp2 ) xi         6
  ---------------------------------------- + O[xi]
                    240
:[font = postscript; inactive; output; BITMAP; PostScript; pictureLeft = 100; pictureTop = 0; pictureWidth = 300; pictureHeight = 246; nowordwrap; ]
%!
%%Creator: Mathematica
%%AspectRatio: .82055 
MathPictureStart
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0249355 0.99742 -0.0396341 0.99742 [
[(0)] .05113 .25884 1 .93395 Msboxa
[(2)] .23273 .18737 .938 1 Msboxa
[(4)] .42876 .11027 .80527 1 Msboxa
[(6)] .64102 .02686 .67254 1 Msboxa
[(xi)] .30204 .09689 .86223 1 Msboxa
[(-1)] .69093 .02039 -1 .39157 Msboxa
[(-0.5)] .76901 .13994 -1 .36413 Msboxa
[(0)] .83872 .24668 -1 .34028 Msboxa
[(0.5)] .90133 .34257 -1 .31937 Msboxa
[(1)] .95788 .42917 -1 .30087 Msboxa
[(kappa1)] .89773 .2266 -1 .34028 Msboxa
[(-2)] .04386 .30178 1 -0.38566 Msboxa
[(0)] .03155 .37899 1 -0.37036 Msboxa
[(2)] .01857 .46034 1 -0.35414 Msboxa
[(E)] -0.02691 .40064 1 -0.37036 Msboxa
[ 0 0 0 0 ]
[ 1 .82055 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06024 .26735 m
.67932 .02494 L
s
P
p
.002 w
.06024 .26735 m
.0648 .2716 L
s
P
[(0)] .05113 .25884 1 .93395 Mshowa
p
.002 w
.24126 .19647 m
.24553 .20101 L
s
P
[(2)] .23273 .18737 .938 1 Mshowa
p
.002 w
.43658 .11999 m
.44049 .12484 L
s
P
[(4)] .42876 .11027 .80527 1 Mshowa
p
.002 w
.64798 .03721 m
.65146 .04238 L
s
P
[(6)] .64102 .02686 .67254 1 Mshowa
p
.001 w
.09538 .25359 m
.09808 .25618 L
s
P
p
.001 w
.13104 .23963 m
.1337 .24225 L
s
P
p
.001 w
.16723 .22546 m
.16986 .22811 L
s
P
p
.001 w
.20396 .21107 m
.20656 .21376 L
s
P
p
.001 w
.27913 .18164 m
.28165 .1844 L
s
P
p
.001 w
.31758 .16658 m
.32006 .16938 L
s
P
p
.001 w
.35663 .15129 m
.35907 .15413 L
s
P
p
.001 w
.39629 .13576 m
.39869 .13864 L
s
P
p
.001 w
.47752 .10396 m
.47981 .10691 L
s
P
p
.001 w
.5191 .08767 m
.52135 .09066 L
s
P
p
.001 w
.56137 .07112 m
.56356 .07415 L
s
P
p
.001 w
.60432 .05431 m
.60646 .05737 L
s
P
[(xi)] .30204 .09689 .86223 1 Mshowa
P
p
p
.002 w
.67932 .02494 m
.94594 .43277 L
s
P
p
.002 w
.67932 .02494 m
.67352 .02721 L
s
P
[(-1)] .69093 .02039 -1 .39157 Mshowa
p
.002 w
.7573 .14421 m
.75144 .14634 L
s
P
[(-0.5)] .76901 .13994 -1 .36413 Mshowa
p
.002 w
.82692 .2507 m
.82101 .25271 L
s
P
[(0)] .83872 .24668 -1 .34028 Mshowa
p
.002 w
.88945 .34636 m
.88352 .34826 L
s
P
[(0.5)] .90133 .34257 -1 .31937 Mshowa
p
.002 w
.94594 .43277 m
.93997 .43456 L
s
P
[(1)] .95788 .42917 -1 .30087 Mshowa
p
.001 w
.69566 .04992 m
.69217 .05127 L
s
P
p
.001 w
.71161 .07432 m
.70811 .07565 L
s
P
p
.001 w
.72719 .09816 m
.72369 .09947 L
s
P
p
.001 w
.74242 .12145 m
.73891 .12274 L
s
P
p
.001 w
.77184 .16646 m
.76832 .16772 L
s
P
p
.001 w
.78607 .18822 m
.78254 .18947 L
s
P
p
.001 w
.79998 .2095 m
.79645 .21074 L
s
P
p
.001 w
.81359 .23032 m
.81006 .23154 L
s
P
p
.001 w
.83995 .27064 m
.83641 .27183 L
s
P
p
.001 w
.85272 .29017 m
.84917 .29135 L
s
P
p
.001 w
.86522 .30929 m
.86166 .31045 L
s
P
p
.001 w
.87746 .32802 m
.8739 .32917 L
s
P
p
.001 w
.90121 .36434 m
.89764 .36546 L
s
P
p
.001 w
.91272 .38196 m
.90915 .38307 L
s
P
p
.001 w
.92402 .39923 m
.92044 .40033 L
s
P
p
.001 w
.93508 .41616 m
.93151 .41725 L
s
P
[(kappa1)] .89773 .2266 -1 .34028 Mshowa
P
p
p
.002 w
.06024 .26735 m
.02494 .49015 L
s
P
p
.002 w
.0555 .2973 m
.06131 .29505 L
s
P
[(-2)] .04386 .30178 1 -0.38566 Mshowa
p
.002 w
.04324 .37466 m
.04908 .37249 L
s
P
[(0)] .03155 .37899 1 -0.37036 Mshowa
p
.002 w
.03032 .45618 m
.03619 .4541 L
s
P
[(2)] .01857 .46034 1 -0.35414 Mshowa
p
.001 w
.05309 .31245 m
.05659 .31112 L
s
P
p
.001 w
.05067 .32776 m
.05417 .32644 L
s
P
p
.001 w
.04822 .34323 m
.05172 .34192 L
s
P
p
.001 w
.04574 .35886 m
.04924 .35756 L
s
P
p
.001 w
.04071 .39062 m
.04422 .38933 L
s
P
p
.001 w
.03815 .40675 m
.04167 .40547 L
s
P
p
.001 w
.03557 .42305 m
.03909 .42178 L
s
P
p
.001 w
.03296 .43953 m
.03648 .43827 L
s
P
p
.001 w
.05787 .2823 m
.06136 .28094 L
s
P
p
.001 w
.06023 .26745 m
.06371 .26608 L
s
P
p
.001 w
.02765 .47302 m
.03118 .47178 L
s
P
p
.001 w
.02495 .49003 m
.02849 .4888 L
s
P
[(E)] -0.02691 .40064 1 -0.37036 Mshowa
P
0 0 m
1 0 L
1 .82055 L
0 .82055 L
closepath
clip
newpath
p
.002 w
.06024 .26735 m
.02494 .49015 L
s
.02494 .49015 m
.40296 .79562 L
s
.40296 .79562 m
.41001 .59401 L
s
.41001 .59401 m
.06024 .26735 L
s
.67932 .02494 m
.94594 .43277 L
s
.94594 .43277 m
.97506 .64585 L
s
.97506 .64585 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.06024 .26735 m
.02494 .49015 L
s
.02494 .49015 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.67932 .02494 m
.06024 .26735 L
s
.41001 .59401 m
.94594 .43277 L
s
.94594 .43277 m
.97506 .64585 L
s
.97506 .64585 m
.40296 .79562 L
s
.40296 .79562 m
.41001 .59401 L
s
P
p
.649 .75 .923 r
.0015 w
.38505 .67298 .40659 .69179 .44249 .6824 .42126 .66317 Metetra
.618 .739 .933 r
.42126 .66317 .44249 .6824 .47887 .67614 .45796 .65581 Metetra
.586 .72 .936 r
.45796 .65581 .47887 .67614 .51585 .67322 .49524 .65098 Metetra
.571 .698 .927 r
.49524 .65098 .51585 .67322 .55255 .56028 .5332 .64763 Metetra
0 0 .081 r
.5332 .64763 .55255 .56028 .58974 .55985 .57025 .53111 Metetra
.591 .648 .875 r
.57025 .53111 .58974 .55985 .62773 .56014 .60834 .52737 Metetra
0 .014 .582 r
.60834 .52737 .62773 .56014 .66909 .61778 .64938 .58036 Metetra
0 .067 .63 r
.64938 .58036 .66909 .61778 .7129 .67884 .69276 .63637 Metetra
.591 .583 .812 r
.69276 .63637 .7129 .67884 .75503 .68051 .73471 .63347 Metetra
.592 .567 .795 r
.73471 .63347 .75503 .68051 .79806 .68141 .77752 .63039 Metetra
.597 .557 .781 r
.77752 .63039 .79806 .68141 .83036 .55942 .82116 .62659 Metetra
.513 .198 .369 r
.82116 .62659 .83036 .55942 .87319 .55516 .86554 .62102 Metetra
0 0 .094 r
.86554 .62102 .87319 .55516 .91645 .54723 .89607 .4908 Metetra
.634 .562 .755 r
.89607 .4908 .91645 .54723 .96002 .53575 .93962 .47866 Metetra
.651 .75 .922 r
.36293 .65367 .38505 .67298 .42126 .66317 .39947 .64346 Metetra
.628 .742 .93 r
.39947 .64346 .42126 .66317 .45796 .65581 .4365 .63508 Metetra
.605 .728 .932 r
.4365 .63508 .45796 .65581 .49524 .65098 .4741 .62852 Metetra
.599 .711 .923 r
.4741 .62852 .49524 .65098 .5332 .64763 .51236 .62265 Metetra
.911 .735 .652 r
.51236 .62265 .5332 .64763 .57025 .53111 .55034 .50239 Metetra
.628 .668 .869 r
.55034 .50239 .57025 .53111 .60834 .52737 .58858 .49444 Metetra
0 .078 .636 r
.58858 .49444 .60834 .52737 .64938 .58036 .62933 .54229 Metetra
0 .129 .678 r
.62933 .54229 .64938 .58036 .69276 .63637 .67229 .59276 Metetra
.618 .595 .804 r
.67229 .59276 .69276 .63637 .73471 .63347 .71408 .58511 Metetra
.612 .575 .788 r
.71408 .58511 .73471 .63347 .77752 .63039 .75671 .57821 Metetra
.609 .562 .777 r
.75671 .57821 .77752 .63039 .82116 .62659 .80016 .57148 Metetra
.613 .557 .768 r
.80016 .57148 .82116 .62659 .86554 .62102 .84437 .56376 Metetra
.622 .558 .761 r
.84437 .56376 .86554 .62102 .89607 .4908 .88919 .55382 Metetra
.472 .15 .338 r
.88919 .55382 .89607 .4908 .93962 .47866 .93453 .54153 Metetra
.652 .75 .922 r
.34022 .63385 .36293 .65367 .39947 .64346 .37709 .62323 Metetra
.635 .745 .927 r
.37709 .62323 .39947 .64346 .4365 .63508 .41446 .61394 Metetra
.62 .734 .928 r
.41446 .61394 .4365 .63508 .4741 .62852 .4524 .60584 Metetra
.621 .722 .919 r
.4524 .60584 .4741 .62852 .51236 .62265 .49099 .59774 Metetra
.636 .711 .901 r
.49099 .59774 .51236 .62265 .55034 .50239 .53023 .58827 Metetra
.49 .194 .39 r
.53023 .58827 .55034 .50239 .58858 .49444 .57009 .57633 Metetra
.093 0 .236 r
.57009 .57633 .58858 .49444 .62933 .54229 .60893 .50356 Metetra
0 .202 .727 r
.60893 .50356 .62933 .54229 .67229 .59276 .65149 .54767 Metetra
.644 .604 .794 r
.65149 .54767 .67229 .59276 .71408 .58511 .69316 .53516 Metetra
.628 .58 .781 r
.69316 .53516 .71408 .58511 .75671 .57821 .73563 .52479 Metetra
.62 .566 .772 r
.73563 .52479 .75671 .57821 .80016 .57148 .77894 .51551 Metetra
.619 .56 .766 r
.77894 .51551 .80016 .57148 .84437 .56376 .82302 .50591 Metetra
.625 .559 .76 r
.82302 .50591 .84437 .56376 .88919 .55382 .86776 .49473 Metetra
.632 .561 .757 r
.86776 .49473 .88919 .55382 .93453 .54153 .91308 .48178 Metetra
.653 .751 .921 r
.31689 .61349 .34022 .63385 .37709 .62323 .35409 .60247 Metetra
.642 .747 .925 r
.35409 .60247 .37709 .62323 .41446 .61394 .39182 .59233 Metetra
.633 .739 .925 r
.39182 .59233 .41446 .61394 .4524 .60584 .43012 .58289 Metetra
.637 .731 .916 r
.43012 .58289 .4524 .60584 .49099 .59774 .46906 .57297 Metetra
.658 .724 .898 r
.46906 .57297 .49099 .59774 .53023 .58827 .50864 .56084 Metetra
.691 .717 .869 r
.50864 .56084 .53023 .58827 .57009 .57633 .54881 .54427 Metetra
0 .193 .723 r
.54881 .54427 .57009 .57633 .60893 .50356 .59063 .58303 Metetra
.65 .327 .413 r
.59063 .58303 .60893 .50356 .65149 .54767 .63449 .62368 Metetra
.63449 .62368 .65149 .54767 .69316 .53516 .67192 .48325 Metetra
.639 .581 .773 r
.67192 .48325 .69316 .53516 .73563 .52479 .7143 .47006 Metetra
.627 .567 .768 r
.7143 .47006 .73563 .52479 .77894 .51551 .75751 .4587 Metetra
.624 .561 .763 r
.75751 .4587 .77894 .51551 .82302 .50591 .80149 .44748 Metetra
.628 .56 .759 r
.80149 .44748 .82302 .50591 .86776 .49473 .84616 .43518 Metetra
.632 .561 .757 r
.84616 .43518 .86776 .49473 .91308 .48178 .89146 .42158 Metetra
.654 .751 .921 r
.29291 .59257 .31689 .61349 .35409 .60247 .33046 .58115 Metetra
.647 .748 .923 r
.33046 .58115 .35409 .60247 .39182 .59233 .36855 .57022 Metetra
.642 .743 .922 r
.36855 .57022 .39182 .59233 .43012 .58289 .40722 .5596 Metetra
.648 .737 .914 r
.40722 .5596 .43012 .58289 .46906 .57297 .44653 .54833 Metetra
.67 .734 .899 r
.44653 .54833 .46906 .57297 .50864 .56084 .48649 .53458 Metetra
.716 .738 .868 r
.48649 .53458 .50864 .56084 .54881 .54427 .52704 .51435 Metetra
.006 .335 .818 r
.52704 .51435 .54881 .54427 .59063 .58303 .56871 .54247 Metetra
.178 .371 .817 r
.56871 .54247 .59063 .58303 .63449 .62368 .61216 .57179 Metetra
.674 .606 .771 r
.61216 .57179 .63449 .62368 .67192 .48325 .65538 .55079 Metetra
.438 .108 .307 r
.65538 .55079 .67192 .48325 .7143 .47006 .69946 .5362 Metetra
.449 .115 .306 r
.69946 .5362 .7143 .47006 .75751 .4587 .74439 .52383 Metetra
.45 .114 .303 r
.74439 .52383 .75751 .4587 .80149 .44748 .79015 .51177 Metetra
.79015 .51177 .80149 .44748 .84616 .43518 .82439 .37516 Metetra
.633 .561 .757 r
.82439 .37516 .84616 .43518 .89146 .42158 .86968 .36092 Metetra
.655 .751 .921 r
.26827 .57106 .29291 .59257 .33046 .58115 .30616 .55924 Metetra
.652 .75 .921 r
.30616 .55924 .33046 .58115 .36855 .57022 .34462 .54755 Metetra
.65 .745 .919 r
.34462 .54755 .36855 .57022 .40722 .5596 .38367 .5359 Metetra
.653 .74 .913 r
.38367 .5359 .40722 .5596 .44653 .54833 .42336 .52371 Metetra
.668 .74 .904 r
.42336 .52371 .44653 .54833 .48649 .53458 .46371 .50973 Metetra
.717 .754 .882 r
.46371 .50973 .48649 .53458 .52704 .51435 .5047 .48953 Metetra
.272 .56 .932 r
.5047 .48953 .52704 .51435 .56871 .54247 .54639 .50116 Metetra
.417 .515 .851 r
.54639 .50116 .56871 .54247 .61216 .57179 .58942 .51317 Metetra
.664 .583 .754 r
.58942 .51317 .61216 .57179 .65538 .55079 .63271 .49221 Metetra
.637 .57 .762 r
.63271 .49221 .65538 .55079 .69946 .5362 .67681 .47725 Metetra
.629 .566 .764 r
.67681 .47725 .69946 .5362 .74439 .52383 .72172 .46373 Metetra
.627 .563 .763 r
.72172 .46373 .74439 .52383 .79015 .51177 .76742 .45034 Metetra
.627 .561 .761 r
.76742 .45034 .79015 .51177 .82439 .37516 .81389 .43649 Metetra
.423 .078 .272 r
.81389 .43649 .82439 .37516 .86968 .36092 .86113 .42205 Metetra
.656 .751 .92 r
.24293 .54895 .26827 .57106 .30616 .55924 .28117 .5367 Metetra
.656 .751 .92 r
.28117 .5367 .30616 .55924 .34462 .54755 .32001 .52427 Metetra
.656 .747 .917 r
.32001 .52427 .34462 .54755 .38367 .5359 .35946 .51164 Metetra
.656 .742 .913 r
.35946 .51164 .38367 .5359 .42336 .52371 .39953 .49881 Metetra
.656 .74 .911 r
.39953 .49881 .42336 .52371 .46371 .50973 .44024 .48578 Metetra
.656 .751 .92 r
.44024 .48578 .46371 .50973 .5047 .48953 .48161 .47253 Metetra
.645 .818 .966 r
.48161 .47253 .5047 .48953 .54639 .50116 .52365 .45908 Metetra
.645 .633 .823 r
.52365 .45908 .54639 .50116 .58942 .51317 .56637 .4454 Metetra
.623 .539 .739 r
.56637 .4454 .58942 .51317 .63271 .49221 .6098 .43149 Metetra
.629 .561 .759 r
.6098 .43149 .63271 .49221 .67681 .47725 .65395 .41736 Metetra
.63 .565 .763 r
.65395 .41736 .67681 .47725 .72172 .46373 .69884 .40299 Metetra
.63 .564 .762 r
.69884 .40299 .72172 .46373 .76742 .45034 .74449 .38837 Metetra
.629 .562 .76 r
.74449 .38837 .76742 .45034 .81389 .43649 .79092 .37351 Metetra
.629 .561 .759 r
.79092 .37351 .81389 .43649 .86113 .42205 .83815 .35839 Metetra
.657 .752 .92 r
.21687 .5262 .24293 .54895 .28117 .5367 .25546 .51352 Metetra
.66 .752 .918 r
.25546 .51352 .28117 .5367 .32001 .52427 .29469 .50032 Metetra
.662 .749 .915 r
.29469 .50032 .32001 .52427 .35946 .51164 .33455 .48669 Metetra
.659 .743 .912 r
.33455 .48669 .35946 .51164 .39953 .49881 .37501 .47319 Metetra
.643 .736 .916 r
.37501 .47319 .39953 .49881 .44024 .48578 .41607 .46111 Metetra
.569 .721 .945 r
.41607 .46111 .44024 .48578 .48161 .47253 .4577 .45495 Metetra
.833 .84 .853 r
.4577 .45495 .48161 .47253 .52365 .45908 .50047 .4162 Metetra
.763 .681 .771 r
.50047 .4162 .52365 .45908 .56637 .4454 .54326 .37743 Metetra
.588 .518 .744 r
.54326 .37743 .56637 .4454 .6098 .43149 .58671 .37031 Metetra
.622 .557 .76 r
.58671 .37031 .6098 .43149 .65395 .41736 .63089 .35695 Metetra
.632 .566 .762 r
.63089 .35695 .65395 .41736 .69884 .40299 .67577 .34172 Metetra
.633 .566 .761 r
.67577 .34172 .69884 .40299 .74449 .38837 .72138 .32589 Metetra
.631 .563 .76 r
.72138 .32589 .74449 .38837 .79092 .37351 .76777 .31002 Metetra
.629 .561 .759 r
.76777 .31002 .79092 .37351 .83815 .35839 .81498 .29421 Metetra
.657 .752 .92 r
.19004 .50278 .21687 .5262 .25546 .51352 .229 .48965 Metetra
.664 .753 .916 r
.229 .48965 .25546 .51352 .29469 .50032 .26863 .47563 Metetra
.669 .75 .911 r
.26863 .47563 .29469 .50032 .33455 .48669 .30892 .46089 Metetra
.664 .743 .909 r
.30892 .46089 .33455 .48669 .37501 .47319 .3498 .44641 Metetra
.641 .732 .914 r
.3498 .44641 .37501 .47319 .41607 .46111 .39123 .43407 Metetra
.568 .706 .935 r
.39123 .43407 .41607 .46111 .4577 .45495 .4332 .42798 Metetra
.855 .776 .773 r
.4332 .42798 .4577 .45495 .50047 .4162 .47686 .37249 Metetra
.809 .696 .74 r
.47686 .37249 .50047 .4162 .54326 .37743 .52007 .31758 Metetra
.588 .541 .77 r
.52007 .31758 .54326 .37743 .58671 .37031 .56346 .31021 Metetra
.623 .562 .765 r
.56346 .31021 .58671 .37031 .63089 .35695 .60764 .29641 Metetra
.635 .569 .763 r
.60764 .29641 .63089 .35695 .67577 .34172 .6525 .28005 Metetra
.637 .568 .761 r
.6525 .28005 .67577 .34172 .72138 .32589 .69808 .26293 Metetra
0 0 .474 r
.69808 .26293 .72138 .32589 .76777 .31002 .75399 .37169 Metetra
.381 .017 .216 r
.75399 .37169 .76777 .31002 .81498 .29421 .80333 .35559 Metetra
.658 .752 .919 r
.16241 .47867 .19004 .50278 .229 .48965 .20174 .46506 Metetra
.669 .754 .914 r
.20174 .46506 .229 .48965 .26863 .47563 .2418 .45014 Metetra
.677 .752 .907 r
.2418 .45014 .26863 .47563 .30892 .46089 .28256 .4341 Metetra
.674 .744 .904 r
.28256 .4341 .30892 .46089 .3498 .44641 .3239 .41815 Metetra
.654 .73 .905 r
.3239 .41815 .3498 .44641 .39123 .43407 .36577 .40406 Metetra
.611 .705 .911 r
.36577 .40406 .39123 .43407 .4332 .42798 .40819 .39415 Metetra
.857 .745 .738 r
.40819 .39415 .4332 .42798 .47686 .37249 .45279 .32795 Metetra
.83 .702 .722 r
.45279 .32795 .47686 .37249 .52007 .31758 .49662 .26288 Metetra
.701 .348 0 r
.49662 .26288 .52007 .31758 .56346 .31021 .54071 .37392 Metetra
.371 .004 .206 r
.54071 .37392 .56346 .31021 .60764 .29641 .58675 .35868 Metetra
.351 0 .193 r
.58675 .35868 .60764 .29641 .6525 .28005 .63355 .34097 Metetra
.346 0 .187 r
.63355 .34097 .6525 .28005 .69808 .26293 .68109 .32263 Metetra
.349 0 .184 r
.68109 .32263 .69808 .26293 .75399 .37169 .72948 .30491 Metetra
.626 .56 .761 r
.72948 .30491 .75399 .37169 .80333 .35559 .7788 .28804 Metetra
.659 .752 .919 r
.13396 .45384 .16241 .47867 .20174 .46506 .17367 .43972 Metetra
.675 .755 .911 r
.17367 .43972 .20174 .46506 .2418 .45014 .21418 .42379 Metetra
.687 .753 .902 r
.21418 .42379 .2418 .45014 .28256 .4341 .25543 .40621 Metetra
.687 .745 .896 r
.25543 .40621 .28256 .4341 .3239 .41815 .2973 .38823 Metetra
.675 .73 .892 r
.2973 .38823 .3239 .41815 .36577 .40406 .3397 .37127 Metetra
.653 .706 .886 r
.3397 .37127 .36577 .40406 .40819 .39415 .38265 .35645 Metetra
0 0 .53 r
.38265 .35645 .40819 .39415 .45279 .32795 .4242 .4072 Metetra
0 0 .008 r
.4242 .4072 .45279 .32795 .49662 .26288 .47071 .33046 Metetra
.363 0 .204 r
.47071 .33046 .49662 .26288 .54071 .37392 .51602 .31486 Metetra
.642 .586 .777 r
.51602 .31486 .54071 .37392 .58675 .35868 .5621 .29655 Metetra
.645 .581 .768 r
.5621 .29655 .58675 .35868 .63355 .34097 .60889 .27662 Metetra
.643 .575 .763 r
.60889 .27662 .63355 .34097 .68109 .32263 .65641 .25653 Metetra
.634 .567 .761 r
.65641 .25653 .68109 .32263 .72948 .30491 .70476 .23758 Metetra
.626 .561 .761 r
.70476 .23758 .72948 .30491 .7788 .28804 .75407 .21992 Metetra
.661 .753 .918 r
.10464 .42825 .13396 .45384 .17367 .43972 .14473 .41358 Metetra
.681 .756 .908 r
.14473 .41358 .17367 .43972 .21418 .42379 .18572 .39652 Metetra
.697 .755 .896 r
.18572 .39652 .21418 .42379 .25543 .40621 .22753 .37713 Metetra
.702 .746 .886 r
.22753 .37713 .25543 .40621 .2973 .38823 .26999 .35663 Metetra
.909 .505 .129 r
.26999 .35663 .2973 .38823 .3397 .37127 .30392 .46521 Metetra
.369 .03 .253 r
.30392 .46521 .3397 .37127 .38265 .35645 .34929 .44544 Metetra
.34929 .44544 .38265 .35645 .4242 .4072 .39807 .36019 Metetra
.857 .711 .701 r
.39807 .36019 .4242 .4072 .47071 .33046 .44551 .27725 Metetra
.661 .617 .795 r
.44551 .27725 .47071 .33046 .51602 .31486 .49101 .25651 Metetra
.659 .6 .778 r
.49101 .25651 .51602 .31486 .5621 .29655 .53718 .23456 Metetra
.656 .589 .768 r
.53718 .23456 .5621 .29655 .60889 .27662 .584 .212 Metetra
.649 .579 .763 r
.584 .212 .60889 .27662 .65641 .25653 .63151 .18997 Metetra
.638 .569 .761 r
.63151 .18997 .65641 .25653 .70476 .23758 .67984 .16969 Metetra
.627 .561 .761 r
.67984 .16969 .70476 .23758 .75407 .21992 .72912 .15121 Metetra
.662 .753 .918 r
.07442 .40187 .10464 .42825 .14473 .41358 .1149 .3866 Metetra
.688 .758 .905 r
.1149 .3866 .14473 .41358 .18572 .39652 .1564 .36827 Metetra
.709 .756 .889 r
.1564 .36827 .18572 .39652 .22753 .37713 .19882 .3468 Metetra
.718 .747 .875 r
.19882 .3468 .22753 .37713 .26999 .35663 .24196 .32338 Metetra
.903 .496 .11 r
.24196 .32338 .26999 .35663 .30392 .46521 .27526 .42825 Metetra
.711 .72 .856 r
.27526 .42825 .30392 .46521 .34929 .44544 .32136 .40319 Metetra
.875 .73 .698 r
.32136 .40319 .34929 .44544 .39807 .36019 .37139 .3122 Metetra
.863 .713 .693 r
.37139 .3122 .39807 .36019 .44551 .27725 .41987 .22403 Metetra
.685 .632 .79 r
.41987 .22403 .44551 .27725 .49101 .25651 .46565 .19841 Metetra
.677 .613 .776 r
.46565 .19841 .49101 .25651 .53718 .23456 .51198 .17259 Metetra
.669 .598 .767 r
.51198 .17259 .53718 .23456 .584 .212 .55887 .14711 Metetra
.657 .585 .762 r
.55887 .14711 .584 .212 .63151 .18997 .60639 .12294 Metetra
0 0 .45 r
.60639 .12294 .63151 .18997 .67984 .16969 .66073 .22828 Metetra
.295 0 .108 r
.66073 .22828 .67984 .16969 .72912 .15121 .71234 .20926 Metetra
.664 .753 .917 r
.04324 .37466 .07442 .40187 .1149 .3866 .08413 .35874 Metetra
.695 .759 .901 r
.08413 .35874 .1149 .3866 .1564 .36827 .12618 .33897 Metetra
.721 .758 .881 r
.12618 .33897 .1564 .36827 .19882 .3468 .16929 .31516 Metetra
.911 .507 .15 r
.16929 .31516 .19882 .3468 .24196 .32338 .19949 .41845 Metetra
.274 0 .181 r
.19949 .41845 .24196 .32338 .27526 .42825 .24587 .38947 Metetra
.734 .722 .84 r
.24587 .38947 .27526 .42825 .32136 .40319 .29277 .35932 Metetra
.879 .728 .691 r
.29277 .35932 .32136 .40319 .37139 .3122 .34415 .26321 Metetra
.869 .713 .687 r
.34415 .26321 .37139 .3122 .41987 .22403 .39376 .17041 Metetra
.706 .643 .784 r
.39376 .17041 .41987 .22403 .46565 .19841 .43991 .14019 Metetra
.694 .624 .773 r
.43991 .14019 .46565 .19841 .51198 .17259 .48647 .11049 Metetra
0 0 .384 r
.48647 .11049 .51198 .17259 .55887 .14711 .53393 .20683 Metetra
.205 0 .058 r
.53393 .20683 .55887 .14711 .60639 .12294 .58368 .17996 Metetra
.231 0 .058 r
.58368 .17996 .60639 .12294 .66073 .22828 .63423 .15664 Metetra
.623 .561 .764 r
.63423 .15664 .66073 .22828 .71234 .20926 .68581 .13668 Metetra
P
p
.002 w
.67932 .02494 m
.94594 .43277 L
s
.94594 .43277 m
.97506 .64585 L
s
.97506 .64585 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.06024 .26735 m
.02494 .49015 L
s
.02494 .49015 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.67932 .02494 m
.06024 .26735 L
s
P
p
p
.002 w
.06024 .26735 m
.67932 .02494 L
s
P
p
.002 w
.06024 .26735 m
.0648 .2716 L
s
P
[(0)] .05113 .25884 1 .93395 Mshowa
p
.002 w
.24126 .19647 m
.24553 .20101 L
s
P
[(2)] .23273 .18737 .938 1 Mshowa
p
.002 w
.43658 .11999 m
.44049 .12484 L
s
P
[(4)] .42876 .11027 .80527 1 Mshowa
p
.002 w
.64798 .03721 m
.65146 .04238 L
s
P
[(6)] .64102 .02686 .67254 1 Mshowa
p
.001 w
.09538 .25359 m
.09808 .25618 L
s
P
p
.001 w
.13104 .23963 m
.1337 .24225 L
s
P
p
.001 w
.16723 .22546 m
.16986 .22811 L
s
P
p
.001 w
.20396 .21107 m
.20656 .21376 L
s
P
p
.001 w
.27913 .18164 m
.28165 .1844 L
s
P
p
.001 w
.31758 .16658 m
.32006 .16938 L
s
P
p
.001 w
.35663 .15129 m
.35907 .15413 L
s
P
p
.001 w
.39629 .13576 m
.39869 .13864 L
s
P
p
.001 w
.47752 .10396 m
.47981 .10691 L
s
P
p
.001 w
.5191 .08767 m
.52135 .09066 L
s
P
p
.001 w
.56137 .07112 m
.56356 .07415 L
s
P
p
.001 w
.60432 .05431 m
.60646 .05737 L
s
P
[(xi)] .30204 .09689 .86223 1 Mshowa
P
% End of Graphics
MathPictureEnd
:[font = section; inactive; ]
The Structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]

The following data are printed out in the process of the work of the program:

1. The symbolic expression for the wave frequency omega corresponding to
     the original PDE;

2. The exact phase shift Phi0 during the time dt (see equation (3.8.6)) comp-
     uted from the original PDE;

3. The difference scheme under consideration;

4. The symbolic expression for the amplification factor lambda for a given
     difference scheme;

5. The real part rel = Re(lambda) and iml = Im(lambda) of the amplification
     factor lambda;

6. The expression for the phase error  (3.8.9) of a given difference scheme;

7. The expression for the dispersion error E(kappa, xi) obtained by the Tay-
     lor expansion around the point xi = 0;

8. The surface E = E(kappa, xi).   

^*)