(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
Numerical Grid Generation
:[font = name; inactive; nohscroll; ]

                                    Victor G.Ganzha and Evgenii V.Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

This Mathematica-Notebook is part of the book entitled

                                 V.G.Ganzha and E.V.Vorozhtsov
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996

:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The program grid1.ma which follows below generates a curvilinear 
grid in the given axisymmetric Laval nozzle with the aid of a simple
algebraic procedure, see  also Section 2.14 of the above book.

:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = special4; inactive; nowordwrap; nohscroll; ]
Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]

           ClearAll[fw, grid1];
:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; ]

 Specify the input data by entering them in the line (see also Section
"Examples of Input Data")
:[font = input; nowordwrap; ]

grid1[0.5, 3.125, 1.0, 0.625, 2.805, 4.005,
      Pi/4, Pi/12, 61, 21]
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line, press Shift + Enter and wait for the result of numerical
computation.The meaning of the input parameters is explained in Section
"Parameters Used in Program grid1.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; backColorRed = 65280; backColorGreen = 65280; backColorBlue = 65280; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; bold; fontName = "Courier New"; fontSize = 12; ]

ClearAll[fw, grid1];
fw[x_] := ( f1 = If[0 <= x && x <= x1,
         y0 - R0 + Sqrt[(R0 - x)*(R0 + x)], 0];
f2 = If[x1 <= x && x <= x2, y1 - ct1*(x - x1), f1];
f3 = If[x2 <= x && x <= x3,
    hc1 + R - Sqrt[(R - x + x0)*(R + x - x0)], f2];
f4 = If[x3 <= x && x <= x4, y3 + ct2*(x - x3), f3]; f4 )

grid1[hc_, cy0_, cR0_, cR_, cx0_, cx4_, thet1_,
      thet2_, ix_, jy_] :=
(
(* -- Specification of the nozzle geometry -- *)
R0 = cR0*hc; y0 = cy0*hc; x0 = cx0*hc; R = cR*hc;
     hc1 = hc;
x1 = R0*N[Sin[thet1]]; ct1 = N[Tan[thet1]];
                 ct2 = N[Tan[thet2]];
x2 = x0-R*N[Sin[thet1]]; x3 = x0+R*N[Sin[thet2]];
x4 = cx4*hc; y1 = y0 - R0*(1 - N[Cos[thet1]]);
	    y3 = hc + R*(1 - N[Cos[thet2]]);
Print["The values of the nozzle geometry",
      " parameters"];
Print["hc = ",hc, ", R0 = ", R0, ", R = ", R,
        ", x0 = ",x0];
Print["thet1 = ", thet1, ", thet2 = ", thet2,
        ", nozzle length = ", x4];

(* -- yw is the list for the ordinates of the 
   nozzle wall ----------------------------- *)
    yw = {};  xorg = 0.0;
  Do[ xi = (i - 1)*x4/(ix - 1); yi = fw[xi];
      AppendTo[yw, yi], {i, ix}];
(* -- x, y are the lists for the abscissas x[[i]]
      and the ordinates y[[i, j]] of the nodes of
      the curvilinear spatial grid ----------- *)
   x = Table[N[(i - 1)*x4/(ix - 1)], {i, ix}];
y = Table[N[yw[[i]]*(j-1)/(jy-1)], {i,ix}, {j,jy}];
(* --- The graphical output of the grid --- *)
(* -------- The lines eta = const ------------ *)
   mt = {}; xtab = {};
 Do[xi = (i - 1)*x4/(ix - 1); 
        AppendTo[xtab, xi], {i, ix}];
 Do[ytab = {};
  Do[yi = y[[i,j]]; AppendTo[ytab, yi], {i, ix}];
   xytab = Table[{xtab[[i]], ytab[[i]]}, {i, ix}];
   mt1 = ListPlot[xytab,
	     AxesLabel  -> {"x", "y"},
             AxesOrigin -> {xorg, 0},
	     PlotJoined -> True,
	     PlotRange  -> {{0, x4}, {0, y0}},
             DisplayFunction -> Identity];
             AppendTo[mt, mt1],
                                 {j, jy}];
(* -- mt3 = Show[mt, 
      DisplayFunction -> $DisplayFunction]; -- *)
(* --------- The lines xi = const ------------ *)
   Do[ xtab = {}; ytab = {};
    xi = (i - 1)*x4/(ix - 1); AppendTo[xtab, xi];
   AppendTo[ytab, 0.0];
 yi = yw[[i]]; AppendTo[xtab, xi]; 
               AppendTo[ytab, yi];
 xytab = Table[{xtab[[j]], ytab[[j]]}, {j, 2}];
      mt1 = ListPlot[xytab,
                     PlotJoined -> True,
                     DisplayFunction -> Identity];
        AppendTo[mt, mt1],
                           {i, ix}];
mt3=Show[mt,DisplayFunction -> $DisplayFunction];
         Display["fig4_6a", mt3];

(* ------- End of the procedure grid1 --------- *)
)

:[font = section; inactive; ]
Parameters Used in Program grid1.ma
:[font = special4; inactive; nowordwrap; nohscroll; ]
____________________________________________________
 Parameter                        Description
____________________________________________________
hc                    the nozzle wall height in the critical section of 
                        the nozzle, hc > 0;
cy0                  the ordinate of the nozzle wall in the inlet section
                        x = 0 related to hc;
cR0                 the radius of the curvature of the nozzle wall in
                        its subsonic part related to hc;
cR                   the nozzle wall radius of the curvature in the
                        critical section related to hc;
cx0                  the abscissa of the critical nozzle section
                        related to hc;
cx4                  the nozzle length related to hc, cx4 > cx0;
thet1                the inclination angle of the nozzle wall in the
                        subsonic part of the nozzle; the angle is speci-
                        fied in radians;
thet2                the inclination angle of the nozzle wall in the
                        supersonic part of the nozzle; the angle is spe-
                        cified in radians;
ix                      the number of grid points on the xi-axis, ix > 1;
jy                      the number of grid points on the eta-axis, jy > 1;
_____________________________________________________

:[font = section; inactive; ]
Examples of Input Data
:[font = subsection; inactive; ]
Example 1 
:[font = input; startGroup; nowordwrap; ]

grid1[0.5, 3.125, 1.0, 0.625, 2.805, 4.005,
      Pi/4, Pi/12, 61, 21]

:[font = print; inactive; formatted; output; nowordwrap; ]
No Input Form Generated


;[o]
The values of the nozzle geometry parameters
hc = 0.5, R0 = 0.5, R = 0.3125, x0 = 1.4025
        Pi          Pi
thet1 = --, thet2 = --, nozzle length = 2.0025
        4           12
:[font = postscript; inactive; output; endGroup; BITMAP; PostScript; pictureLeft = 168; pictureTop = 0; pictureWidth = 307; pictureHeight = 190; nowordwrap; ]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.48265e-17 0.499376 1.73472e-17 0.395542 [
[(0.5)] .24969 0 0 2 Msboxa
[(1)] .49938 0 0 2 Msboxa
[(1.5)] .74906 0 0 2 Msboxa
[(2)] .99875 0 0 2 Msboxa
[(x)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .07911 1 0 Msboxa
[(0.4)] -0.0125 .15822 1 0 Msboxa
[(0.6)] -0.0125 .23733 1 0 Msboxa
[(0.8)] -0.0125 .31643 1 0 Msboxa
[(1)] -0.0125 .39554 1 0 Msboxa
[(1.2)] -0.0125 .47465 1 0 Msboxa
[(1.4)] -0.0125 .55376 1 0 Msboxa
[(y)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.24969 0 m
.24969 .00625 L
s
P
[(0.5)] .24969 0 0 2 Mshowa
p
.002 w
.49938 0 m
.49938 .00625 L
s
P
[(1)] .49938 0 0 2 Mshowa
p
.002 w
.74906 0 m
.74906 .00625 L
s
P
[(1.5)] .74906 0 0 2 Mshowa
p
.002 w
.99875 0 m
.99875 .00625 L
s
P
[(2)] .99875 0 0 2 Mshowa
p
.001 w
.04994 0 m
.04994 .00375 L
s
P
p
.001 w
.09988 0 m
.09988 .00375 L
s
P
p
.001 w
.14981 0 m
.14981 .00375 L
s
P
p
.001 w
.19975 0 m
.19975 .00375 L
s
P
p
.001 w
.29963 0 m
.29963 .00375 L
s
P
p
.001 w
.34956 0 m
.34956 .00375 L
s
P
p
.001 w
.3995 0 m
.3995 .00375 L
s
P
p
.001 w
.44944 0 m
.44944 .00375 L
s
P
p
.001 w
.54931 0 m
.54931 .00375 L
s
P
p
.001 w
.59925 0 m
.59925 .00375 L
s
P
p
.001 w
.64919 0 m
.64919 .00375 L
s
P
p
.001 w
.69913 0 m
.69913 .00375 L
s
P
p
.001 w
.799 0 m
.799 .00375 L
s
P
p
.001 w
.84894 0 m
.84894 .00375 L
s
P
p
.001 w
.89888 0 m
.89888 .00375 L
s
P
p
.001 w
.94881 0 m
.94881 .00375 L
s
P
[(x)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .07911 m
.00625 .07911 L
s
P
[(0.2)] -0.0125 .07911 1 0 Mshowa
p
.002 w
0 .15822 m
.00625 .15822 L
s
P
[(0.4)] -0.0125 .15822 1 0 Mshowa
p
.002 w
0 .23733 m
.00625 .23733 L
s
P
[(0.6)] -0.0125 .23733 1 0 Mshowa
p
.002 w
0 .31643 m
.00625 .31643 L
s
P
[(0.8)] -0.0125 .31643 1 0 Mshowa
p
.002 w
0 .39554 m
.00625 .39554 L
s
P
[(1)] -0.0125 .39554 1 0 Mshowa
p
.002 w
0 .47465 m
.00625 .47465 L
s
P
[(1.2)] -0.0125 .47465 1 0 Mshowa
p
.002 w
0 .55376 m
.00625 .55376 L
s
P
[(1.4)] -0.0125 .55376 1 0 Mshowa
p
.001 w
0 .01582 m
.00375 .01582 L
s
P
p
.001 w
0 .03164 m
.00375 .03164 L
s
P
p
.001 w
0 .04747 m
.00375 .04747 L
s
P
p
.001 w
0 .06329 m
.00375 .06329 L
s
P
p
.001 w
0 .09493 m
.00375 .09493 L
s
P
p
.001 w
0 .11075 m
.00375 .11075 L
s
P
p
.001 w
0 .12657 m
.00375 .12657 L
s
P
p
.001 w
0 .1424 m
.00375 .1424 L
s
P
p
.001 w
0 .17404 m
.00375 .17404 L
s
P
p
.001 w
0 .18986 m
.00375 .18986 L
s
P
p
.001 w
0 .20568 m
.00375 .20568 L
s
P
p
.001 w
0 .2215 m
.00375 .2215 L
s
P
p
.001 w
0 .25315 m
.00375 .25315 L
s
P
p
.001 w
0 .26897 m
.00375 .26897 L
s
P
p
.001 w
0 .28479 m
.00375 .28479 L
s
P
p
.001 w
0 .30061 m
.00375 .30061 L
s
P
p
.001 w
0 .33226 m
.00375 .33226 L
s
P
p
.001 w
0 .34808 m
.00375 .34808 L
s
P
p
.001 w
0 .3639 m
.00375 .3639 L
s
P
p
.001 w
0 .37972 m
.00375 .37972 L
s
P
p
.001 w
0 .41136 m
.00375 .41136 L
s
P
p
.001 w
0 .42719 m
.00375 .42719 L
s
P
p
.001 w
0 .44301 m
.00375 .44301 L
s
P
p
.001 w
0 .45883 m
.00375 .45883 L
s
P
p
.001 w
0 .49047 m
.00375 .49047 L
s
P
p
.001 w
0 .50629 m
.00375 .50629 L
s
P
p
.001 w
0 .52212 m
.00375 .52212 L
s
P
p
.001 w
0 .53794 m
.00375 .53794 L
s
P
p
.001 w
0 .56958 m
.00375 .56958 L
s
P
p
.001 w
0 .5854 m
.00375 .5854 L
s
P
p
.001 w
0 .60122 m
.00375 .60122 L
s
P
p
.001 w
0 .61705 m
.00375 .61705 L
s
P
[(y)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
0 0 m
.01667 0 L
.03333 0 L
.05 0 L
.06667 0 L
.08333 0 L
.1 0 L
.11667 0 L
.13333 0 L
.15 0 L
.16667 0 L
.18333 0 L
.2 0 L
.21667 0 L
.23333 0 L
.25 0 L
.26667 0 L
.28333 0 L
.3 0 L
.31667 0 L
.33333 0 L
.35 0 L
.36667 0 L
.38333 0 L
.4 0 L
.41667 0 L
.43333 0 L
.45 0 L
.46667 0 L
.48333 0 L
.5 0 L
.51667 0 L
.53333 0 L
.55 0 L
.56667 0 L
.58333 0 L
.6 0 L
.61667 0 L
.63333 0 L
.65 0 L
.66667 0 L
.68333 0 L
.7 0 L
.71667 0 L
.73333 0 L
.75 0 L
.76667 0 L
.78333 0 L
.8 0 L
.81667 0 L
Mistroke
.83333 0 L
.85 0 L
.86667 0 L
.88333 0 L
.9 0 L
.91667 0 L
.93333 0 L
.95 0 L
.96667 0 L
.98333 0 L
1 0 L
Mfstroke
0 .0309 m
.01667 .03088 L
.03333 .03081 L
.05 .0307 L
.06667 .03054 L
.08333 .03033 L
.1 .03007 L
.11667 .02976 L
.13333 .02937 L
.15 .02892 L
.16667 .02838 L
.18333 .02774 L
.2 .02708 L
.21667 .02642 L
.23333 .02576 L
.25 .0251 L
.26667 .02444 L
.28333 .02378 L
.3 .02312 L
.31667 .02246 L
.33333 .0218 L
.35 .02114 L
.36667 .02048 L
.38333 .01982 L
.4 .01916 L
.41667 .0185 L
.43333 .01784 L
.45 .01718 L
.46667 .01652 L
.48333 .01586 L
.5 .0152 L
.51667 .01454 L
.53333 .01388 L
.55 .01322 L
.56667 .01256 L
.58333 .0119 L
.6 .01134 L
.61667 .01085 L
.63333 .01049 L
.65 .01022 L
.66667 .01003 L
.68333 .00993 L
.7 .00989 L
.71667 .00992 L
.73333 .01003 L
.75 .0102 L
.76667 .01037 L
.78333 .01055 L
.8 .01073 L
.81667 .0109 L
Mistroke
.83333 .01108 L
.85 .01126 L
.86667 .01144 L
.88333 .01161 L
.9 .01179 L
.91667 .01197 L
.93333 .01214 L
.95 .01232 L
.96667 .0125 L
.98333 .01267 L
1 .01285 L
Mfstroke
0 .0618 m
.01667 .06176 L
.03333 .06163 L
.05 .0614 L
.06667 .06109 L
.08333 .06067 L
.1 .06015 L
.11667 .05951 L
.13333 .05875 L
.15 .05784 L
.16667 .05675 L
.18333 .05547 L
.2 .05415 L
.21667 .05283 L
.23333 .05151 L
.25 .05019 L
.26667 .04887 L
.28333 .04755 L
.3 .04623 L
.31667 .04491 L
.33333 .04359 L
.35 .04227 L
.36667 .04095 L
.38333 .03963 L
.4 .03831 L
.41667 .03699 L
.43333 .03567 L
.45 .03435 L
.46667 .03303 L
.48333 .03171 L
.5 .03039 L
.51667 .02907 L
.53333 .02775 L
.55 .02643 L
.56667 .02511 L
.58333 .02379 L
.6 .02267 L
.61667 .02171 L
.63333 .02098 L
.65 .02044 L
.66667 .02007 L
.68333 .01985 L
.7 .01978 L
.71667 .01984 L
.73333 .02006 L
.75 .02039 L
.76667 .02075 L
.78333 .0211 L
.8 .02146 L
.81667 .02181 L
Mistroke
.83333 .02216 L
.85 .02252 L
.86667 .02287 L
.88333 .02322 L
.9 .02358 L
.91667 .02393 L
.93333 .02429 L
.95 .02464 L
.96667 .02499 L
.98333 .02535 L
1 .0257 L
Mfstroke
0 .09271 m
.01667 .09264 L
.03333 .09244 L
.05 .0921 L
.06667 .09163 L
.08333 .091 L
.1 .09022 L
.11667 .08927 L
.13333 .08812 L
.15 .08676 L
.16667 .08513 L
.18333 .08321 L
.2 .08123 L
.21667 .07925 L
.23333 .07727 L
.25 .07529 L
.26667 .07331 L
.28333 .07133 L
.3 .06935 L
.31667 .06737 L
.33333 .06539 L
.35 .06341 L
.36667 .06143 L
.38333 .05945 L
.4 .05747 L
.41667 .05549 L
.43333 .05351 L
.45 .05153 L
.46667 .04955 L
.48333 .04757 L
.5 .04559 L
.51667 .04361 L
.53333 .04163 L
.55 .03965 L
.56667 .03767 L
.58333 .03569 L
.6 .03401 L
.61667 .03256 L
.63333 .03146 L
.65 .03066 L
.66667 .0301 L
.68333 .02978 L
.7 .02967 L
.71667 .02977 L
.73333 .03008 L
.75 .03059 L
.76667 .03112 L
.78333 .03165 L
.8 .03218 L
.81667 .03271 L
Mistroke
.83333 .03324 L
.85 .03377 L
.86667 .03431 L
.88333 .03484 L
.9 .03537 L
.91667 .0359 L
.93333 .03643 L
.95 .03696 L
.96667 .03749 L
.98333 .03802 L
1 .03855 L
Mfstroke
0 .12361 m
.01667 .12352 L
.03333 .12325 L
.05 .12281 L
.06667 .12217 L
.08333 .12134 L
.1 .1203 L
.11667 .11902 L
.13333 .1175 L
.15 .11567 L
.16667 .11351 L
.18333 .11095 L
.2 .10831 L
.21667 .10567 L
.23333 .10303 L
.25 .10039 L
.26667 .09775 L
.28333 .09511 L
.3 .09247 L
.31667 .08983 L
.33333 .08719 L
.35 .08455 L
.36667 .08191 L
.38333 .07927 L
.4 .07662 L
.41667 .07398 L
.43333 .07134 L
.45 .0687 L
.46667 .06606 L
.48333 .06342 L
.5 .06078 L
.51667 .05814 L
.53333 .0555 L
.55 .05286 L
.56667 .05022 L
.58333 .04758 L
.6 .04535 L
.61667 .04341 L
.63333 .04195 L
.65 .04088 L
.66667 .04014 L
.68333 .0397 L
.7 .03955 L
.71667 .03969 L
.73333 .04011 L
.75 .04079 L
.76667 .0415 L
.78333 .0422 L
.8 .04291 L
.81667 .04362 L
Mistroke
.83333 .04433 L
.85 .04503 L
.86667 .04574 L
.88333 .04645 L
.9 .04716 L
.91667 .04786 L
.93333 .04857 L
.95 .04928 L
.96667 .04999 L
.98333 .05069 L
1 .0514 L
Mfstroke
0 .15451 m
.01667 .1544 L
.03333 .15407 L
.05 .15351 L
.06667 .15271 L
.08333 .15167 L
.1 .15037 L
.11667 .14878 L
.13333 .14687 L
.15 .14459 L
.16667 .14188 L
.18333 .13869 L
.2 .13538 L
.21667 .13208 L
.23333 .12878 L
.25 .12548 L
.26667 .12218 L
.28333 .11888 L
.3 .11558 L
.31667 .11228 L
.33333 .10898 L
.35 .10568 L
.36667 .10238 L
.38333 .09908 L
.4 .09578 L
.41667 .09248 L
.43333 .08918 L
.45 .08588 L
.46667 .08258 L
.48333 .07928 L
.5 .07598 L
.51667 .07268 L
.53333 .06938 L
.55 .06608 L
.56667 .06278 L
.58333 .05948 L
.6 .05668 L
.61667 .05426 L
.63333 .05244 L
.65 .0511 L
.66667 .05017 L
.68333 .04963 L
.7 .04944 L
.71667 .04961 L
.73333 .05014 L
.75 .05099 L
.76667 .05187 L
.78333 .05275 L
.8 .05364 L
.81667 .05452 L
Mistroke
.83333 .05541 L
.85 .05629 L
.86667 .05718 L
.88333 .05806 L
.9 .05894 L
.91667 .05983 L
.93333 .06071 L
.95 .0616 L
.96667 .06248 L
.98333 .06337 L
1 .06425 L
Mfstroke
0 .18541 m
.01667 .18528 L
.03333 .18488 L
.05 .18421 L
.06667 .18326 L
.08333 .18201 L
.1 .18044 L
.11667 .17854 L
.13333 .17624 L
.15 .17351 L
.16667 .17026 L
.18333 .16642 L
.2 .16246 L
.21667 .1585 L
.23333 .15454 L
.25 .15058 L
.26667 .14662 L
.28333 .14266 L
.3 .1387 L
.31667 .13474 L
.33333 .13078 L
.35 .12682 L
.36667 .12286 L
.38333 .1189 L
.4 .11494 L
.41667 .11098 L
.43333 .10702 L
.45 .10306 L
.46667 .0991 L
.48333 .09514 L
.5 .09118 L
.51667 .08721 L
.53333 .08325 L
.55 .07929 L
.56667 .07533 L
.58333 .07137 L
.6 .06802 L
.61667 .06512 L
.63333 .06293 L
.65 .06132 L
.66667 .06021 L
.68333 .05955 L
.7 .05933 L
.71667 .05953 L
.73333 .06017 L
.75 .06118 L
.76667 .06224 L
.78333 .06331 L
.8 .06437 L
.81667 .06543 L
Mistroke
.83333 .06649 L
.85 .06755 L
.86667 .06861 L
.88333 .06967 L
.9 .07073 L
.91667 .07179 L
.93333 .07286 L
.95 .07392 L
.96667 .07498 L
.98333 .07604 L
1 .0771 L
Mfstroke
0 .21631 m
.01667 .21616 L
.03333 .21569 L
.05 .21491 L
.06667 .2138 L
.08333 .21234 L
.1 .21052 L
.11667 .20829 L
.13333 .20562 L
.15 .20243 L
.16667 .19863 L
.18333 .19416 L
.2 .18954 L
.21667 .18492 L
.23333 .1803 L
.25 .17568 L
.26667 .17106 L
.28333 .16644 L
.3 .16182 L
.31667 .1572 L
.33333 .15258 L
.35 .14795 L
.36667 .14333 L
.38333 .13871 L
.4 .13409 L
.41667 .12947 L
.43333 .12485 L
.45 .12023 L
.46667 .11561 L
.48333 .11099 L
.5 .10637 L
.51667 .10175 L
.53333 .09713 L
.55 .09251 L
.56667 .08789 L
.58333 .08327 L
.6 .07936 L
.61667 .07597 L
.63333 .07342 L
.65 .07154 L
.66667 .07024 L
.68333 .06948 L
.7 .06922 L
.71667 .06946 L
.73333 .0702 L
.75 .07138 L
.76667 .07262 L
.78333 .07386 L
.8 .07509 L
.81667 .07633 L
Mistroke
.83333 .07757 L
.85 .07881 L
.86667 .08005 L
.88333 .08128 L
.9 .08252 L
.91667 .08376 L
.93333 .085 L
.95 .08624 L
.96667 .08747 L
.98333 .08871 L
1 .08995 L
Mfstroke
0 .24721 m
.01667 .24704 L
.03333 .24651 L
.05 .24561 L
.06667 .24434 L
.08333 .24268 L
.1 .24059 L
.11667 .23805 L
.13333 .23499 L
.15 .23135 L
.16667 .22701 L
.18333 .2219 L
.2 .21662 L
.21667 .21134 L
.23333 .20605 L
.25 .20077 L
.26667 .19549 L
.28333 .19021 L
.3 .18493 L
.31667 .17965 L
.33333 .17437 L
.35 .16909 L
.36667 .16381 L
.38333 .15853 L
.4 .15325 L
.41667 .14797 L
.43333 .14269 L
.45 .13741 L
.46667 .13213 L
.48333 .12685 L
.5 .12157 L
.51667 .11629 L
.53333 .11101 L
.55 .10573 L
.56667 .10044 L
.58333 .09516 L
.6 .09069 L
.61667 .08682 L
.63333 .0839 L
.65 .08176 L
.66667 .08028 L
.68333 .0794 L
.7 .07911 L
.71667 .07938 L
.73333 .08022 L
.75 .08158 L
.76667 .08299 L
.78333 .08441 L
.8 .08582 L
.81667 .08724 L
Mistroke
.83333 .08865 L
.85 .09007 L
.86667 .09148 L
.88333 .0929 L
.9 .09431 L
.91667 .09573 L
.93333 .09714 L
.95 .09856 L
.96667 .09997 L
.98333 .10139 L
1 .1028 L
Mfstroke
0 .27812 m
.01667 .27792 L
.03333 .27732 L
.05 .27631 L
.06667 .27488 L
.08333 .27301 L
.1 .27067 L
.11667 .2678 L
.13333 .26436 L
.15 .26027 L
.16667 .25539 L
.18333 .24963 L
.2 .24369 L
.21667 .23775 L
.23333 .23181 L
.25 .22587 L
.26667 .21993 L
.28333 .21399 L
.3 .20805 L
.31667 .20211 L
.33333 .19617 L
.35 .19023 L
.36667 .18429 L
.38333 .17835 L
.4 .17241 L
.41667 .16647 L
.43333 .16052 L
.45 .15458 L
.46667 .14864 L
.48333 .1427 L
.5 .13676 L
.51667 .13082 L
.53333 .12488 L
.55 .11894 L
.56667 .113 L
.58333 .10706 L
.6 .10203 L
.61667 .09768 L
.63333 .09439 L
.65 .09197 L
.66667 .09031 L
.68333 .08933 L
.7 .089 L
.71667 .0893 L
.73333 .09025 L
.75 .09177 L
.76667 .09337 L
.78333 .09496 L
.8 .09655 L
.81667 .09814 L
Mistroke
.83333 .09973 L
.85 .10132 L
.86667 .10292 L
.88333 .10451 L
.9 .1061 L
.91667 .10769 L
.93333 .10928 L
.95 .11088 L
.96667 .11247 L
.98333 .11406 L
1 .11565 L
Mfstroke
0 .30902 m
.01667 .3088 L
.03333 .30813 L
.05 .30701 L
.06667 .30543 L
.08333 .30335 L
.1 .30074 L
.11667 .29756 L
.13333 .29374 L
.15 .28918 L
.16667 .28376 L
.18333 .27737 L
.2 .27077 L
.21667 .26417 L
.23333 .25757 L
.25 .25097 L
.26667 .24437 L
.28333 .23777 L
.3 .23117 L
.31667 .22457 L
.33333 .21796 L
.35 .21136 L
.36667 .20476 L
.38333 .19816 L
.4 .19156 L
.41667 .18496 L
.43333 .17836 L
.45 .17176 L
.46667 .16516 L
.48333 .15856 L
.5 .15196 L
.51667 .14536 L
.53333 .13876 L
.55 .13216 L
.56667 .12556 L
.58333 .11896 L
.6 .11337 L
.61667 .10853 L
.63333 .10488 L
.65 .10219 L
.66667 .10034 L
.68333 .09926 L
.7 .09889 L
.71667 .09922 L
.73333 .10028 L
.75 .10197 L
.76667 .10374 L
.78333 .10551 L
.8 .10728 L
.81667 .10905 L
Mistroke
.83333 .11081 L
.85 .11258 L
.86667 .11435 L
.88333 .11612 L
.9 .11789 L
.91667 .11966 L
.93333 .12143 L
.95 .12319 L
.96667 .12496 L
.98333 .12673 L
1 .1285 L
Mfstroke
0 .33992 m
.01667 .33968 L
.03333 .33895 L
.05 .33772 L
.06667 .33597 L
.08333 .33368 L
.1 .33081 L
.11667 .32731 L
.13333 .32311 L
.15 .3181 L
.16667 .31214 L
.18333 .30511 L
.2 .29785 L
.21667 .29059 L
.23333 .28333 L
.25 .27606 L
.26667 .2688 L
.28333 .26154 L
.3 .25428 L
.31667 .24702 L
.33333 .23976 L
.35 .2325 L
.36667 .22524 L
.38333 .21798 L
.4 .21072 L
.41667 .20346 L
.43333 .1962 L
.45 .18894 L
.46667 .18168 L
.48333 .17442 L
.5 .16715 L
.51667 .15989 L
.53333 .15263 L
.55 .14537 L
.56667 .13811 L
.58333 .13085 L
.6 .1247 L
.61667 .11938 L
.63333 .11537 L
.65 .11241 L
.66667 .11038 L
.68333 .10918 L
.7 .10877 L
.71667 .10915 L
.73333 .11031 L
.75 .11217 L
.76667 .11411 L
.78333 .11606 L
.8 .118 L
.81667 .11995 L
Mistroke
.83333 .1219 L
.85 .12384 L
.86667 .12579 L
.88333 .12773 L
.9 .12968 L
.91667 .13162 L
.93333 .13357 L
.95 .13551 L
.96667 .13746 L
.98333 .13941 L
1 .14135 L
Mfstroke
0 .37082 m
.01667 .37056 L
.03333 .36976 L
.05 .36842 L
.06667 .36651 L
.08333 .36402 L
.1 .36089 L
.11667 .35707 L
.13333 .35249 L
.15 .34702 L
.16667 .34052 L
.18333 .33284 L
.2 .32492 L
.21667 .317 L
.23333 .30908 L
.25 .30116 L
.26667 .29324 L
.28333 .28532 L
.3 .2774 L
.31667 .26948 L
.33333 .26156 L
.35 .25364 L
.36667 .24572 L
.38333 .2378 L
.4 .22987 L
.41667 .22195 L
.43333 .21403 L
.45 .20611 L
.46667 .19819 L
.48333 .19027 L
.5 .18235 L
.51667 .17443 L
.53333 .16651 L
.55 .15859 L
.56667 .15067 L
.58333 .14275 L
.6 .13604 L
.61667 .13023 L
.63333 .12586 L
.65 .12263 L
.66667 .12041 L
.68333 .11911 L
.7 .11866 L
.71667 .11907 L
.73333 .12034 L
.75 .12237 L
.76667 .12449 L
.78333 .12661 L
.8 .12873 L
.81667 .13086 L
Mistroke
.83333 .13298 L
.85 .1351 L
.86667 .13722 L
.88333 .13934 L
.9 .14147 L
.91667 .14359 L
.93333 .14571 L
.95 .14783 L
.96667 .14996 L
.98333 .15208 L
1 .1542 L
Mfstroke
0 .40172 m
.01667 .40144 L
.03333 .40057 L
.05 .39912 L
.06667 .39706 L
.08333 .39435 L
.1 .39096 L
.11667 .38683 L
.13333 .38186 L
.15 .37594 L
.16667 .36889 L
.18333 .36058 L
.2 .352 L
.21667 .34342 L
.23333 .33484 L
.25 .32626 L
.26667 .31768 L
.28333 .3091 L
.3 .30052 L
.31667 .29193 L
.33333 .28335 L
.35 .27477 L
.36667 .26619 L
.38333 .25761 L
.4 .24903 L
.41667 .24045 L
.43333 .23187 L
.45 .22329 L
.46667 .21471 L
.48333 .20613 L
.5 .19755 L
.51667 .18897 L
.53333 .18038 L
.55 .1718 L
.56667 .16322 L
.58333 .15464 L
.6 .14738 L
.61667 .14109 L
.63333 .13634 L
.65 .13285 L
.66667 .13045 L
.68333 .12903 L
.7 .12855 L
.71667 .12899 L
.73333 .13036 L
.75 .13256 L
.76667 .13486 L
.78333 .13716 L
.8 .13946 L
.81667 .14176 L
Mistroke
.83333 .14406 L
.85 .14636 L
.86667 .14866 L
.88333 .15096 L
.9 .15326 L
.91667 .15555 L
.93333 .15785 L
.95 .16015 L
.96667 .16245 L
.98333 .16475 L
1 .16705 L
Mfstroke
0 .43262 m
.01667 .43232 L
.03333 .43138 L
.05 .42982 L
.06667 .4276 L
.08333 .42469 L
.1 .42104 L
.11667 .41658 L
.13333 .41123 L
.15 .40486 L
.16667 .39727 L
.18333 .38832 L
.2 .37908 L
.21667 .36984 L
.23333 .3606 L
.25 .35135 L
.26667 .34211 L
.28333 .33287 L
.3 .32363 L
.31667 .31439 L
.33333 .30515 L
.35 .29591 L
.36667 .28667 L
.38333 .27743 L
.4 .26819 L
.41667 .25895 L
.43333 .24971 L
.45 .24046 L
.46667 .23122 L
.48333 .22198 L
.5 .21274 L
.51667 .2035 L
.53333 .19426 L
.55 .18502 L
.56667 .17578 L
.58333 .16654 L
.6 .15871 L
.61667 .15194 L
.63333 .14683 L
.65 .14307 L
.66667 .14048 L
.68333 .13896 L
.7 .13844 L
.71667 .13891 L
.73333 .14039 L
.75 .14276 L
.76667 .14524 L
.78333 .14771 L
.8 .15019 L
.81667 .15266 L
Mistroke
.83333 .15514 L
.85 .15762 L
.86667 .16009 L
.88333 .16257 L
.9 .16504 L
.91667 .16752 L
.93333 .17 L
.95 .17247 L
.96667 .17495 L
.98333 .17743 L
1 .1799 L
Mfstroke
0 .46353 m
.01667 .46319 L
.03333 .4622 L
.05 .46052 L
.06667 .45814 L
.08333 .45502 L
.1 .45111 L
.11667 .44634 L
.13333 .44061 L
.15 .43378 L
.16667 .42564 L
.18333 .41606 L
.2 .40615 L
.21667 .39625 L
.23333 .38635 L
.25 .37645 L
.26667 .36655 L
.28333 .35665 L
.3 .34675 L
.31667 .33685 L
.33333 .32695 L
.35 .31705 L
.36667 .30715 L
.38333 .29724 L
.4 .28734 L
.41667 .27744 L
.43333 .26754 L
.45 .25764 L
.46667 .24774 L
.48333 .23784 L
.5 .22794 L
.51667 .21804 L
.53333 .20814 L
.55 .19824 L
.56667 .18833 L
.58333 .17843 L
.6 .17005 L
.61667 .16279 L
.63333 .15732 L
.65 .15329 L
.66667 .15052 L
.68333 .14888 L
.7 .14833 L
.71667 .14883 L
.73333 .15042 L
.75 .15296 L
.76667 .15561 L
.78333 .15826 L
.8 .16092 L
.81667 .16357 L
Mistroke
.83333 .16622 L
.85 .16887 L
.86667 .17153 L
.88333 .17418 L
.9 .17683 L
.91667 .17949 L
.93333 .18214 L
.95 .18479 L
.96667 .18745 L
.98333 .1901 L
1 .19275 L
Mfstroke
0 .49443 m
.01667 .49407 L
.03333 .49301 L
.05 .49122 L
.06667 .48868 L
.08333 .48536 L
.1 .48118 L
.11667 .47609 L
.13333 .46998 L
.15 .46269 L
.16667 .45402 L
.18333 .44379 L
.2 .43323 L
.21667 .42267 L
.23333 .41211 L
.25 .40155 L
.26667 .39099 L
.28333 .38043 L
.3 .36987 L
.31667 .3593 L
.33333 .34874 L
.35 .33818 L
.36667 .32762 L
.38333 .31706 L
.4 .3065 L
.41667 .29594 L
.43333 .28538 L
.45 .27482 L
.46667 .26426 L
.48333 .25369 L
.5 .24313 L
.51667 .23257 L
.53333 .22201 L
.55 .21145 L
.56667 .20089 L
.58333 .19033 L
.6 .18139 L
.61667 .17365 L
.63333 .16781 L
.65 .16351 L
.66667 .16055 L
.68333 .15881 L
.7 .15822 L
.71667 .15876 L
.73333 .16045 L
.75 .16315 L
.76667 .16598 L
.78333 .16881 L
.8 .17164 L
.81667 .17447 L
Mistroke
.83333 .1773 L
.85 .18013 L
.86667 .18296 L
.88333 .18579 L
.9 .18862 L
.91667 .19145 L
.93333 .19428 L
.95 .19711 L
.96667 .19994 L
.98333 .20277 L
1 .2056 L
Mfstroke
0 .52533 m
.01667 .52495 L
.03333 .52382 L
.05 .52192 L
.06667 .51923 L
.08333 .51569 L
.1 .51126 L
.11667 .50585 L
.13333 .49935 L
.15 .49161 L
.16667 .4824 L
.18333 .47153 L
.2 .46031 L
.21667 .44909 L
.23333 .43787 L
.25 .42664 L
.26667 .41542 L
.28333 .4042 L
.3 .39298 L
.31667 .38176 L
.33333 .37054 L
.35 .35932 L
.36667 .3481 L
.38333 .33688 L
.4 .32566 L
.41667 .31443 L
.43333 .30321 L
.45 .29199 L
.46667 .28077 L
.48333 .26955 L
.5 .25833 L
.51667 .24711 L
.53333 .23589 L
.55 .22467 L
.56667 .21345 L
.58333 .20222 L
.6 .19272 L
.61667 .1845 L
.63333 .17829 L
.65 .17373 L
.66667 .17059 L
.68333 .16873 L
.7 .16811 L
.71667 .16868 L
.73333 .17048 L
.75 .17335 L
.76667 .17636 L
.78333 .17936 L
.8 .18237 L
.81667 .18538 L
Mistroke
.83333 .18838 L
.85 .19139 L
.86667 .1944 L
.88333 .1974 L
.9 .20041 L
.91667 .20342 L
.93333 .20642 L
.95 .20943 L
.96667 .21244 L
.98333 .21544 L
1 .21845 L
Mfstroke
0 .55623 m
.01667 .55583 L
.03333 .55464 L
.05 .55263 L
.06667 .54977 L
.08333 .54602 L
.1 .54133 L
.11667 .53561 L
.13333 .52873 L
.15 .52053 L
.16667 .51077 L
.18333 .49927 L
.2 .48739 L
.21667 .4755 L
.23333 .46362 L
.25 .45174 L
.26667 .43986 L
.28333 .42798 L
.3 .4161 L
.31667 .40422 L
.33333 .39234 L
.35 .38046 L
.36667 .36857 L
.38333 .35669 L
.4 .34481 L
.41667 .33293 L
.43333 .32105 L
.45 .30917 L
.46667 .29729 L
.48333 .28541 L
.5 .27353 L
.51667 .26164 L
.53333 .24976 L
.55 .23788 L
.56667 .226 L
.58333 .21412 L
.6 .20406 L
.61667 .19535 L
.63333 .18878 L
.65 .18395 L
.66667 .18062 L
.68333 .17866 L
.7 .17799 L
.71667 .1786 L
.73333 .1805 L
.75 .18355 L
.76667 .18673 L
.78333 .18992 L
.8 .1931 L
.81667 .19628 L
Mistroke
.83333 .19947 L
.85 .20265 L
.86667 .20583 L
.88333 .20902 L
.9 .2122 L
.91667 .21538 L
.93333 .21857 L
.95 .22175 L
.96667 .22493 L
.98333 .22812 L
1 .2313 L
Mfstroke
0 .58713 m
.01667 .58671 L
.03333 .58545 L
.05 .58333 L
.06667 .58031 L
.08333 .57636 L
.1 .57141 L
.11667 .56536 L
.13333 .5581 L
.15 .54945 L
.16667 .53915 L
.18333 .527 L
.2 .51446 L
.21667 .50192 L
.23333 .48938 L
.25 .47684 L
.26667 .4643 L
.28333 .45176 L
.3 .43922 L
.31667 .42667 L
.33333 .41413 L
.35 .40159 L
.36667 .38905 L
.38333 .37651 L
.4 .36397 L
.41667 .35143 L
.43333 .33889 L
.45 .32634 L
.46667 .3138 L
.48333 .30126 L
.5 .28872 L
.51667 .27618 L
.53333 .26364 L
.55 .2511 L
.56667 .23856 L
.58333 .22602 L
.6 .2154 L
.61667 .20621 L
.63333 .19927 L
.65 .19417 L
.66667 .19065 L
.68333 .18858 L
.7 .18788 L
.71667 .18852 L
.73333 .19053 L
.75 .19375 L
.76667 .19711 L
.78333 .20047 L
.8 .20383 L
.81667 .20719 L
Mistroke
.83333 .21055 L
.85 .21391 L
.86667 .21727 L
.88333 .22063 L
.9 .22399 L
.91667 .22735 L
.93333 .23071 L
.95 .23407 L
.96667 .23743 L
.98333 .24079 L
1 .24415 L
Mfstroke
0 .61803 m
.01667 .61759 L
.03333 .61626 L
.05 .61403 L
.06667 .61085 L
.08333 .60669 L
.1 .60148 L
.11667 .59512 L
.13333 .58748 L
.15 .57837 L
.16667 .56753 L
.18333 .55474 L
.2 .54154 L
.21667 .52834 L
.23333 .51514 L
.25 .50194 L
.26667 .48873 L
.28333 .47553 L
.3 .46233 L
.31667 .44913 L
.33333 .43593 L
.35 .42273 L
.36667 .40953 L
.38333 .39633 L
.4 .38312 L
.41667 .36992 L
.43333 .35672 L
.45 .34352 L
.46667 .33032 L
.48333 .31712 L
.5 .30392 L
.51667 .29072 L
.53333 .27751 L
.55 .26431 L
.56667 .25111 L
.58333 .23791 L
.6 .22673 L
.61667 .21706 L
.63333 .20976 L
.65 .20439 L
.66667 .20069 L
.68333 .19851 L
.7 .19777 L
.71667 .19845 L
.73333 .20056 L
.75 .20394 L
.76667 .20748 L
.78333 .21102 L
.8 .21455 L
.81667 .21809 L
Mistroke
.83333 .22163 L
.85 .22517 L
.86667 .2287 L
.88333 .23224 L
.9 .23578 L
.91667 .23932 L
.93333 .24285 L
.95 .24639 L
.96667 .24993 L
.98333 .25346 L
1 .257 L
Mfstroke
0 0 m
0 .61803 L
s
.01667 0 m
.01667 .61759 L
s
.03333 0 m
.03333 .61626 L
s
.05 0 m
.05 .61403 L
s
.06667 0 m
.06667 .61085 L
s
.08333 0 m
.08333 .60669 L
s
.1 0 m
.1 .60148 L
s
.11667 0 m
.11667 .59512 L
s
.13333 0 m
.13333 .58748 L
s
.15 0 m
.15 .57837 L
s
.16667 0 m
.16667 .56753 L
s
.18333 0 m
.18333 .55474 L
s
.2 0 m
.2 .54154 L
s
.21667 0 m
.21667 .52834 L
s
.23333 0 m
.23333 .51514 L
s
.25 0 m
.25 .50194 L
s
.26667 0 m
.26667 .48873 L
s
.28333 0 m
.28333 .47553 L
s
.3 0 m
.3 .46233 L
s
.31667 0 m
.31667 .44913 L
s
.33333 0 m
.33333 .43593 L
s
.35 0 m
.35 .42273 L
s
.36667 0 m
.36667 .40953 L
s
.38333 0 m
.38333 .39633 L
s
.4 0 m
.4 .38312 L
s
.41667 0 m
.41667 .36992 L
s
.43333 0 m
.43333 .35672 L
s
.45 0 m
.45 .34352 L
s
.46667 0 m
.46667 .33032 L
s
.48333 0 m
.48333 .31712 L
s
.5 0 m
.5 .30392 L
s
.51667 0 m
.51667 .29072 L
s
.53333 0 m
.53333 .27751 L
s
.55 0 m
.55 .26431 L
s
.56667 0 m
.56667 .25111 L
s
.58333 0 m
.58333 .23791 L
s
.6 0 m
.6 .22673 L
s
.61667 0 m
.61667 .21706 L
s
.63333 0 m
.63333 .20976 L
s
.65 0 m
.65 .20439 L
s
.66667 0 m
.66667 .20069 L
s
.68333 0 m
.68333 .19851 L
s
.7 0 m
.7 .19777 L
s
.71667 0 m
.71667 .19845 L
s
.73333 0 m
.73333 .20056 L
s
.75 0 m
.75 .20394 L
s
.76667 0 m
.76667 .20748 L
s
.78333 0 m
.78333 .21102 L
s
.8 0 m
.8 .21455 L
s
.81667 0 m
.81667 .21809 L
s
.83333 0 m
.83333 .22163 L
s
.85 0 m
.85 .22517 L
s
.86667 0 m
.86667 .2287 L
s
.88333 0 m
.88333 .23224 L
s
.9 0 m
.9 .23578 L
s
.91667 0 m
.91667 .23932 L
s
.93333 0 m
.93333 .24285 L
s
.95 0 m
.95 .24639 L
s
.96667 0 m
.96667 .24993 L
s
.98333 0 m
.98333 .25346 L
s
1 0 m
1 .257 L
s
P
% End of Graphics
MathPictureEnd
:[font = subsection; inactive; ]
Example 2
:[font = input; nowordwrap; ]

grid1[0.5, 1.617, 1.617, 0.1, 2.0, 2.6,
      Pi/9, Pi/9, 61, 21]

:[font = section; inactive; ]
The Structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]
The following data are printed out in the process of the work of the
program:

1. The values of the nozzle geometry parameters.

2. The grid obtained by the interpolation method of Section 2.14.

^*)