(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
Explicit Scheme for the One-Dimensional Heat Equation
:[font = name; inactive; nohscroll; ]

                                   Victor G.Ganzha and Evgenii V.Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

This Mathematica-Notebook is part of the book entitled
                              V.G.Ganzha and E.V.Vorozhtsov
    Numerical  Solutions For Partial Differential Equations: Problem Solving
    Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]

    Numerical  Solutions For Partial Differential Equations: Problem Solving
    Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.

:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The program heat1.ma which follows below implements the computation by
the explicit difference scheme  (3.2.1) under the initial condition (3.2.4)
and the boundary conditions (3.2.5)-(3.2.6). A more detailed description of
the structure of the program can be found in  section 3.2 of the above book.

:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1

:[font = special4; inactive; nowordwrap; nohscroll; ]
Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]

ClearAll[uinit, uexact, heat1];

:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the input data by entering them in the line
:[font = input; nowordwrap; ]
heat1[2.0, 4.0, 0.0, 1.0, 0.0, 2.0, 80, 0.5, 100, 4]


:[font = special4; inactive; nowordwrap; nohscroll; ]
(See section "Examples of Input Data" below). Then click in this line, press
Shift + Enter and wait for the result of numerical computation. The meaning 
of the input parameters is explained in Section "Parameters Used in 
Program heat1.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; ]


ClearAll[uinit, uexact, heat1];

(* --- The function uinit[...] computes the initial
       condition (3.2.4) --- *)
uinit[x_, beta_, A1_, A2_] :=
(xb = beta*x; A1*Cos[xb] + A2*Sin[xb] )

(* --- The function uexact[...] computes the exact
       solution (3.2.3) ----- *)
 uexact[x_, t_, nu_, beta_, A1_, A2_] :=
(xb = beta*x;  
E^(-nu*beta^2*t)*(A1*Cos[xb] + A2*Sin[xb]) )

heat1[nu_, beta_, A1_, A2_, a1_, b1_, M_, cap_,
      numbt_, Npic_]:=Block[
(* --- Definition of the local variables --- *)
{uj,up,ug,ut,tnt,y,j,k,n,M1,h,t,dt,xf0,Tmax,N},

(*  uj = the difference solution at time level n,
up = the difference solution at time level n+1  *)
     h = (b1 - a1)/M;  M1 = M + 1; M2 = M - 1;
       dt = cap*h*h/nu;   xf0 = a1 + jf0*h;
	  Tmax = numbt*dt; N = numbt;
(* Computation of the initial values u(xj,0)
                                at grid points *)
uj = Table[1.0, {j,0,M}];
Do[xj = a1 + j*h; uj[[j]] = uinit[xj, beta, A1, A2], 
                                           {j, 0, M}];
up = uj; u0 =uj[[0]];
                 ug = Table[u0,{j, 1, M1}];
          tnt = Table[Tmax, {j, Npic}];
          mt = Table[j, {j, Npic}];
(* - Tmax is the right end of the time interval - *)
      nplot = Max[1, Floor[N/Npic]];
(* - The solution graphs u(x, tk) will be given at
      tk = (k-1)*nplot*dt, k = 1,...,Npic  ----- *)
      um0 = Abs[A1] + Abs[A2];
      Print["um0 = ",um0];
t= 0.0;  n2 = nplot;  nt = 1;  tnt[[1]] = 0.0;
(* - Generation of the two-dimensional table ut - *)
        ut = Table[u0, {k, 1, Npic}, {j, 1, M1}];
(* - Storing the initial profile u(x,0) in
     ut[[j, 1]] - *)
         Do[ ut[[1,j + 1]] = uj[[j]], {j, 0, M}];
(* --- Begin of the Do-loop for time steps --- *)
        Do[
            t = t + dt;
            Print["n = ", n, ", t = ", t];
(* -- Do-loop over grid nodes on the x-axis -- *)
      fxr = uj[[1]] - uj[[0]];
            Do[ fxl = fxr;
(* -- The explicit scheme (3.2.1) for the heat
      equation (3.1.2) ----------------------- *)
      fxr = uj[[j + 1]] - uj[[j]];
        up[[j]] = uj[[j]] + cap*(fxr - fxl),
          {j, 1, M2}];
(* -- The boundary condition on the left 
                            boundary x = a1 -- *)
       up[[0]] = uexact[a1, t, nu, beta, A1, A2];
(* -- The boundary condition on the right
                            boundary x = b1 -- *)
       up[[M]] = uexact[b1, t, nu, beta, A1, A2];
(* --------- Exchange of the lists ----------- *)
                         uj = up;
(* ------ Find Max[Abs[u(j,n+1) - um] -------- *)
      um = E^(-beta^2*t)*um0;  umax = 0.0;
Do[ y = Abs[uj[[j]] -um]; umax = Max[y, umax],
        {j, 0, M, 1}];
           If[n == n2, Goto[store]];
  If[umax > 2.*um, Goto [endsteps], Goto [endn]];
Label[endsteps]; Tmax = t;
Label[store]; n2 = n2 + nplot;
      nt = nt + 1;
                   If[nt <= Npic,
      tnt[[nt]] = t;
(* -- Storing the solution u(x,t) in ut[[nt,j]] --*)
      Do[ ut[[nt, j + 1]] = uj[[j]], {j, 0, M}]];
      If[umax > 2.0*um||nt == Npic, Break[]];
 Label[endn],
(* -------- End of the Do-loop in n ------------ *)
              {n, 0, N, 1}];
(* -- Plotting the solution graphs for several
                              moments of time -- *)
(* -- Determining min(ut) and max(ut) ---------- *)
            umin = 10^6;  umax = -umin;
       nt = If[nt > Npic, Npic, nt];
      Do[
          y = ut[[k, j]];
            umin = If[y < umin, y, umin];
              umax = If[y > umax, y, umax],
         {k, nt}, {j, M1}];
        Print["umin = ", umin, ", umax = ", umax];
(* -- Storing the pictures in the elements mt[[j]],
      j = 1,...,Npic -- *)
     umin = If[umin > 0, 0.0, umin];
     umax = If[umax < 0, 0.0, umax];
     Do[
        ug = ut[[j]];
        t  = tnt[[j]];
     Print["The solution graph at t = ", t];
 mt[[j]] = ListPlot[ug,
               AxesLabel -> {"x", "u"},
               PlotJoined -> True,
               PlotRange -> {{0, M1}, {umin, umax}}],
       {j, nt}];
If[nt == 2,
gr = Show[GraphicsArray[{mt[[1]], mt[[2]]}]]  ];
If[nt == 3,
gr = Show[GraphicsArray[{{mt[[1]], mt[[2]]},
                         {mt[[3]]}}]]];
If[nt == 4,
gr = Show[GraphicsArray[{{mt[[1]], mt[[2]]},
                             {mt[[3]], mt[[4]]}}]]];
If[nt == 5,
 gr = Show[GraphicsArray[{
     {mt[[1]], mt[[2]], mt[[3]]},
     {mt[[4]], mt[[5]]}}]] ];
If[nt == 6,
 gr = Show[GraphicsArray[{
     {mt[[1]], mt[[2]], mt[[3]]},
     {mt[[4]], mt[[5]], mt[[6]]}}]] ];
If[nt == 7,
 gr = Show[GraphicsArray[{
     {mt[[1]], mt[[2]], mt[[3]], mt[[4]]},
     {mt[[5]], mt[[6]], mt[[7]]}}]] ];
If[nt >= 8,
 gr = Show[GraphicsArray[{
     {mt[[1]], mt[[2]], mt[[3]], mt[[4]]},
     {mt[[5]], mt[[6]], mt[[7]], mt[[8]]}}]] ];
     Display["fig3_14", gr];
(* ----------- End of the block ------------- *)
           ];


:[font = section; inactive; ]
Parameters Used in Program heat1.ma      
:[font = text; inactive; ]

________________________________________________________
 Parameter                              Description
________________________________________________________

nu                       the positive coefficient $\nu$ in the heat
                           equation (3.1.2);
beta                   the constant entering the exact solution (3.2.3);
A1                      the constant entering the exact solution (3.2.3);
A2                      the constant entering the exact solution (3.2.3),
                           |A1| + |A2| != 0;
a1                      the abscissa of the left end of the interval on
                           the x-axis;
b1                      the abscissa of the right end of the above interval,
                          a1 < b1;
M                       the number of the grid node coinciding with the right
                          boundary x = b1 of the spatial integration interval
                          (see also (2.1.5));
cap                    the Courant number, cap = nu*dt/(h*h), where dt is the
                           time step of the difference scheme, and h is the step
                           of the uniform grid in the interval a1 <=x <= b1;
numbt                the number of the time steps to be made by the
                          difference scheme, numbt > 1;
Npic                  the number of the pictures of the difference solution
                          graphs for Npic moments of time, Npic > 1.
________________________________________________________

:[font = section; inactive; ]
 Examples of Input Data    
   
:[font = subsection; inactive; ]
Example 1
:[font = input; nowordwrap; ]

heat1[2.0, 4.0, 0.0, 1.0, 0.0, 2.0, 80, 0.5, 100, 4]

:[font = subsection; inactive; ]
Example 2 (Unstable Computation with kappa = 0.6)
:[font = input; nowordwrap; ]

heat1[2.0, 4.0, 0.0, 1.0, 0.0, 2.0, 80, 0.6, 100, 4]

:[font = subsection; inactive; ]
Example 3 (beta = 8, kappa = 0.5)
:[font = input; nowordwrap; ]

heat1[2.0, 8.0, 0.0, 1.0, 0.0, 2.0, 80, 0.5, 100, 4]

:[font = subsection; inactive; ]
Example 4 (beta = 50, kappa = 0.5)
:[font = input; nowordwrap; ]

heat1[2.0, 50.0, 0.0, 1.0, 0.0, 2.0, 80, 0.5, 5, 4]

:[font = subsection; inactive; ]
Example 5 (beta = 70, kappa = 0.5)
:[font = input; nowordwrap; ]

heat1[2.0, 70.0, 0.0, 1.0, 0.0, 2.0, 80, 0.5, 5, 4]

:[font = input; nowordwrap; ]


:[font = section; inactive; ]
The Structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]
The following data are printed out in the process of the work of the
program:

1. um0 = |A1 + |A2|;

2. The current values of n, the time step number, and the time t;
                                                             n       n
3. The numerical solution graphs u   =  u  (x) for Npic fixed moments
    of time; the values of these times are printed out in the message
    like
                      The solution graph at t = 0.00046875

    To resize an individual picture obtained by Mathematica, please

 (i) Click anywhere inside the cell, but not the cell bracket itself. 
     A bounding box with small handles appears around the graphic
     image.

 (ii) Drag one of the handles to adjust the size and shape of the
      bounding box. In this way it is possible to resize the height and
      width of the graphic image.  
^*)