(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "System", 10, L0, bold;
	fontset = input, "Courier", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 10, L0, nowordwrap;
	fontset = message, "MS Sans Serif", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "System", 10, L0, nowordwrap, bold;
	fontset = postscript, "System", 10, L0, nowordwrap, bold;
	fontset = name, "MS Serif", 10, L0, nohscroll, italic, B65280;
	fontset = header, "System", 10, L0, right, nohscroll, bold;
	fontset = footer, "System", 10, L0, right, nohscroll, bold;
	fontset = help, "System", 10, L0, nohscroll, bold;
	fontset = clipboard, "System", 10, L0, nohscroll, bold;
	fontset = completions, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = graphics, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = special1, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = special2, "System", 10, L0, center, nowordwrap, nohscroll, bold;
	fontset = special3, "System", 10, L0, right, nowordwrap, nohscroll, bold;
	fontset = special4, "MS Sans Serif", 10, L0, nowordwrap, nohscroll;
	fontset = special5, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = leftheader, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = leftfooter, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = reserved1, "System", 10, L0, nowordwrap, nohscroll, bold;]
:[font = title; inactive; nohscroll; center; ]
Fourier Method
:[font = name; inactive; nohscroll; ]

                                                     Victor G. Ganzha and Evgenii V. Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = text; inactive; ]
This Mathematica-Notebook is part of the book entitled
                                     V.G.Ganzha and E.V.Vorozhtsov
   Numerical Solutions For Partial Differential Equations: Problem Solving
   Using Mathematica.   CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = text; inactive; ]
 Numerical Solutions For Partial Differential Equations: Problem Solving
 Using Mathematica.   CRC Press, Boca Raton, Ann Arbor, 1996.

:[font = section; inactive; ]
Initialisation
:[font = special4; inactive; nowordwrap; nohscroll; ]
Needs[Algebra `ReIm`, Algebra `Trigonometry`]

:[font = section; inactive; ]
General Description
:[font = text; inactive; ]
The program  st1.ma which follows below enables one to obtain the stability 
region of an explicit  scalar difference scheme approximating a scalar one-di-
mensional PDE of hyperbolic or parabolic type. The underlying method of the
 stability analysis is the Fourier method (see Section 2.3 of the above book).
 It is assumed that the stability region is described in terms of a single nondi-
mensional parameter c1, for example, the Courant number c1 = a*dt/h, where
dt is the time step of difference scheme.
    A more detailed description of the underlying symbolic-numerical method 
can be found in Section 2.3 of the above mentioned book.  
:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = text; inactive; ]
 Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]

ClearAll[fbis, rel, iml, bisec];

:[font = subsection; inactive; ]
Step 2
:[font = text; inactive; ]
Specify the form of a difference scheme by modifying the body of the
function sch1[  ] or sch2[  ], see below Section "Examples of Difference
Schemes".
:[font = subsection; inactive; ]
Step 3
:[font = text; inactive; ]
Specify the form of a nondimensional variable c1 = kappa in terms of which 
the stability region is to be determined. The corresponding transformation 
rule should follow the expression for the difference scheme (see the examples below) and should be in the same cell as the difference scheme itself. Load
and compile the difference scheme  together with the transformation rule.
:[font = subsection; inactive; ]
Step 4
:[font = text; inactive; ]
Specify the input data by entering them in the line (see also Section 
"Examples of the Input Data" below)
:[font = input; nowordwrap; ]

stab1[0.002, 4, 0.0, 1.5, sch1]
:[font = text; inactive; ]
Then click in this line and wait for the result of symbolic/numerical computation.
The meaning of the input parameters is explained in the Section
"Parameters Used in  Program st1.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; backColorRed = 65280; backColorGreen = 65280; backColorBlue = 65280; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; bold; fontName = "Courier"; fontSize = 12; ]
ClearAll[fbis, rel, iml, bisec];
fbis[x_, ss1_List, cc1_List, nspg_]:=
( fbs1 = 1.0; deps = N[1.0 + 1.0/(10^8)];
      j = 1; nspg1 = nspg;
Label[loop];
 rj = N[r /. {sa->ss1[[j]], ca->cc1[[j]], c1->x}];
   If[rj[[1]]> deps, nspg1 = j];
   j = j + 1; If[j <= nspg1, Goto[loop]];
   If[nspg1 < nspg, fbs1 = -1.0];Clear[j];fbs1 )
(* -- The function providing a list {Re(lambda(xi)),
      Im(lambda(xi))} for the Mathematica function
                         ParametricPlot  ------- *)

bisec[eps1_, ac1_, bc1_, ss1_List, cc1_List, nspg_]:=
(* -- This function determines the stability region
      boundary by the bisection method --------- *)
   ( fa = N[fbis[ac1, ss1, cc1, nspg]];
       fb = N[fbis[bc1, ss1, cc1, nspg]];
         isl = Sign[fa]; isr = Sign[fb];
      ac2 = ac1; bc2 = bc1;
    If[isl!= isr, Goto[bisproc]];
    If[isr== -1, Goto[unstable]];
Print["The scheme is stable in the interval ", ac1,
       "<= c1 <= ", bc1];
   xbs = bc1; Goto[endbis];
Label[unstable];
    Print["The scheme is unstable"];
    xbs = ac1; Goto[endbis];
Label[bisproc];
xbs = N[(ac2 + bc2)*0.5];
yy = N[fbis[xbs, ss1, cc1, nspg]];  ny = Sign[yy];
If[ny==isr, bc2=xbs, ac2=xbs];
If[N[Abs[ac2 - bc2]] >= eps1, Goto[bisproc]];
Label[endbis]; xbs )

ClearAll[stab1];
  stab1[eps_, n1plot_, ac1_, bc1_,sc_] := Module[
 {sc1, sc2, mt,rel,iml},
(* --- The representation of the difference solution
       in the form of a Fourier harmonic --------- *)

(* --- Substitution of a Fourier harmonic into the
       difference scheme ----------------------------- *)
Print["The difference scheme under consideration"];
Print[sc," = 0"];
(* -- Divide the both sides of obtained equation by
                                    l^n Exp[I*j*xi] -- *)
sc1=sc/.{u[j_,n_]->l^n Exp[I j xi]};
sc3 = sc1/(l^n*Exp[I*j*xi]) //Expand;
sc2 = Simplify[sc3];
sol = Solve[sc2==0, l];
l1 = Simplify[l /. sol];
Print["The amplification factor of scheme has the form"];
Print["lambda = ", l1];
rel=ComplexExpand[Re[l1]]/. c1rule //Simplify;
iml=ComplexExpand[Im[l1]]/. c1rule //Simplify;
  Print["Re(lambda) =",rel];
  Print["Im(lambda) =",iml];
      If[n1plot != 0,
(* --- Specification of the values of the
   nondimensional parameter c1 ----------- *)
      c1j = Table[N[2*j/n1plot], {j, n1plot}];
      Print["c1j=",c1j];
(* --- Storing the pictures in the elements mt[[j]],
                                  j = 1,...,n1plot - *)
       mt = {}; 
       Do[capp = c1j[[j]];
  zz1 = N[rel /. {c1 -> capp, xi -> t}];
  zz2 = N[iml /. {c1 -> capp, xi -> t}];
 mt1 = ParametricPlot[{zz1[[1]],zz2[[1]]},{t,0,2Pi},
                       DisplayFunction -> Identity];
mt2 = ParametricPlot[{Cos[t], Sin[t]}, {t, 0, 2Pi},
           PlotStyle ->{Dashing[{0.04,0.03}]},
           DisplayFunction -> Identity];
 obj= Polygon[Table[{Cos[n Pi/40],Sin[n Pi/40]},{n,80}]];
mt4 = Show[Graphics[{RGBColor[0.3,0.9,1], obj}],
           Axes -> True,
           Ticks -> Automatic,  
           DisplayFunction -> Identity]; 
mt3 = Show[mt4, mt1, mt2, 
           Axes -> True, Ticks -> Automatic,
           AspectRatio -> Automatic,  
           DisplayFunction -> $DisplayFunction];
AppendTo[mt, mt3],                     
                         {j, n1plot}];
Clear[gr];
If[n1plot == 2,
gr = Show[GraphicsArray[{mt[[1]], mt[[2]]}]] ];
If[n1plot == 3,
gr = Show[GraphicsArray[{{mt[[1]], mt[[2]]},
     {mt[[3]]}}]] ];
If[n1plot == 4,
gr = Show[GraphicsArray[{{mt[[1]], mt[[2]]},
                         {mt[[3]], mt[[4]]}}]] ];
If[n1plot == 5,
gr = Show[GraphicsArray[{{mt[[1]], mt[[2]], mt[[3]]},
                         {mt[[4]], mt[[5]]}}]] ];
If[n1plot == 6,
gr = Show[GraphicsArray[{{mt[[1]], mt[[2]], mt[[3]]},
                     {mt[[4]], mt[[5]], mt[[6]]}}]] ];
(* -- End of If[n1plot != 0... -------------------- *)
     ];
<<Algebra`Trigonometry`;
casa = {Cos[xi] -> ca, Sin[xi] -> sa};
iml = TrigReduce[iml]/.casa;
rel = TrigReduce[rel]/.casa;
Print["Re(lambda) = ", rel];
Print["Im(lambda) =", iml];
 r = rel^2 + iml^2 //Expand //Simplify;
    Print["|lambda|^2 =", r]; 

     (*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     %%                                      %%
     %%   The numerical stage of the method  %%
     %%                                      %%
     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*)
(* ------ Determination of nspg ------------- *)
  nspg0 = 2; c1sb = 10000; eps1 = eps;
     Do[nspg = nspg0 + 2*j; j1 = j;
   ss1 = Table[N[Sin[(k-1)*2*Pi/nspg]], {k, nspg}];
   cc1 = Table[N[Cos[(k-1)*2*Pi/nspg]], {k, nspg}];
  c1s0 = bisec[eps1, ac1, bc1, ss1, cc1, nspg];
dabsc1 = 100;
If[j1 > 1, dabsc1 = N[Abs[c1s0-c1sb]]];
   Print["nspg, cpold, cpnew,dabsc1 = ",
   nspg, "  ",c1sb,"  ",c1s0,"  ", dabsc1];
         If[dabsc1<eps, Break[]];
  c1sb = c1s0,
                {j, 48}];
   Print["j       Xj        sin(Xj)      cos(Xj)"];
Do[ss= ss1[[j]]; cc= cc1[[j]]; xj= N[(j - 1)*2*Pi/nspg];
     Print[j, "  ", xj, ,"  ", ss, , "  ", cc],
            {j, nspg}];
cap = Table[N[fbis[(k-1)*(bc1-ac1)/15,ss1,cc1,nspg]],
                    {k, 15}];
Print["The values of the binary function fbis(kappa)"];
Print[cap[[1]], cap[[2]], cap[[3]], cap[[4]], cap[[5]],
cap[[6]], cap[[7]], cap[[8]], cap[[9]], cap[[10]],
cap[[11]], cap[[12]], cap[[13]], cap[[14]], cap[[15]]];
c1s = bisec[eps1, ac1, bc1, ss1, cc1, nspg];
Print["The stability region boundary is ", c1s];
(* --------- End of the block ---------------- *)
	  ];


:[font = section; inactive; ]
Parameters Used in Program st1.ma
:[font = special5; inactive; nowordwrap; nohscroll; ]
____________________________________________________
 Parameter                                        Description
____________________________________________________
eps                     the given accuracy  of the computation of the
                           coordinates of points of the stability region
                           boundary;
n1plot                 the number of graphics pictures showing the
                           curves 
                           (Re[lambda(kappa,xi)], Im[lambda(kappa, xi)],
                           0<=xi<= 2Pi, where lambda(kappa, xi) is the
                           amplification factor; n1plot >= 0;
ac1                     the left end of the interval in which the stabil-
                           ity region is to be determined;
bc1                     the right end of the above interval
                           ac1 <= c1 <= bc1;
sc                       the left-hand side of the difference equation
                           sc = 0
____________________________________________________

:[font = section; inactive; ]
Examples of Difference Schemes
:[font = input; nowordwrap; ]
(* --  Attention! Only the letter j can be used to 
denote the number of the grid node on the x-axis,
and only the letter n can be used to denote the
time level. -------------------------------------- *)
ClearAll[sch1];
sch1 =
(* --- The upwind difference scheme for advection
       equation (2.1.1) ---- *)
(u[j,n+1] - u[j,n])/dt + a*(u[j,n] - u[j-1,n])/h

c1rule = {dt -> c1 h/a}
 
(* ----------- dt is the time step ----------- *)
:[font = message; inactive; formatted; output; nowordwrap; ]
Can't Format Cell


;[o]
General::spell1: 
   Possible spelling error: new symbol name "sch1"
     is similar to existing symbol "sc1".
:[font = output; inactive; formatted; output; nowordwrap; ]
(a*(-u[-1 + j, n] + u[j, n]))/h + (-u[j, n] + u[j, 1 + n])/dt


;[o]
a (-u[-1 + j, n] + u[j, n])   -u[j, n] + u[j, 1 + n]
--------------------------- + ----------------------
             h                          dt
:[font = output; inactive; formatted; output; nowordwrap; ]
{dt -> (c1*h)/a}


;[o]
       c1 h
{dt -> ----}
        a
:[font = input; nowordwrap; ]

(* --- Scheme of Jameson (1981) for advection 
   equation (2.1.1) -------------------------- *)
ClearAll[sch2];
sch2 = 
       (ut1 = (u[j,n+1] - u[j,n])/dt +
         a*(u[j+1,n] - u[j-1,n])/(2*h);
uxx = a^2*(u[j+2,n] -2*u[j,n] + u[j-2,n])*dt/(4*h^2);
ut1 - uxx )

c1rule = {dt -> c1 h/a}
:[font = input; nowordwrap; ]

(* Explicit difference scheme for the one-dimensional
   heat equation *)
ClearAll[sch3];
sch3 =
(u[j,n+1] - u[j,n])/dt -
nu*(u[j+1,n] - 2 u[j,n] + u[j-1,n])/(h^2)

c1rule = {dt -> c1*h^2/nu}

:[font = section; inactive; ]
Examples of the Input Data
:[font = subsection; inactive; ]
Example 1
:[font = input; nowordwrap; ]
stab1[0.002, 4, 0.0, 1.5, sch1]

:[font = print; inactive; formatted; output; nowordwrap; ]
No Input Form Generated

;[o]
The difference scheme under consideration
a (-u[-1 + j, n] + u[j, n])   -u[j, n] + u[j, 1 + n]
--------------------------- + ---------------------- = 0
             h                          dt
The amplification factor of scheme has the form
                           -I xi
              a dt   a dt E
lambda = {1 - ---- + -----------}
               h          h
Re(lambda) ={1 - c1 + c1 Cos[xi]}
Im(lambda) ={-(c1 Sin[xi])}
c1j={0.5, 1., 1.5, 2.}
Re(lambda) = {1 - c1 + ca c1}
Im(lambda) ={-(c1 sa)}
                                    2          2     2   2
|lambda|^2 ={1 - 2 c1 + 2 ca c1 + c1  - 2 ca c1  + ca  c1  + 
 
     2   2
   c1  sa }
nspg, cpold, cpnew,dabsc1 = 4  10000  1.00049  100
nspg, cpold, cpnew,dabsc1 = 6  1.00049  1.00049  0.
j       Xj        sin(Xj)      cos(Xj)
1  0Null  0Null  1.
2  1.0472Null  0.866025Null  0.5
3  2.0944Null  0.866025Null  -0.5
4  3.14159Null  0Null  -1.
5  4.18879Null  -0.866025Null  -0.5
6  5.23599Null  -0.866025Null  0.5
The values of the binary function fbis(kappa)
1.1.1.1.1.1.1.1.1.1.1.-1.-1.-1.-1.
The stability region boundary is 1.00049
:[font = postscript; inactive; output; BITMAP; PostScript; pictureLeft = 100; pictureTop = 0; pictureWidth = 300; pictureHeight = 300; nowordwrap; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.5 0.31746 [
[(-2)] .02381 .5 0 2 Msboxa
[(-1.5)] .18254 .5 0 2 Msboxa
[(-1)] .34127 .5 0 2 Msboxa
[(-0.5)] .5 .5 0 2 Msboxa
[(0.5)] .81746 .5 0 2 Msboxa
[(1)] .97619 .5 0 2 Msboxa
[(-1.5)] .64623 .02381 1 0 Msboxa
[(-1)] .64623 .18254 1 0 Msboxa
[(-0.5)] .64623 .34127 1 0 Msboxa
[(0.5)] .64623 .65873 1 0 Msboxa
[(1)] .64623 .81746 1 0 Msboxa
[(1.5)] .64623 .97619 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.02381 .5 m
.02381 .50625 L
s
P
[(-2)] .02381 .5 0 2 Mshowa
p
.002 w
.18254 .5 m
.18254 .50625 L
s
P
[(-1.5)] .18254 .5 0 2 Mshowa
p
.002 w
.34127 .5 m
.34127 .50625 L
s
P
[(-1)] .34127 .5 0 2 Mshowa
p
.002 w
.5 .5 m
.5 .50625 L
s
P
[(-0.5)] .5 .5 0 2 Mshowa
p
.002 w
.81746 .5 m
.81746 .50625 L
s
P
[(0.5)] .81746 .5 0 2 Mshowa
p
.002 w
.97619 .5 m
.97619 .50625 L
s
P
[(1)] .97619 .5 0 2 Mshowa
p
.001 w
.05556 .5 m
.05556 .50375 L
s
P
p
.001 w
.0873 .5 m
.0873 .50375 L
s
P
p
.001 w
.11905 .5 m
.11905 .50375 L
s
P
p
.001 w
.15079 .5 m
.15079 .50375 L
s
P
p
.001 w
.21429 .5 m
.21429 .50375 L
s
P
p
.001 w
.24603 .5 m
.24603 .50375 L
s
P
p
.001 w
.27778 .5 m
.27778 .50375 L
s
P
p
.001 w
.30952 .5 m
.30952 .50375 L
s
P
p
.001 w
.37302 .5 m
.37302 .50375 L
s
P
p
.001 w
.40476 .5 m
.40476 .50375 L
s
P
p
.001 w
.43651 .5 m
.43651 .50375 L
s
P
p
.001 w
.46825 .5 m
.46825 .50375 L
s
P
p
.001 w
.53175 .5 m
.53175 .50375 L
s
P
p
.001 w
.56349 .5 m
.56349 .50375 L
s
P
p
.001 w
.59524 .5 m
.59524 .50375 L
s
P
p
.001 w
.62698 .5 m
.62698 .50375 L
s
P
p
.001 w
.69048 .5 m
.69048 .50375 L
s
P
p
.001 w
.72222 .5 m
.72222 .50375 L
s
P
p
.001 w
.75397 .5 m
.75397 .50375 L
s
P
p
.001 w
.78571 .5 m
.78571 .50375 L
s
P
p
.001 w
.84921 .5 m
.84921 .50375 L
s
P
p
.001 w
.88095 .5 m
.88095 .50375 L
s
P
p
.001 w
.9127 .5 m
.9127 .50375 L
s
P
p
.001 w
.94444 .5 m
.94444 .50375 L
s
P
p
.002 w
0 .5 m
1 .5 L
s
P
p
.002 w
.65873 .02381 m
.66498 .02381 L
s
P
[(-1.5)] .64623 .02381 1 0 Mshowa
p
.002 w
.65873 .18254 m
.66498 .18254 L
s
P
[(-1)] .64623 .18254 1 0 Mshowa
p
.002 w
.65873 .34127 m
.66498 .34127 L
s
P
[(-0.5)] .64623 .34127 1 0 Mshowa
p
.002 w
.65873 .65873 m
.66498 .65873 L
s
P
[(0.5)] .64623 .65873 1 0 Mshowa
p
.002 w
.65873 .81746 m
.66498 .81746 L
s
P
[(1)] .64623 .81746 1 0 Mshowa
p
.002 w
.65873 .97619 m
.66498 .97619 L
s
P
[(1.5)] .64623 .97619 1 0 Mshowa
p
.001 w
.65873 .05556 m
.66248 .05556 L
s
P
p
.001 w
.65873 .0873 m
.66248 .0873 L
s
P
p
.001 w
.65873 .11905 m
.66248 .11905 L
s
P
p
.001 w
.65873 .15079 m
.66248 .15079 L
s
P
p
.001 w
.65873 .21429 m
.66248 .21429 L
s
P
p
.001 w
.65873 .24603 m
.66248 .24603 L
s
P
p
.001 w
.65873 .27778 m
.66248 .27778 L
s
P
p
.001 w
.65873 .30952 m
.66248 .30952 L
s
P
p
.001 w
.65873 .37302 m
.66248 .37302 L
s
P
p
.001 w
.65873 .40476 m
.66248 .40476 L
s
P
p
.001 w
.65873 .43651 m
.66248 .43651 L
s
P
p
.001 w
.65873 .46825 m
.66248 .46825 L
s
P
p
.001 w
.65873 .53175 m
.66248 .53175 L
s
P
p
.001 w
.65873 .56349 m
.66248 .56349 L
s
P
p
.001 w
.65873 .59524 m
.66248 .59524 L
s
P
p
.001 w
.65873 .62698 m
.66248 .62698 L
s
P
p
.001 w
.65873 .69048 m
.66248 .69048 L
s
P
p
.001 w
.65873 .72222 m
.66248 .72222 L
s
P
p
.001 w
.65873 .75397 m
.66248 .75397 L
s
P
p
.001 w
.65873 .78571 m
.66248 .78571 L
s
P
p
.001 w
.65873 .84921 m
.66248 .84921 L
s
P
p
.001 w
.65873 .88095 m
.66248 .88095 L
s
P
p
.001 w
.65873 .9127 m
.66248 .9127 L
s
P
p
.001 w
.65873 .94444 m
.66248 .94444 L
s
P
p
.002 w
.65873 0 m
.65873 1 L
s
P
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
.3 .9 1 r
.97521 .52491 m
.97228 .54966 L
.96742 .57411 L
.96065 .5981 L
.95203 .62149 L
.94159 .64412 L
.92941 .66587 L
.91556 .6866 L
.90013 .70617 L
.88321 .72448 L
.8649 .7414 L
.84533 .75683 L
.8246 .77068 L
.80285 .78286 L
.78022 .7933 L
.75683 .80192 L
.73284 .80869 L
.70839 .81355 L
.68364 .81648 L
.65873 .81746 L
.63382 .81648 L
.60907 .81355 L
.58462 .80869 L
.56063 .80192 L
.53724 .7933 L
.51461 .78286 L
.49286 .77068 L
.47213 .75683 L
.45256 .7414 L
.43425 .72448 L
.41733 .70617 L
.4019 .6866 L
.38805 .66587 L
.37587 .64412 L
.36544 .62149 L
.35681 .5981 L
.35004 .57411 L
.34518 .54966 L
.34225 .52491 L
.34127 .5 L
.34225 .47509 L
.34518 .45034 L
.35004 .42589 L
.35681 .4019 L
.36544 .37851 L
.37587 .35588 L
.38805 .33413 L
.4019 .3134 L
.41733 .29383 L
.43425 .27552 L
.45256 .2586 L
.47213 .24317 L
.49286 .22932 L
.51461 .21714 L
.53724 .2067 L
.56063 .19808 L
.58462 .19131 L
.60907 .18645 L
.63382 .18352 L
.65873 .18254 L
.68364 .18352 L
.70839 .18645 L
.73284 .19131 L
.75683 .19808 L
.78022 .2067 L
.80285 .21714 L
.8246 .22932 L
.84533 .24317 L
.8649 .2586 L
.88321 .27552 L
.90013 .29383 L
.91556 .3134 L
.92941 .33413 L
.94159 .35588 L
.95203 .37851 L
.96065 .4019 L
.96742 .42589 L
.97228 .45034 L
.97521 .47509 L
.97619 .5 L
F
P
p
p
.004 w
.97619 .5 m
.97617 .4961 L
.97613 .49221 L
.97605 .48831 L
.97594 .48442 L
.97579 .48053 L
.97562 .47663 L
.97517 .46886 L
.9746 .46109 L
.9739 .45333 L
.97212 .43784 L
.96983 .42243 L
.96704 .4071 L
.95996 .37675 L
.95092 .34693 L
.93994 .31777 L
.91239 .2619 L
.87779 .21011 L
.83672 .16328 L
.78989 .12221 L
.7381 .08761 L
.71061 .07292 L
.68223 .06006 L
.65307 .04908 L
.62325 .04004 L
.5929 .03296 L
.57757 .03017 L
.56216 .02788 L
.54667 .0261 L
.53891 .0254 L
.53114 .02483 L
.52337 .02438 L
.51947 .02421 L
.51558 .02406 L
.51169 .02395 L
.50779 .02387 L
.5039 .02383 L
.5 .02381 L
.4961 .02383 L
.49221 .02387 L
.48831 .02395 L
.48442 .02406 L
.47663 .02438 L
.46886 .02483 L
.46109 .0254 L
.45333 .0261 L
.43784 .02788 L
.42243 .03017 L
.4071 .03296 L
.37675 .04004 L
Mistroke
.34693 .04908 L
.31777 .06006 L
.2619 .08761 L
.21011 .12221 L
.16328 .16328 L
.12221 .21011 L
.08761 .2619 L
.07292 .28939 L
.06006 .31777 L
.04908 .34693 L
.04004 .37675 L
.03296 .4071 L
.03017 .42243 L
.02788 .43784 L
.0261 .45333 L
.0254 .46109 L
.02483 .46886 L
.02438 .47663 L
.02421 .48053 L
.02406 .48442 L
.02395 .48831 L
.02387 .49221 L
.02383 .4961 L
.02381 .5 L
.02383 .5039 L
.02387 .50779 L
.02395 .51169 L
.02406 .51558 L
.02421 .51947 L
.02438 .52337 L
.02483 .53114 L
.0254 .53891 L
.0261 .54667 L
.02788 .56216 L
.03017 .57757 L
.03296 .5929 L
.04004 .62325 L
.04908 .65307 L
.06006 .68223 L
.08761 .7381 L
.12221 .78989 L
.16328 .83672 L
.21011 .87779 L
.2619 .91239 L
.28939 .92708 L
.31777 .93994 L
.34693 .95092 L
.37675 .95996 L
.4071 .96704 L
.42243 .96983 L
Mistroke
.43784 .97212 L
.45333 .9739 L
.46109 .9746 L
.46886 .97517 L
.47663 .97562 L
.48053 .97579 L
.48442 .97594 L
.48831 .97605 L
.49221 .97613 L
.4961 .97617 L
.5 .97619 L
.5039 .97617 L
.50779 .97613 L
.51169 .97605 L
.51558 .97594 L
.52337 .97562 L
.53114 .97517 L
.53891 .9746 L
.54667 .9739 L
.56216 .97212 L
.57757 .96983 L
.5929 .96704 L
.62325 .95996 L
.65307 .95092 L
.68223 .93994 L
.7381 .91239 L
.78989 .87779 L
.83672 .83672 L
.87779 .78989 L
.91239 .7381 L
.92708 .71061 L
.93994 .68223 L
.95092 .65307 L
.95996 .62325 L
.96704 .5929 L
.96983 .57757 L
.97212 .56216 L
.9739 .54667 L
.9746 .53891 L
.97517 .53114 L
.97562 .52337 L
.97579 .51947 L
.97594 .51558 L
.97605 .51169 L
.97613 .50779 L
.97617 .5039 L
.97619 .5 L
Mfstroke
P
P
p
[ .04 .03 ] 0 setdash
p
.004 w
.97619 .5 m
.97618 .5026 L
.97615 .50519 L
.97609 .50779 L
.97602 .51039 L
.97592 .51298 L
.97581 .51558 L
.97551 .52076 L
.97513 .52594 L
.97466 .53112 L
.97347 .54144 L
.97195 .55171 L
.97009 .56193 L
.96537 .58216 L
.95934 .60204 L
.95203 .62149 L
.93366 .65873 L
.91059 .69326 L
.88321 .72448 L
.85199 .75186 L
.81746 .77493 L
.79914 .78472 L
.78022 .7933 L
.76077 .80061 L
.74089 .80664 L
.72066 .81136 L
.71044 .81322 L
.70017 .81474 L
.68985 .81593 L
.68467 .8164 L
.67949 .81678 L
.67431 .81708 L
.67171 .81719 L
.66912 .81729 L
.66652 .81736 L
.66392 .81742 L
.66133 .81745 L
.65873 .81746 L
.65613 .81745 L
.65354 .81742 L
.65094 .81736 L
.64834 .81729 L
.64315 .81708 L
.63797 .81678 L
.63279 .8164 L
.62761 .81593 L
.61729 .81474 L
.60702 .81322 L
.5968 .81136 L
.57657 .80664 L
Mistroke
.55669 .80061 L
.53724 .7933 L
.5 .77493 L
.46547 .75186 L
.43425 .72448 L
.40687 .69326 L
.3838 .65873 L
.37401 .64041 L
.36544 .62149 L
.35812 .60204 L
.35209 .58216 L
.34737 .56193 L
.34551 .55171 L
.34399 .54144 L
.3428 .53112 L
.34233 .52594 L
.34195 .52076 L
.34165 .51558 L
.34154 .51298 L
.34144 .51039 L
.34137 .50779 L
.34131 .50519 L
.34128 .5026 L
.34127 .5 L
.34128 .4974 L
.34131 .49481 L
.34137 .49221 L
.34144 .48961 L
.34154 .48702 L
.34165 .48442 L
.34195 .47924 L
.34233 .47406 L
.3428 .46888 L
.34399 .45856 L
.34551 .44829 L
.34737 .43807 L
.35209 .41784 L
.35812 .39796 L
.36544 .37851 L
.3838 .34127 L
.40687 .30674 L
.43425 .27552 L
.46547 .24814 L
.5 .22507 L
.51832 .21528 L
.53724 .2067 L
.55669 .19939 L
.57657 .19336 L
.5968 .18864 L
.60702 .18678 L
Mistroke
.61729 .18526 L
.62761 .18407 L
.63279 .1836 L
.63797 .18322 L
.64315 .18292 L
.64575 .18281 L
.64834 .18271 L
.65094 .18264 L
.65354 .18258 L
.65613 .18255 L
.65873 .18254 L
.66133 .18255 L
.66392 .18258 L
.66652 .18264 L
.66912 .18271 L
.67431 .18292 L
.67949 .18322 L
.68467 .1836 L
.68985 .18407 L
.70017 .18526 L
.71044 .18678 L
.72066 .18864 L
.74089 .19336 L
.76077 .19939 L
.78022 .2067 L
.81746 .22507 L
.85199 .24814 L
.88321 .27552 L
.91059 .30674 L
.93366 .34127 L
.94345 .35959 L
.95203 .37851 L
.95934 .39796 L
.96537 .41784 L
.97009 .43807 L
.97195 .44829 L
.97347 .45856 L
.97466 .46888 L
.97513 .47406 L
.97551 .47924 L
.97581 .48442 L
.97592 .48702 L
.97602 .48961 L
.97609 .49221 L
.97615 .49481 L
.97618 .4974 L
.97619 .5 L
Mfstroke
P
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.238095 0.5 0.238095 [
[(-3)] .02381 .5 0 2 Msboxa
[(-2)] .2619 .5 0 2 Msboxa
[(-1)] .5 .5 0 2 Msboxa
[(1)] .97619 .5 0 2 Msboxa
[(-2)] .7256 .02381 1 0 Msboxa
[(-1)] .7256 .2619 1 0 Msboxa
[(1)] .7256 .7381 1 0 Msboxa
[(2)] .7256 .97619 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.02381 .5 m
.02381 .50625 L
s
P
[(-3)] .02381 .5 0 2 Mshowa
p
.002 w
.2619 .5 m
.2619 .50625 L
s
P
[(-2)] .2619 .5 0 2 Mshowa
p
.002 w
.5 .5 m
.5 .50625 L
s
P
[(-1)] .5 .5 0 2 Mshowa
p
.002 w
.97619 .5 m
.97619 .50625 L
s
P
[(1)] .97619 .5 0 2 Mshowa
p
.001 w
.07143 .5 m
.07143 .50375 L
s
P
p
.001 w
.11905 .5 m
.11905 .50375 L
s
P
p
.001 w
.16667 .5 m
.16667 .50375 L
s
P
p
.001 w
.21429 .5 m
.21429 .50375 L
s
P
p
.001 w
.30952 .5 m
.30952 .50375 L
s
P
p
.001 w
.35714 .5 m
.35714 .50375 L
s
P
p
.001 w
.40476 .5 m
.40476 .50375 L
s
P
p
.001 w
.45238 .5 m
.45238 .50375 L
s
P
p
.001 w
.54762 .5 m
.54762 .50375 L
s
P
p
.001 w
.59524 .5 m
.59524 .50375 L
s
P
p
.001 w
.64286 .5 m
.64286 .50375 L
s
P
p
.001 w
.69048 .5 m
.69048 .50375 L
s
P
p
.001 w
.78571 .5 m
.78571 .50375 L
s
P
p
.001 w
.83333 .5 m
.83333 .50375 L
s
P
p
.001 w
.88095 .5 m
.88095 .50375 L
s
P
p
.001 w
.92857 .5 m
.92857 .50375 L
s
P
p
.002 w
0 .5 m
1 .5 L
s
P
p
.002 w
.7381 .02381 m
.74435 .02381 L
s
P
[(-2)] .7256 .02381 1 0 Mshowa
p
.002 w
.7381 .2619 m
.74435 .2619 L
s
P
[(-1)] .7256 .2619 1 0 Mshowa
p
.002 w
.7381 .7381 m
.74435 .7381 L
s
P
[(1)] .7256 .7381 1 0 Mshowa
p
.002 w
.7381 .97619 m
.74435 .97619 L
s
P
[(2)] .7256 .97619 1 0 Mshowa
p
.001 w
.7381 .07143 m
.74185 .07143 L
s
P
p
.001 w
.7381 .11905 m
.74185 .11905 L
s
P
p
.001 w
.7381 .16667 m
.74185 .16667 L
s
P
p
.001 w
.7381 .21429 m
.74185 .21429 L
s
P
p
.001 w
.7381 .30952 m
.74185 .30952 L
s
P
p
.001 w
.7381 .35714 m
.74185 .35714 L
s
P
p
.001 w
.7381 .40476 m
.74185 .40476 L
s
P
p
.001 w
.7381 .45238 m
.74185 .45238 L
s
P
p
.001 w
.7381 .54762 m
.74185 .54762 L
s
P
p
.001 w
.7381 .59524 m
.74185 .59524 L
s
P
p
.001 w
.7381 .64286 m
.74185 .64286 L
s
P
p
.001 w
.7381 .69048 m
.74185 .69048 L
s
P
p
.001 w
.7381 .78571 m
.74185 .78571 L
s
P
p
.001 w
.7381 .83333 m
.74185 .83333 L
s
P
p
.001 w
.7381 .88095 m
.74185 .88095 L
s
P
p
.001 w
.7381 .92857 m
.74185 .92857 L
s
P
p
.002 w
.7381 0 m
.7381 1 L
s
P
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
.3 .9 1 r
.97546 .51868 m
.97326 .53725 L
.96961 .55558 L
.96454 .57358 L
.95807 .59112 L
.95024 .60809 L
.9411 .6244 L
.93072 .63995 L
.91914 .65463 L
.90645 .66836 L
.89273 .68105 L
.87804 .69262 L
.8625 .70301 L
.84619 .71214 L
.82921 .71997 L
.81167 .72644 L
.79368 .73152 L
.77534 .73516 L
.75678 .73736 L
.7381 .7381 L
.71941 .73736 L
.70085 .73516 L
.68251 .73152 L
.66452 .72644 L
.64698 .71997 L
.63 .71214 L
.61369 .70301 L
.59815 .69262 L
.58346 .68105 L
.56974 .66836 L
.55705 .65463 L
.54547 .63995 L
.53509 .6244 L
.52595 .60809 L
.51812 .59112 L
.51165 .57358 L
.50658 .55558 L
.50293 .53725 L
.50073 .51868 L
.5 .5 L
.50073 .48132 L
.50293 .46275 L
.50658 .44442 L
.51165 .42642 L
.51812 .40888 L
.52595 .39191 L
.53509 .3756 L
.54547 .36005 L
.55705 .34537 L
.56974 .33164 L
.58346 .31895 L
.59815 .30738 L
.61369 .29699 L
.63 .28786 L
.64698 .28003 L
.66452 .27356 L
.68251 .26848 L
.70085 .26484 L
.71941 .26264 L
.7381 .2619 L
.75678 .26264 L
.77534 .26484 L
.79368 .26848 L
.81167 .27356 L
.82921 .28003 L
.84619 .28786 L
.8625 .29699 L
.87804 .30738 L
.89273 .31895 L
.90645 .33164 L
.91914 .34537 L
.93072 .36005 L
.9411 .3756 L
.95024 .39191 L
.95807 .40888 L
.96454 .42642 L
.96961 .44442 L
.97326 .46275 L
.97546 .48132 L
.97619 .5 L
F
P
p
p
.004 w
.97619 .5 m
.97617 .4961 L
.97613 .49221 L
.97605 .48831 L
.97594 .48442 L
.97579 .48053 L
.97562 .47663 L
.97517 .46886 L
.9746 .46109 L
.9739 .45333 L
.97212 .43784 L
.96983 .42243 L
.96704 .4071 L
.95996 .37675 L
.95092 .34693 L
.93994 .31777 L
.91239 .2619 L
.87779 .21011 L
.83672 .16328 L
.78989 .12221 L
.7381 .08761 L
.71061 .07292 L
.68223 .06006 L
.65307 .04908 L
.62325 .04004 L
.5929 .03296 L
.57757 .03017 L
.56216 .02788 L
.54667 .0261 L
.53891 .0254 L
.53114 .02483 L
.52337 .02438 L
.51947 .02421 L
.51558 .02406 L
.51169 .02395 L
.50779 .02387 L
.5039 .02383 L
.5 .02381 L
.4961 .02383 L
.49221 .02387 L
.48831 .02395 L
.48442 .02406 L
.47663 .02438 L
.46886 .02483 L
.46109 .0254 L
.45333 .0261 L
.43784 .02788 L
.42243 .03017 L
.4071 .03296 L
.37675 .04004 L
Mistroke
.34693 .04908 L
.31777 .06006 L
.2619 .08761 L
.21011 .12221 L
.16328 .16328 L
.12221 .21011 L
.08761 .2619 L
.07292 .28939 L
.06006 .31777 L
.04908 .34693 L
.04004 .37675 L
.03296 .4071 L
.03017 .42243 L
.02788 .43784 L
.0261 .45333 L
.0254 .46109 L
.02483 .46886 L
.02438 .47663 L
.02421 .48053 L
.02406 .48442 L
.02395 .48831 L
.02387 .49221 L
.02383 .4961 L
.02381 .5 L
.02383 .5039 L
.02387 .50779 L
.02395 .51169 L
.02406 .51558 L
.02421 .51947 L
.02438 .52337 L
.02483 .53114 L
.0254 .53891 L
.0261 .54667 L
.02788 .56216 L
.03017 .57757 L
.03296 .5929 L
.04004 .62325 L
.04908 .65307 L
.06006 .68223 L
.08761 .7381 L
.12221 .78989 L
.16328 .83672 L
.21011 .87779 L
.2619 .91239 L
.28939 .92708 L
.31777 .93994 L
.34693 .95092 L
.37675 .95996 L
.4071 .96704 L
.42243 .96983 L
Mistroke
.43784 .97212 L
.45333 .9739 L
.46109 .9746 L
.46886 .97517 L
.47663 .97562 L
.48053 .97579 L
.48442 .97594 L
.48831 .97605 L
.49221 .97613 L
.4961 .97617 L
.5 .97619 L
.5039 .97617 L
.50779 .97613 L
.51169 .97605 L
.51558 .97594 L
.52337 .97562 L
.53114 .97517 L
.53891 .9746 L
.54667 .9739 L
.56216 .97212 L
.57757 .96983 L
.5929 .96704 L
.62325 .95996 L
.65307 .95092 L
.68223 .93994 L
.7381 .91239 L
.78989 .87779 L
.83672 .83672 L
.87779 .78989 L
.91239 .7381 L
.92708 .71061 L
.93994 .68223 L
.95092 .65307 L
.95996 .62325 L
.96704 .5929 L
.96983 .57757 L
.97212 .56216 L
.9739 .54667 L
.9746 .53891 L
.97517 .53114 L
.97562 .52337 L
.97579 .51947 L
.97594 .51558 L
.97605 .51169 L
.97613 .50779 L
.97617 .5039 L
.97619 .5 L
Mfstroke
P
P
p
[ .04 .03 ] 0 setdash
p
.004 w
.97619 .5 m
.97618 .50195 L
.97616 .5039 L
.97612 .50584 L
.97606 .50779 L
.97599 .50974 L
.9759 .51168 L
.97568 .51557 L
.97539 .51946 L
.97504 .52334 L
.97415 .53108 L
.97301 .53878 L
.97162 .54645 L
.96808 .56162 L
.96355 .57653 L
.95807 .59112 L
.94429 .61905 L
.92699 .64494 L
.90645 .66836 L
.88304 .68889 L
.85714 .7062 L
.8434 .71354 L
.82921 .71997 L
.81463 .72546 L
.79972 .72998 L
.78455 .73352 L
.77688 .73492 L
.76917 .73606 L
.76143 .73695 L
.75755 .7373 L
.75367 .73759 L
.74978 .73781 L
.74783 .7379 L
.74589 .73797 L
.74394 .73802 L
.74199 .73806 L
.74004 .73809 L
.7381 .7381 L
.73615 .73809 L
.7342 .73806 L
.73225 .73802 L
.7303 .73797 L
.72641 .73781 L
.72252 .73759 L
.71864 .7373 L
.71476 .73695 L
.70702 .73606 L
.69931 .73492 L
.69165 .73352 L
.67647 .72998 L
Mistroke
.66156 .72546 L
.64698 .71997 L
.61905 .7062 L
.59315 .68889 L
.56974 .66836 L
.5492 .64494 L
.5319 .61905 L
.52455 .60531 L
.51812 .59112 L
.51264 .57653 L
.50811 .56162 L
.50457 .54645 L
.50318 .53878 L
.50204 .53108 L
.50115 .52334 L
.5008 .51946 L
.50051 .51557 L
.50029 .51168 L
.5002 .50974 L
.50013 .50779 L
.50007 .50584 L
.50003 .5039 L
.50001 .50195 L
.5 .5 L
.50001 .49805 L
.50003 .4961 L
.50007 .49416 L
.50013 .49221 L
.5002 .49026 L
.50029 .48832 L
.50051 .48443 L
.5008 .48054 L
.50115 .47666 L
.50204 .46892 L
.50318 .46122 L
.50457 .45355 L
.50811 .43838 L
.51264 .42347 L
.51812 .40888 L
.5319 .38095 L
.5492 .35506 L
.56974 .33164 L
.59315 .31111 L
.61905 .2938 L
.63279 .28646 L
.64698 .28003 L
.66156 .27454 L
.67647 .27002 L
.69165 .26648 L
.69931 .26508 L
Mistroke
.70702 .26394 L
.71476 .26305 L
.71864 .2627 L
.72252 .26241 L
.72641 .26219 L
.72836 .2621 L
.7303 .26203 L
.73225 .26198 L
.7342 .26194 L
.73615 .26191 L
.7381 .2619 L
.74004 .26191 L
.74199 .26194 L
.74394 .26198 L
.74589 .26203 L
.74978 .26219 L
.75367 .26241 L
.75755 .2627 L
.76143 .26305 L
.76917 .26394 L
.77688 .26508 L
.78455 .26648 L
.79972 .27002 L
.81463 .27454 L
.82921 .28003 L
.85714 .2938 L
.88304 .31111 L
.90645 .33164 L
.92699 .35506 L
.94429 .38095 L
.95164 .39469 L
.95807 .40888 L
.96355 .42347 L
.96808 .43838 L
.97162 .45355 L
.97301 .46122 L
.97415 .46892 L
.97504 .47666 L
.97539 .48054 L
.97568 .48443 L
.9759 .48832 L
.97599 .49026 L
.97606 .49221 L
.97612 .49416 L
.97616 .4961 L
.97618 .49805 L
.97619 .5 L
Mfstroke
P
P
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[(-1)] .02381 .5 0 2 Msboxa
[(-0.5)] .2619 .5 0 2 Msboxa
[(0.5)] .7381 .5 0 2 Msboxa
[(1)] .97619 .5 0 2 Msboxa
[(-1)] .4875 .02381 1 0 Msboxa
[(-0.5)] .4875 .2619 1 0 Msboxa
[(0.5)] .4875 .7381 1 0 Msboxa
[(1)] .4875 .97619 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.02381 .5 m
.02381 .50625 L
s
P
[(-1)] .02381 .5 0 2 Mshowa
p
.002 w
.2619 .5 m
.2619 .50625 L
s
P
[(-0.5)] .2619 .5 0 2 Mshowa
p
.002 w
.7381 .5 m
.7381 .50625 L
s
P
[(0.5)] .7381 .5 0 2 Mshowa
p
.002 w
.97619 .5 m
.97619 .50625 L
s
P
[(1)] .97619 .5 0 2 Mshowa
p
.001 w
.07143 .5 m
.07143 .50375 L
s
P
p
.001 w
.11905 .5 m
.11905 .50375 L
s
P
p
.001 w
.16667 .5 m
.16667 .50375 L
s
P
p
.001 w
.21429 .5 m
.21429 .50375 L
s
P
p
.001 w
.30952 .5 m
.30952 .50375 L
s
P
p
.001 w
.35714 .5 m
.35714 .50375 L
s
P
p
.001 w
.40476 .5 m
.40476 .50375 L
s
P
p
.001 w
.45238 .5 m
.45238 .50375 L
s
P
p
.001 w
.54762 .5 m
.54762 .50375 L
s
P
p
.001 w
.59524 .5 m
.59524 .50375 L
s
P
p
.001 w
.64286 .5 m
.64286 .50375 L
s
P
p
.001 w
.69048 .5 m
.69048 .50375 L
s
P
p
.001 w
.78571 .5 m
.78571 .50375 L
s
P
p
.001 w
.83333 .5 m
.83333 .50375 L
s
P
p
.001 w
.88095 .5 m
.88095 .50375 L
s
P
p
.001 w
.92857 .5 m
.92857 .50375 L
s
P
p
.002 w
0 .5 m
1 .5 L
s
P
p
.002 w
.5 .02381 m
.50625 .02381 L
s
P
[(-1)] .4875 .02381 1 0 Mshowa
p
.002 w
.5 .2619 m
.50625 .2619 L
s
P
[(-0.5)] .4875 .2619 1 0 Mshowa
p
.002 w
.5 .7381 m
.50625 .7381 L
s
P
[(0.5)] .4875 .7381 1 0 Mshowa
p
.002 w
.5 .97619 m
.50625 .97619 L
s
P
[(1)] .4875 .97619 1 0 Mshowa
p
.001 w
.5 .07143 m
.50375 .07143 L
s
P
p
.001 w
.5 .11905 m
.50375 .11905 L
s
P
p
.001 w
.5 .16667 m
.50375 .16667 L
s
P
p
.001 w
.5 .21429 m
.50375 .21429 L
s
P
p
.001 w
.5 .30952 m
.50375 .30952 L
s
P
p
.001 w
.5 .35714 m
.50375 .35714 L
s
P
p
.001 w
.5 .40476 m
.50375 .40476 L
s
P
p
.001 w
.5 .45238 m
.50375 .45238 L
s
P
p
.001 w
.5 .54762 m
.50375 .54762 L
s
P
p
.001 w
.5 .59524 m
.50375 .59524 L
s
P
p
.001 w
.5 .64286 m
.50375 .64286 L
s
P
p
.001 w
.5 .69048 m
.50375 .69048 L
s
P
p
.001 w
.5 .78571 m
.50375 .78571 L
s
P
p
.001 w
.5 .83333 m
.50375 .83333 L
s
P
p
.001 w
.5 .88095 m
.50375 .88095 L
s
P
p
.001 w
.5 .92857 m
.50375 .92857 L
s
P
p
.002 w
.5 0 m
.5 1 L
s
P
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
.3 .9 1 r
.97472 .53736 m
.97033 .57449 L
.96303 .61116 L
.95288 .64715 L
.93994 .68223 L
.92429 .71619 L
.90602 .74881 L
.88525 .7799 L
.8621 .80926 L
.83672 .83672 L
.80926 .8621 L
.7799 .88525 L
.74881 .90602 L
.71619 .92429 L
.68223 .93994 L
.64715 .95288 L
.61116 .96303 L
.57449 .97033 L
.53736 .97472 L
.5 .97619 L
.46264 .97472 L
.42551 .97033 L
.38884 .96303 L
.35285 .95288 L
.31777 .93994 L
.28381 .92429 L
.25119 .90602 L
.2201 .88525 L
.19074 .8621 L
.16328 .83672 L
.1379 .80926 L
.11475 .7799 L
.09398 .74881 L
.07571 .71619 L
.06006 .68223 L
.04712 .64715 L
.03697 .61116 L
.02967 .57449 L
.02528 .53736 L
.02381 .5 L
.02528 .46264 L
.02967 .42551 L
.03697 .38884 L
.04712 .35285 L
.06006 .31777 L
.07571 .28381 L
.09398 .25119 L
.11475 .2201 L
.1379 .19074 L
.16328 .16328 L
.19074 .1379 L
.2201 .11475 L
.25119 .09398 L
.28381 .07571 L
.31777 .06006 L
.35285 .04712 L
.38884 .03697 L
.42551 .02967 L
.46264 .02528 L
.5 .02381 L
.53736 .02528 L
.57449 .02967 L
.61116 .03697 L
.64715 .04712 L
.68223 .06006 L
.71619 .07571 L
.74881 .09398 L
.7799 .11475 L
.80926 .1379 L
.83672 .16328 L
.8621 .19074 L
.88525 .2201 L
.90602 .25119 L
.92429 .28381 L
.93994 .31777 L
.95288 .35285 L
.96303 .38884 L
.97033 .42551 L
.97472 .46264 L
.97619 .5 L
F
P
p
p
.004 w
.97619 .5 m
.97618 .49805 L
.97616 .4961 L
.97612 .49416 L
.97606 .49221 L
.97599 .49026 L
.9759 .48832 L
.97568 .48443 L
.97539 .48054 L
.97504 .47666 L
.97415 .46892 L
.97301 .46122 L
.97162 .45355 L
.96808 .43838 L
.96355 .42347 L
.95807 .40888 L
.94429 .38095 L
.92699 .35506 L
.90645 .33164 L
.88304 .31111 L
.85714 .2938 L
.8434 .28646 L
.82921 .28003 L
.81463 .27454 L
.79972 .27002 L
.78455 .26648 L
.77688 .26508 L
.76917 .26394 L
.76143 .26305 L
.75755 .2627 L
.75367 .26241 L
.74978 .26219 L
.74783 .2621 L
.74589 .26203 L
.74394 .26198 L
.74199 .26194 L
.74004 .26191 L
.7381 .2619 L
.73615 .26191 L
.7342 .26194 L
.73225 .26198 L
.7303 .26203 L
.72641 .26219 L
.72252 .26241 L
.71864 .2627 L
.71476 .26305 L
.70702 .26394 L
.69931 .26508 L
.69165 .26648 L
.67647 .27002 L
Mistroke
.66156 .27454 L
.64698 .28003 L
.61905 .2938 L
.59315 .31111 L
.56974 .33164 L
.5492 .35506 L
.5319 .38095 L
.52455 .39469 L
.51812 .40888 L
.51264 .42347 L
.50811 .43838 L
.50457 .45355 L
.50318 .46122 L
.50204 .46892 L
.50115 .47666 L
.5008 .48054 L
.50051 .48443 L
.50029 .48832 L
.5002 .49026 L
.50013 .49221 L
.50007 .49416 L
.50003 .4961 L
.50001 .49805 L
.5 .5 L
.50001 .50195 L
.50003 .5039 L
.50007 .50584 L
.50013 .50779 L
.5002 .50974 L
.50029 .51168 L
.50051 .51557 L
.5008 .51946 L
.50115 .52334 L
.50204 .53108 L
.50318 .53878 L
.50457 .54645 L
.50811 .56162 L
.51264 .57653 L
.51812 .59112 L
.5319 .61905 L
.5492 .64494 L
.56974 .66836 L
.59315 .68889 L
.61905 .7062 L
.63279 .71354 L
.64698 .71997 L
.66156 .72546 L
.67647 .72998 L
.69165 .73352 L
.69931 .73492 L
Mistroke
.70702 .73606 L
.71476 .73695 L
.71864 .7373 L
.72252 .73759 L
.72641 .73781 L
.72836 .7379 L
.7303 .73797 L
.73225 .73802 L
.7342 .73806 L
.73615 .73809 L
.7381 .7381 L
.74004 .73809 L
.74199 .73806 L
.74394 .73802 L
.74589 .73797 L
.74978 .73781 L
.75367 .73759 L
.75755 .7373 L
.76143 .73695 L
.76917 .73606 L
.77688 .73492 L
.78455 .73352 L
.79972 .72998 L
.81463 .72546 L
.82921 .71997 L
.85714 .7062 L
.88304 .68889 L
.90645 .66836 L
.92699 .64494 L
.94429 .61905 L
.95164 .60531 L
.95807 .59112 L
.96355 .57653 L
.96808 .56162 L
.97162 .54645 L
.97301 .53878 L
.97415 .53108 L
.97504 .52334 L
.97539 .51946 L
.97568 .51557 L
.9759 .51168 L
.97599 .50974 L
.97606 .50779 L
.97612 .50584 L
.97616 .5039 L
.97618 .50195 L
.97619 .5 L
Mfstroke
P
P
p
[ .04 .03 ] 0 setdash
p
.004 w
.97619 .5 m
.97617 .5039 L
.97613 .50779 L
.97605 .51169 L
.97594 .51558 L
.97579 .51947 L
.97562 .52337 L
.97517 .53114 L
.9746 .53891 L
.9739 .54667 L
.97212 .56216 L
.96983 .57757 L
.96704 .5929 L
.95996 .62325 L
.95092 .65307 L
.93994 .68223 L
.91239 .7381 L
.87779 .78989 L
.83672 .83672 L
.78989 .87779 L
.7381 .91239 L
.71061 .92708 L
.68223 .93994 L
.65307 .95092 L
.62325 .95996 L
.5929 .96704 L
.57757 .96983 L
.56216 .97212 L
.54667 .9739 L
.53891 .9746 L
.53114 .97517 L
.52337 .97562 L
.51947 .97579 L
.51558 .97594 L
.51169 .97605 L
.50779 .97613 L
.5039 .97617 L
.5 .97619 L
.4961 .97617 L
.49221 .97613 L
.48831 .97605 L
.48442 .97594 L
.47663 .97562 L
.46886 .97517 L
.46109 .9746 L
.45333 .9739 L
.43784 .97212 L
.42243 .96983 L
.4071 .96704 L
.37675 .95996 L
Mistroke
.34693 .95092 L
.31777 .93994 L
.2619 .91239 L
.21011 .87779 L
.16328 .83672 L
.12221 .78989 L
.08761 .7381 L
.07292 .71061 L
.06006 .68223 L
.04908 .65307 L
.04004 .62325 L
.03296 .5929 L
.03017 .57757 L
.02788 .56216 L
.0261 .54667 L
.0254 .53891 L
.02483 .53114 L
.02438 .52337 L
.02421 .51947 L
.02406 .51558 L
.02395 .51169 L
.02387 .50779 L
.02383 .5039 L
.02381 .5 L
.02383 .4961 L
.02387 .49221 L
.02395 .48831 L
.02406 .48442 L
.02421 .48053 L
.02438 .47663 L
.02483 .46886 L
.0254 .46109 L
.0261 .45333 L
.02788 .43784 L
.03017 .42243 L
.03296 .4071 L
.04004 .37675 L
.04908 .34693 L
.06006 .31777 L
.08761 .2619 L
.12221 .21011 L
.16328 .16328 L
.21011 .12221 L
.2619 .08761 L
.28939 .07292 L
.31777 .06006 L
.34693 .04908 L
.37675 .04004 L
.4071 .03296 L
.42243 .03017 L
Mistroke
.43784 .02788 L
.45333 .0261 L
.46109 .0254 L
.46886 .02483 L
.47663 .02438 L
.48053 .02421 L
.48442 .02406 L
.48831 .02395 L
.49221 .02387 L
.4961 .02383 L
.5 .02381 L
.5039 .02383 L
.50779 .02387 L
.51169 .02395 L
.51558 .02406 L
.52337 .02438 L
.53114 .02483 L
.53891 .0254 L
.54667 .0261 L
.56216 .02788 L
.57757 .03017 L
.5929 .03296 L
.62325 .04004 L
.65307 .04908 L
.68223 .06006 L
.7381 .08761 L
.78989 .12221 L
.83672 .16328 L
.87779 .21011 L
.91239 .2619 L
.92708 .28939 L
.93994 .31777 L
.95092 .34693 L
.95996 .37675 L
.96704 .4071 L
.96983 .42243 L
.97212 .43784 L
.9739 .45333 L
.9746 .46109 L
.97517 .46886 L
.97562 .47663 L
.97579 .48053 L
.97594 .48442 L
.97605 .48831 L
.97613 .49221 L
.97617 .4961 L
.97619 .5 L
Mfstroke
P
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[(-1)] .02381 .5 0 2 Msboxa
[(-0.5)] .2619 .5 0 2 Msboxa
[(0.5)] .7381 .5 0 2 Msboxa
[(1)] .97619 .5 0 2 Msboxa
[(-1)] .4875 .02381 1 0 Msboxa
[(-0.5)] .4875 .2619 1 0 Msboxa
[(0.5)] .4875 .7381 1 0 Msboxa
[(1)] .4875 .97619 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.02381 .5 m
.02381 .50625 L
s
P
[(-1)] .02381 .5 0 2 Mshowa
p
.002 w
.2619 .5 m
.2619 .50625 L
s
P
[(-0.5)] .2619 .5 0 2 Mshowa
p
.002 w
.7381 .5 m
.7381 .50625 L
s
P
[(0.5)] .7381 .5 0 2 Mshowa
p
.002 w
.97619 .5 m
.97619 .50625 L
s
P
[(1)] .97619 .5 0 2 Mshowa
p
.001 w
.07143 .5 m
.07143 .50375 L
s
P
p
.001 w
.11905 .5 m
.11905 .50375 L
s
P
p
.001 w
.16667 .5 m
.16667 .50375 L
s
P
p
.001 w
.21429 .5 m
.21429 .50375 L
s
P
p
.001 w
.30952 .5 m
.30952 .50375 L
s
P
p
.001 w
.35714 .5 m
.35714 .50375 L
s
P
p
.001 w
.40476 .5 m
.40476 .50375 L
s
P
p
.001 w
.45238 .5 m
.45238 .50375 L
s
P
p
.001 w
.54762 .5 m
.54762 .50375 L
s
P
p
.001 w
.59524 .5 m
.59524 .50375 L
s
P
p
.001 w
.64286 .5 m
.64286 .50375 L
s
P
p
.001 w
.69048 .5 m
.69048 .50375 L
s
P
p
.001 w
.78571 .5 m
.78571 .50375 L
s
P
p
.001 w
.83333 .5 m
.83333 .50375 L
s
P
p
.001 w
.88095 .5 m
.88095 .50375 L
s
P
p
.001 w
.92857 .5 m
.92857 .50375 L
s
P
p
.002 w
0 .5 m
1 .5 L
s
P
p
.002 w
.5 .02381 m
.50625 .02381 L
s
P
[(-1)] .4875 .02381 1 0 Mshowa
p
.002 w
.5 .2619 m
.50625 .2619 L
s
P
[(-0.5)] .4875 .2619 1 0 Mshowa
p
.002 w
.5 .7381 m
.50625 .7381 L
s
P
[(0.5)] .4875 .7381 1 0 Mshowa
p
.002 w
.5 .97619 m
.50625 .97619 L
s
P
[(1)] .4875 .97619 1 0 Mshowa
p
.001 w
.5 .07143 m
.50375 .07143 L
s
P
p
.001 w
.5 .11905 m
.50375 .11905 L
s
P
p
.001 w
.5 .16667 m
.50375 .16667 L
s
P
p
.001 w
.5 .21429 m
.50375 .21429 L
s
P
p
.001 w
.5 .30952 m
.50375 .30952 L
s
P
p
.001 w
.5 .35714 m
.50375 .35714 L
s
P
p
.001 w
.5 .40476 m
.50375 .40476 L
s
P
p
.001 w
.5 .45238 m
.50375 .45238 L
s
P
p
.001 w
.5 .54762 m
.50375 .54762 L
s
P
p
.001 w
.5 .59524 m
.50375 .59524 L
s
P
p
.001 w
.5 .64286 m
.50375 .64286 L
s
P
p
.001 w
.5 .69048 m
.50375 .69048 L
s
P
p
.001 w
.5 .78571 m
.50375 .78571 L
s
P
p
.001 w
.5 .83333 m
.50375 .83333 L
s
P
p
.001 w
.5 .88095 m
.50375 .88095 L
s
P
p
.001 w
.5 .92857 m
.50375 .92857 L
s
P
p
.002 w
.5 0 m
.5 1 L
s
P
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
.3 .9 1 r
.97472 .53736 m
.97033 .57449 L
.96303 .61116 L
.95288 .64715 L
.93994 .68223 L
.92429 .71619 L
.90602 .74881 L
.88525 .7799 L
.8621 .80926 L
.83672 .83672 L
.80926 .8621 L
.7799 .88525 L
.74881 .90602 L
.71619 .92429 L
.68223 .93994 L
.64715 .95288 L
.61116 .96303 L
.57449 .97033 L
.53736 .97472 L
.5 .97619 L
.46264 .97472 L
.42551 .97033 L
.38884 .96303 L
.35285 .95288 L
.31777 .93994 L
.28381 .92429 L
.25119 .90602 L
.2201 .88525 L
.19074 .8621 L
.16328 .83672 L
.1379 .80926 L
.11475 .7799 L
.09398 .74881 L
.07571 .71619 L
.06006 .68223 L
.04712 .64715 L
.03697 .61116 L
.02967 .57449 L
.02528 .53736 L
.02381 .5 L
.02528 .46264 L
.02967 .42551 L
.03697 .38884 L
.04712 .35285 L
.06006 .31777 L
.07571 .28381 L
.09398 .25119 L
.11475 .2201 L
.1379 .19074 L
.16328 .16328 L
.19074 .1379 L
.2201 .11475 L
.25119 .09398 L
.28381 .07571 L
.31777 .06006 L
.35285 .04712 L
.38884 .03697 L
.42551 .02967 L
.46264 .02528 L
.5 .02381 L
.53736 .02528 L
.57449 .02967 L
.61116 .03697 L
.64715 .04712 L
.68223 .06006 L
.71619 .07571 L
.74881 .09398 L
.7799 .11475 L
.80926 .1379 L
.83672 .16328 L
.8621 .19074 L
.88525 .2201 L
.90602 .25119 L
.92429 .28381 L
.93994 .31777 L
.95288 .35285 L
.96303 .38884 L
.97033 .42551 L
.97472 .46264 L
.97619 .5 L
F
P
p
p
.004 w
.97619 .5 m
.97617 .4961 L
.97613 .49221 L
.97605 .48831 L
.97594 .48442 L
.97579 .48053 L
.97562 .47663 L
.97517 .46886 L
.9746 .46109 L
.9739 .45333 L
.97212 .43784 L
.96983 .42243 L
.96704 .4071 L
.95996 .37675 L
.95092 .34693 L
.93994 .31777 L
.91239 .2619 L
.87779 .21011 L
.83672 .16328 L
.78989 .12221 L
.7381 .08761 L
.71061 .07292 L
.68223 .06006 L
.65307 .04908 L
.62325 .04004 L
.5929 .03296 L
.57757 .03017 L
.56216 .02788 L
.54667 .0261 L
.53891 .0254 L
.53114 .02483 L
.52337 .02438 L
.51947 .02421 L
.51558 .02406 L
.51169 .02395 L
.50779 .02387 L
.5039 .02383 L
.5 .02381 L
.4961 .02383 L
.49221 .02387 L
.48831 .02395 L
.48442 .02406 L
.47663 .02438 L
.46886 .02483 L
.46109 .0254 L
.45333 .0261 L
.43784 .02788 L
.42243 .03017 L
.4071 .03296 L
.37675 .04004 L
Mistroke
.34693 .04908 L
.31777 .06006 L
.2619 .08761 L
.21011 .12221 L
.16328 .16328 L
.12221 .21011 L
.08761 .2619 L
.07292 .28939 L
.06006 .31777 L
.04908 .34693 L
.04004 .37675 L
.03296 .4071 L
.03017 .42243 L
.02788 .43784 L
.0261 .45333 L
.0254 .46109 L
.02483 .46886 L
.02438 .47663 L
.02421 .48053 L
.02406 .48442 L
.02395 .48831 L
.02387 .49221 L
.02383 .4961 L
.02381 .5 L
.02383 .5039 L
.02387 .50779 L
.02395 .51169 L
.02406 .51558 L
.02421 .51947 L
.02438 .52337 L
.02483 .53114 L
.0254 .53891 L
.0261 .54667 L
.02788 .56216 L
.03017 .57757 L
.03296 .5929 L
.04004 .62325 L
.04908 .65307 L
.06006 .68223 L
.08761 .7381 L
.12221 .78989 L
.16328 .83672 L
.21011 .87779 L
.2619 .91239 L
.28939 .92708 L
.31777 .93994 L
.34693 .95092 L
.37675 .95996 L
.4071 .96704 L
.42243 .96983 L
Mistroke
.43784 .97212 L
.45333 .9739 L
.46109 .9746 L
.46886 .97517 L
.47663 .97562 L
.48053 .97579 L
.48442 .97594 L
.48831 .97605 L
.49221 .97613 L
.4961 .97617 L
.5 .97619 L
.5039 .97617 L
.50779 .97613 L
.51169 .97605 L
.51558 .97594 L
.52337 .97562 L
.53114 .97517 L
.53891 .9746 L
.54667 .9739 L
.56216 .97212 L
.57757 .96983 L
.5929 .96704 L
.62325 .95996 L
.65307 .95092 L
.68223 .93994 L
.7381 .91239 L
.78989 .87779 L
.83672 .83672 L
.87779 .78989 L
.91239 .7381 L
.92708 .71061 L
.93994 .68223 L
.95092 .65307 L
.95996 .62325 L
.96704 .5929 L
.96983 .57757 L
.97212 .56216 L
.9739 .54667 L
.9746 .53891 L
.97517 .53114 L
.97562 .52337 L
.97579 .51947 L
.97594 .51558 L
.97605 .51169 L
.97613 .50779 L
.97617 .5039 L
.97619 .5 L
Mfstroke
P
P
p
[ .04 .03 ] 0 setdash
p
.004 w
.97619 .5 m
.97617 .5039 L
.97613 .50779 L
.97605 .51169 L
.97594 .51558 L
.97579 .51947 L
.97562 .52337 L
.97517 .53114 L
.9746 .53891 L
.9739 .54667 L
.97212 .56216 L
.96983 .57757 L
.96704 .5929 L
.95996 .62325 L
.95092 .65307 L
.93994 .68223 L
.91239 .7381 L
.87779 .78989 L
.83672 .83672 L
.78989 .87779 L
.7381 .91239 L
.71061 .92708 L
.68223 .93994 L
.65307 .95092 L
.62325 .95996 L
.5929 .96704 L
.57757 .96983 L
.56216 .97212 L
.54667 .9739 L
.53891 .9746 L
.53114 .97517 L
.52337 .97562 L
.51947 .97579 L
.51558 .97594 L
.51169 .97605 L
.50779 .97613 L
.5039 .97617 L
.5 .97619 L
.4961 .97617 L
.49221 .97613 L
.48831 .97605 L
.48442 .97594 L
.47663 .97562 L
.46886 .97517 L
.46109 .9746 L
.45333 .9739 L
.43784 .97212 L
.42243 .96983 L
.4071 .96704 L
.37675 .95996 L
Mistroke
.34693 .95092 L
.31777 .93994 L
.2619 .91239 L
.21011 .87779 L
.16328 .83672 L
.12221 .78989 L
.08761 .7381 L
.07292 .71061 L
.06006 .68223 L
.04908 .65307 L
.04004 .62325 L
.03296 .5929 L
.03017 .57757 L
.02788 .56216 L
.0261 .54667 L
.0254 .53891 L
.02483 .53114 L
.02438 .52337 L
.02421 .51947 L
.02406 .51558 L
.02395 .51169 L
.02387 .50779 L
.02383 .5039 L
.02381 .5 L
.02383 .4961 L
.02387 .49221 L
.02395 .48831 L
.02406 .48442 L
.02421 .48053 L
.02438 .47663 L
.02483 .46886 L
.0254 .46109 L
.0261 .45333 L
.02788 .43784 L
.03017 .42243 L
.03296 .4071 L
.04004 .37675 L
.04908 .34693 L
.06006 .31777 L
.08761 .2619 L
.12221 .21011 L
.16328 .16328 L
.21011 .12221 L
.2619 .08761 L
.28939 .07292 L
.31777 .06006 L
.34693 .04908 L
.37675 .04004 L
.4071 .03296 L
.42243 .03017 L
Mistroke
.43784 .02788 L
.45333 .0261 L
.46109 .0254 L
.46886 .02483 L
.47663 .02438 L
.48053 .02421 L
.48442 .02406 L
.48831 .02395 L
.49221 .02387 L
.4961 .02383 L
.5 .02381 L
.5039 .02383 L
.50779 .02387 L
.51169 .02395 L
.51558 .02406 L
.52337 .02438 L
.53114 .02483 L
.53891 .0254 L
.54667 .0261 L
.56216 .02788 L
.57757 .03017 L
.5929 .03296 L
.62325 .04004 L
.65307 .04908 L
.68223 .06006 L
.7381 .08761 L
.78989 .12221 L
.83672 .16328 L
.87779 .21011 L
.91239 .2619 L
.92708 .28939 L
.93994 .31777 L
.95092 .34693 L
.95996 .37675 L
.96704 .4071 L
.96983 .42243 L
.97212 .43784 L
.9739 .45333 L
.9746 .46109 L
.97517 .46886 L
.97562 .47663 L
.97579 .48053 L
.97594 .48442 L
.97605 .48831 L
.97613 .49221 L
.97617 .4961 L
.97619 .5 L
Mfstroke
P
P
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
:[font = subsection; inactive; ]
Example 2
:[font = input; nowordwrap; ]

stab1[0.003, 4, 0.0, 1.5, sch2]

:[font = subsection; inactive; ]
Example 3
:[font = input; nowordwrap; ]

stab1[0.002, 4, 0.0, 1.5, sch3]

:[font = section; inactive; ]
The Structure of the Output
:[font = text; inactive; ]
The following data are printed out in the process of the work of the program:

1. The symbolic expression for the amplification factor lambda for a given
     difference scheme;

2. The real part rel = Re(lambda) and iml = Im(lambda) of the amplification
     factor lambda;

3. The graphs of the curves (Re(lambda), Im(lambda)) for n1plot fixed
     values of the parameter c1 = kappa;

4. The table of the values of sin(xi) and cos(xi) in the  nspg nodes of an
     uniform grid in the interval [0, 2Pi];

5. The table of the values of the binary function (2.3.18) in 15 nodes of an
     uniform grid in the interval ac1 <= kappa <= bc1;

6. The computed value of c1 = kappa corresponding to the stability region
     boundary of a given difference scheme.
^*)