(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
Modified Pavlidis'Algorithm
:[font = name; inactive; nohscroll; ]

                                   Victor G.Ganzha and Evgenii V.Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

This Mathematica-Notebook is part of the book entitled
                                  V.G.Ganzha and E.V.Vorozhtsov
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]
Numerical Solutions For Partial Differential Equations: Problem Solving
Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.

:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The program st2t.ma which follows below enables one to perform the
test of the modified Pavlidis' algorithm from Section 2.13 of the above
book at the binary function (2.13.6). The description of the algorithm 
can be found in Section 2.13 of the above book.

:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = special4; inactive; nowordwrap; nohscroll; ]
Load and compile the program file beginning with the line

:[font = input; nowordwrap; ]

ClearAll[fbis, bingen, inds, atan3,
         tracer, bisec, stab2];
:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the input data by entering them in the line (see Section 
"Examples of the Input Data"):
:[font = input; nowordwrap; ]

stab2[-1.2, 1.2, -1.2, 1.2, 10, 10, 2, 0.005]
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line and wait for the result of symbolic/numerical computation.
The meaning of the input parameters is explained in the Section
"Parameters Used in Program st2mc.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; backColorRed = 65280; backColorGreen = 65280; backColorBlue = 65280; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; bold; fontName = "Courier New"; fontSize = 12; ]

ClearAll[fbis, bingen, inds, atan3,
         tracer, bisec, stab2];

fbis[x_, y_, ss1_List, cc1_List, nspg_] :=
( r1 = 0.5; r2 = r1/2; r = N[Sqrt[x^2 + y^2]];
  fbs1 = If[r2<= r&&r<=r1, 1, 0];
fbs2 = If[-0.05<=y && y<= 0.05, 0, fbs1];
fbs3 = If[-0.05<=x&&x<=0.05&&0.3<=y&&y<=0.4,0,fbs2];
fbs4=If[-0.07<=x&&x<=0.07&&-0.4<=y&&y<=-0.3,0,fbs3];
fbs4 );

bingen[xl_, xr_, yb_, yt_, ix_, jy_]:=
(* --- Generation of the bilevel image fbin --- *)
( fbin = Table[0, {i, ix}, {j, jy}];
  jsum = 0; hx = (xr - xl)/ix; hy = (yt - yb)/jy;
Print["Bilevel picture generation"];
 Do[x = xl + (i - 0.5)*hx; binlist = {};
    Do[y = yb + (j -0.5)*hy;
    fbin[[i, j]] = fbis[x, y, ss1, cc1, nspg];
    AppendTo[binlist, fbin[[i, j]] ];
       jsum = jsum + fbin[[i, j]], {j, jy}];
       Print[binlist], {i, ix}];
		                {jsum, fbin} );

inds[is_, i_, j_, ix_, jy_]:=
(* - This procedure determines the indices (i1,j1)
     of the next cell along the contour basing on 
     the indices (i,j) of a given cell and the 
     given search direction "is", 1<= is<= 8 - *)
( jb = 0; is2 = is; If[is2 > 8, is2 = is - 8];
  If[is2 == 1, i1 = i + 1; j1 = j;
 If[i1 < 1||i1 > ix || j1 < 1 || j1 > jy, jb = 1];
 Return[{i1, j1, jb}]];
   If[is2 == 2, i1 = i + 1; j1 = j + 1;
   If[i1 < 1||i1 > ix || j1 < 1||j1 > jy, jb = 1];
   Return[{i1, j1, jb}]];
     If[is2 == 3, i1 = i; j1 = j + 1;
     If[i1 < 1||i1 > ix||j1 < 1||j1 > jy, jb = 1];
     Return[{i1, j1, jb}]];
       If[is2 == 4, i1 = i - 1; j1 = j + 1;
 If[i1 < 1||i1 > ix || j1 < 1 || j1 > jy, jb = 1];
       Return[{i1, j1, jb}]];
         If[is2 == 5, i1 = i - 1; j1 = j;
 If[i1 < 1||i1 > ix || j1 < 1 || j1 > jy, jb = 1];
         Return[{i1, j1, jb}]];
          If[is2 == 6, i1 = i - 1; j1 = j - 1;
 If[i1 < 1||i1 > ix || j1 < 1 || j1 > jy, jb = 1];
          Return[{i1, j1, jb}]];
        If[is2 == 7, i1 = i; j1 = j - 1;
 If[i1 < 1||i1 > ix || j1 < 1 || j1 > jy, jb = 1];
        Return[{i1, j1, jb}]];
      If[is2 == 8, i1 = i + 1; j1 = j - 1;
 If[i1 < 1||i1 > ix || j1 < 1 || j1 > jy, jb = 1];
      Return[{i1, j1, jb}]]);

tracer[nsg_, i0_, j0_, xl_, yb_]:=
(* ------------ Tracing a contour ------------ *)
( i = i0;   j = j0;   is = 0;
fbin[[i, j]] = fbin[[i, j]] + 1;
is = is + 1; jc[[is, nsg]] = 9; iser = 7; ifir = 1;
     xs[[is, nsg]] = xl + (i - 0.5)*hx;
     ys[[is, nsg]] = yb + (j - 0.5)*hy;
Label[m8]; icnt = 0; ifnd = 0;
Label[m13]; is1 = iser - 1; If[is1 == 0, is1 = 8];
	   {i1, j1, jb} = inds[is1, i, j, ix, jy];
 If[jb == 1|| fbin[[i1, j1]] == 0, Goto[m9]];
  iser = iser - 2; If[iser <= 0, iser = iser + 8];
Label[m11]; is = is + 1; i=i1; j=j1;
            fbin[[i, j]] = fbin[[i, j]] + 1;
xs[[is, nsg]] = xl + (i - 0.5)*hx;
ys[[is, nsg]] = yb + (j - 0.5)*hy;
jc[[is, nsg]] = is1; ifnd = 1;
        If[i!= i0 || j != j0, Goto[m8], Goto[m7]];
Label[m9]; {i1, j1, jb} = inds[iser, i, j, ix, jy];
       If[jb == 1||fbin[[i1, j1]] == 0, Goto[m10]];
is1 = iser; Goto[m11];
Label[m10]; is1=iser+1; If[is1 > 8, is1 = is1 - 8];
{i1, j1, jb} = inds[is1, i, j, ix, jy];
If[jb==1||fbin[[i1,j1]]==0, Goto[m12]]; Goto[m11];
Label[m12]; iser=iser+2; If[iser>8,iser=iser - 8];
            ifir = 0;
If[ifnd == 1, Goto[m7]]; icnt = icnt + 1;
                         If[icnt < 3, Goto[m13]];
Label[m7]; kss[[nsg]] = is );

remove[istar_, ifin_, k_] :=
( istar2 = istar; If[istar<=ifin,ic=jc[[istar,k]];
istar2 = istar2 + 1; Return[{ic, istar2}]];
ic = -1; {ic, istar2} );

 atan3[zy_, zx_] :=
( rof = 0.000000001;
If[Abs[zx]>rof,Goto[m2]]; If[Abs[zy]<rof,Goto[m3]];
a = N[Pi/2.0]; If[zy < 0.0, a = N[a + Pi]]; 
    Return[a];
Label[m3]; a = 0.0; Return[a];
Label[m2]; If[Abs[zy] < rof, a = 0.0;
           If[zx < 0.0, a = N[Pi]]; Return[a]];
a = ArcTan[zx,zy]; If[zx>0.0&&zy>0.0, Return[a]];
If[zx > 0.0&& zy < 0.0, a = N[a + 2*Pi]; Return[a]];
     If[zx < 0.0, a = N[a + Pi]]; Return[a]  );

bisec[x_,y_,ik_,k_,mk_,eps_,xl_,yb_,adir_List]:=
(* The refinement of the (x,y) coordinates of the
   ik th point of the k th contour; mk is the 
   length of the kth contour -------------------- *)
( i = Floor[1.0 + (x - xl)*hx1];
                     j = Floor[1.0 + (y -yb)*hy1];
i1 = ik + 1; i2 = ik - 1;
    If[ik == mk, i1 = i1 - 1; i2 = i2 - 1];
       If[ik == 1, i2 = 1];
(* -- Determining the number k2 of the principal 
      direction corresponding to the direction of 
      a normal to the contour at (i, j) point. - *)
(* x1 = xs[[i1, k]]; y1 = ys[[i1, k]];
           x2 = xs[[i2, k]]; y2 = ys[[i2, k]];  *)
   x1 = xtab[[i1]]; y1 = ytab[[i1]];
                 x2 = xtab[[i2]]; y2 = ytab[[i2]];
     dx = x2 - x1; dy = y1 - y2;
anrm = atan3[dx, dy];   zm = 1000.0; il = -2;
Do[ zk = Abs[adir[[ja]] - anrm];
                     If[zk < zm, zm = zk;k2 = ja],
     {ja, 9}];
               If[k2 == 9, k2 = 1];
(* -- Determining the indices (il, jl) of a cell 
      lying on a normal to the contour -------- *)
If[k2 == 1, il = i + 1; jl = j; ir = i - 1; jr = j];
  If[il > -2, Goto[refin]];
If[k2 == 2, il=i+1; jl=j+1; ir = i - 1; jr= j - 1];
     If[il > -2, Goto[refin]];
If[k2 == 3, il = i; jl = j+ 1; ir = i; jr = j - 1];
        If[il > -2, Goto[refin]];
If[k2 == 4, il = i - 1; jl=j+1; ir=i+1;jr = j - 1];
           If[il > -2, Goto[refin]];
If[k2 == 5, il = i - 1; jl = j; ir = i + 1; jr= j];
           If[il > -2, Goto[refin]];
If[k2 == 6, il = i-1; jl=j-1; ir=i + 1;jr = j + 1];
        If[il > -2, Goto[refin]];
If[k2 == 7, il = i; jl = j - 1; ir = i; jr= j + 1];
    If[il > -2, Goto[refin]];
If[k2 == 8, il= i + 1; jl = j-1; ir=i-1; jr=j + 1];
Label[refin];
x1n = xl + (il - 0.5)*hx; y1n = yb + (jl - 0.5)*hy;
x2n = xl + (ir - 0.5)*hx; y2n = yb + (jr - 0.5)*hy;
tl = 0.0; tr = 1.0; a1 = x2n - x1n; a2 = y2n - y1n;
	 isl = fbis[x1n, y1n, ss1, cc1, nspg];
isr = fbis[x2n,y2n,ss1,cc1,nspg]; x3 = x; y3 = y;
     If[isl != isr, Goto[bisproc]];
                       If[isl== 0, Goto[recalc]];
If[il == 0||ir == 0, x3 = xl];
         If[il == ix + 1||ir == ix + 1, x3 = xr];
If[jl == 0||jr == 0,y3 = yb];
         If[jl == jy + 1||jr == jy + 1, y3 = yt];
Return[{x3, y3}];
Label[recalc]; ir=i;jr=j; x2n=x; y2n= y; isr = 1;
                  a1 = x2n - x1n; a2 = y2n - y1n;
Label[bisproc];
t = N[(tl+tr)*0.5]; xc=a1*t+x1n; yc = a2*t + y1n;
         nc = fbis[xc, yc, ss1, cc1, nspg];
	If[nc == isr, tr = t, tl = t];
  If[N[Abs[a1*(tl - tr)]] > eps, Goto[bisproc]];
     If[N[Abs[a2*(tl - tr)]] > eps, Goto[bisproc]];
  x3 = a1*t + x1n; y3 = a2*t + y1n;
			 Return[{x3, y3}]  );

 stab2[xl_,xr_,yb_,yt_,ix_,jy_,nsptr_,eps_] :=
 (

(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%  Part 2. Numerical computations with the purpose  %%%%
%%%%  of determining the coordinates of points of all  %%%%
%%%%  the contours of the stability region boundary    %%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*)

nspg = 2; 
    ss1 = Table[N[Sin[(k-1)*2*Pi/nspg]], {k, nspg}];
    cc1 = Table[N[Cos[(k-1)*2*Pi/nspg]], {k, nspg}];
  {nsp1, fbin} = bingen[xl, xr, yb, yt, ix, jy];
  nparea = nsp1; lenmax = 1000;
             xtab = Table[99.9999, {j,lenmax}];
             ytab = Table[99.9999, {j,lenmax}];
   frow = Table[0, {i, ix}];
   Do[k = jy - j + 1;
      Do[frow[[i]] = fbin[[i, k]], {i, ix}];
      Print[frow],
   {j,jy}];
If[nsp1 == 0, Print["No stability points"]; 
Interrupt[ ]];
If[nsp1 == ix*jy,
Print["The difference scheme is stable in the",
" given region"];
Print["{(kappa1,kappa2)|",xl,"<=kappa1<=",xr,
",", yb,"<=kappa2<=",yt,"}"];
Print["Computation is interrupted."];
Interrupt[] ];

   Print["j       Xj        sin(Xj)      cos(Xj)"];
Do[ss= ss1[[j]]; cc= cc1[[j]]; xj= N[(j - 1)*2*Pi/nspg];
     Print[j, "  ", xj, ,"  ", ss, , "  ", cc],
            {j, nspg}];

z1 = nsp1*hx*hy; Print["Area of stability region = ", z1];
      nparea = nsp1; ifir = 0; nsg = 0;
			nsgmax = 10; lenmax = 1000;
(*  nsg is the number of contours of the stability
    region boundary  *)
(* -- lenmax is the maximum length, that is the maximum
      number of pixels, for each detected contour ------ *)
(* --- Initialization of a number of lists ----- *)
    xs = Table[999.99999, {i, lenmax}, {j, nsgmax}];
    ys = Table[999.99999, {i, lenmax}, {j, nsgmax}];
(*  (xs[[i, j]], ys[[i, j]]) are the (kappa1, kappa2)
   coordinates of the i th point of the j th contour --- *)
      jc = Table[99, {i, lenmax}, {j, nsgmax}];
(*  jc is a two-dimensional array of integers used to mark
      different points of different contours ---- *)
      kss = Table[9999, {j, nsgmax}];
(*  kss[[j]] is the length of the j th contour,
    1 <= j <= nsgmax  *)

(* ------ Tracing the external contours ------- *)
    Do[
       Do[
          If[fbin[[ii, jj]] == 0, Goto[endloop]];
(* - Search for the starting point of the contour - *)
If[fbin[[ii, jj]] > 1, Goto[endloop]];
                          If[ii == 1,Goto[start]];
If[fbin[[ii - 1, jj]] != 0, Goto[endloop]];
Label[start]; i0 = ii; j0 = jj; nsg = nsg + 1;
 If[nsg > nsgmax,
          Print["The number of contours exceeds ", nsgmax];
Print["Detection of further contours is interrupted."];
Print["To detect the remaining contours please increase",
" the value of nsgmax, see line 419 above."]; Break[ ]];
   tracer[nsg, i0, j0, xl, yb];
		       Label[endloop],
	    {ii, ix}];
If[nsg > nsgmax, nsg = nsg - 1; Break[ ]],
   {jj, jy}];
(* ------- Tracing the contours of holes ------- *)
 k1 = 1; k2 = nsg; nsg1 = nsg; hx = (xr - xl)/ix;
                               hy = (yt - yb)/jy;
                 hx1 = 1/hx; hy1 = 1/hy; k = 1;
 Label[l20];
      ig = kss[[k]]; istar = 1; ifin = ig;
Label[l17]; {id, istar2} = remove[istar, ifin, k];
        istar = istar2;
   If[id == -1, Goto[l3]];  If[id != 9, Goto[l15]];
id0 = id; {id,istar2} = remove[istar, ifin, k];
                istar = istar2;
Label[l15]; If[id0 < 5||id0 > 8, Goto [l16]];
            If[id < 6||id > 8, Goto[l16]];
x1 = xs[[istar, k]]; y1 = ys[[istar, k]];
  ilef = Floor[0.51 + (x1 - xl)*hx1];
                  j2 = Floor[0.51 + (y1 - yb)*hy1];
ilp = ilef + 1; irm = ix - 1;  i2 = ilp;
   Label[lilp];
    ia = fbin[[i2 - 1, j2]]; ib = fbin[[i2, j2]];
   ic = fbin[[i2 + 1, j2]]; If[ia != 0, Goto[l37]];
    If[ib != 1||ib != 2||ic != 0, Goto[l27]];
          i0 = i2; j0 = j2; nsg1 = nsg1 + 1;
 Print["The contour No. ", nsg1, " is detected."];
 tracer[nsg1, i0, j0, xl, yb]; Goto[l16];
Label[l27];
       If[ia == 0 && ib > 2 && id ==-1, Goto[l16]];
Label[l37];
    If[ia == 1 && ib == 2&&id == -1, Goto[l16]];
 i2 = i2 + 1; If[i2 <= irm, Goto[lilp]];  Goto[l3];
Label[l16]; id0 = id; Goto[l17];
Label[l3];
          k = k + 1; If[k <= k2, Goto[l20]];
If[nsg1 == nsg, Goto[l21]];
nsg = k2; k1 = nsg + 1; k2 = nsg1; Goto[l20];
Label[l21]; nsg = nsg1; Print["Number of contours = ",nsg];
   Do[ isg = kss[[k]];
Print["The length of the contour No. ", k, " is ", isg,
      " points"], {k, nsg}];

(* -- Storing the pictures in the elements mt[[k]],
         k = 1,...,nsg ------------------------- *)
             nsg1 = nsg + 1;  mt = {};
          xtab = Table[99.9999, {j,lenmax}];
          ytab = Table[99.9999, {j,lenmax}];
    Do[ isg = kss[[k]];
Print["The x- and y-coordinates of points of the contour ",
      "No. ", k];
       Do[    xx = xs[[j, k]]; yy = ys[[j, k]];
          Print[j,"   ", xx, "   ", yy], {j, isg}],
          {k, nsg}];
   Do[ isg = kss[[k]];
       Do[xtab[[j]] = xs[[j, k]]; ytab[[j]] = ys[[j, k]],
          {j, isg}];
       xytab = Table[{xtab[[j]], ytab[[j]]}, {j, isg}];
       plj = ListPlot[xytab, PlotJoined -> True,
                   AxesLabel->{"kappa1","kappa2"},
                   AspectRatio -> Automatic,
                   DisplayFunction -> Identity];
       AppendTo[mt, plj],
          {k, nsg}];
xtab = Table[99.999,{j, nparea}]; 
ytab = Table[99.999,{j, nparea}];
   k = 0;
   Do[
      Do[ k1 = fbin[[i, j]];
   If[k1 != 0, k=k + 1; xtab[[k]]=xl + (i - 0.5)*hx;
          ytab[[k]] = yb + (j - 0.5)*hy],
                        {j, jy}],
           {i, ix}];
   xytab = Table[{xtab[[j]], ytab[[j]]}, {j, nparea}];
   pldot = ListPlot[xytab,
             AxesLabel->{"kappa1","kappa2"},
             AspectRatio -> Automatic,
             DisplayFunction -> Identity];
   AppendTo[mt, pldot];
 gr = Show[mt,DisplayFunction->$DisplayFunction]; 
  Display["fig2_36", gr];

(*  Specification of the angles adir[[j]] corresponding to
    the eight principal directions; the direction
    adir[[9]] = 2 Pi is an auxiliary direction, which is
    identified with the direction adir[[1]] = 0 in subseq-
    uent computations. *)
 adir = {}; AppendTo[adir, 0.0]; z = ArcTan[hx, hy];
       AppendTo[adir, z]; pi2 = N[Pi/2.]; z2 = N[pi2 - z];
z3 = N[pi2 + z2]; z4 = N[Pi + z]; z7 = N[Pi + pi2];
z8 = N[z7 + z2];
     AppendTo[adir, pi2];
AppendTo[adir, z3]; AppendTo[adir, N[Pi]];
      AppendTo[adir, z4];
      AppendTo[adir, z7]; AppendTo[adir, z8];
                  z9 = Pi + Pi; AppendTo[adir, N[z9]];
Print["The values of angles corresponding to nine",
              " principal directions"];
 Print[adir];
 Print["The refinement of coordinates of contour points"];
(* - Refinement of coordinates of boundary points - *)
Do[  mk = kss[[k]]; xtab = {}; ytab = {};
   Do[ xx6 = xs[[ii,k]]; yy6 = ys[[ii, k]];
   AppendTo[xtab, xx6]; AppendTo[ytab, yy6],
      {ii, mk}];
   Do[x1 = xs[[ii, k]]; y1 = ys[[ii, k]];
{x3, y3} = bisec[x1,y1,ii,k,mk,eps,xl,yb,adir];
Print["The point no. ", ii, " has been refined"];
	 xs[[ii, k]] = x3; ys[[ii, k]] = y3,
      {ii, mk}];
 Print["The contour No.", k," has been refined"],
 {k, nsg}];
(* ------- Closing the refined contours ------- *)
Do[ isg = kss[[k]]; z1=0.5*(xs[[1,k]]+xs[[isg,k]]);
                     z2 = 0.5*(ys[[1,k]] + ys[[isg, k]]);
    xs[[1,k]] = z1; ys[[1, k]] = z2;
	     xs[[isg, k]] = z1; ys[[isg, k]] = z2,
    {k, nsg}];
(* - Graphical display of the refined contours - *)
                           mt = {}; 
   Do[ isg = kss[[k]]; xtab = {}; ytab = {};
       Do[ AppendTo[xtab,xs[[j,k]]]; 
        AppendTo[ytab,ys[[j,k]]], {j, isg}];
   xytab = Table[{xtab[[j]], ytab[[j]]}, {j, isg}];
       plj = ListPlot[xytab, PlotJoined -> True,
                    AxesLabel->{"kappa1","kappa2"},
                    AspectRatio -> Automatic,
                    DisplayFunction -> Identity];
       AppendTo[mt, plj],
          {k, nsg}];
                     AppendTo[mt, pldot];
gr1 = Show[mt,DisplayFunction->$DisplayFunction];

		  Display["fig2_37", gr1];

(* ------- End of the procedure stab2 --------- *)
	  )


:[font = section; inactive; ]
Parameters Used in Program st2t.ma
:[font = special4; inactive; nowordwrap; nohscroll; ]
______________________________________________________
 Parameter                         Description
______________________________________________________
xl                   the left end of the interval on the kappa1-axis (the
                     horizontal axis), in which the stability region is to
                     be determined;
 xr                 the right end of the above interval on the
                     kappa1-axis; xl<=kappa1<= xr;
 yb                the lower end of the interval on the kappa2-axis (the
                     vertical axis), in which the stability region is to
                     be determined;
 yt                 the upper end of the above interval on the kappa2-
                    axis; yb<=kappa1<= yt;
                    the stability region is thus to be determined in a
                    rectangle in the (kappa1, kappa2) plane;
 ix                the number of cells of an uniform mesh in the inter-
                    val xl<= kappa1<=xr; ix >= 3;
 jy                 the number of cells of an uniform mesh in the inter-
                    val yb<= kappa2<=yt; jy >= 3;
nsptr            the number of spectral variables,  nsptr = 1 or
                    nsptr = 2;
eps              the given accuracy of the computation of the coordi-
                    nates of points of the stability region boundary.  *)
_______________________________________________________

:[font = section; inactive; ]
Examples of the Input Data
:[font = subsection; inactive; ]
Example 1
:[font = input; nowordwrap; ]

stab2[-0.6, 0.6, -0.6, 0.6, 30, 30, 1, 0.005]

:[font = section; inactive; ]
The Structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]

    The following data are printed out in the process of the work of the program:

1. The values of the binary function fbin[[j,k]] for all the nodes (p,q) of an
     uniform grid in the (kappa1,kappa2) plane. The value fbin[[j,k]] = 1
     corresponds to a stable point of difference scheme.

2. The table of the values of sin(xj) and cos(xj) in the nspg nodes of an
     uniform grid in the interval [0, 2Pi).

3. The area of stability region.

4. The number of the detected contours of the stability region boundary.

5. The length of each contour as the number of (p,q) nodes belonging to
     the contour.

6. The x- and y-coordinates of points of each contour.

7. The values of angles (in radians) corresponding to nine principal 
       directions. These values are used in the Pavlidis' algorithm of 
       contour tracing.

8. The stability region with its interior marked by stable points.

9. The refined stability region boundaries together with the interior of 
       the stability region marked by stable points.
^*)